<?php

namespace App\Console\Commands;

use App\Enums\OrderStatusEnum;
use App\Models\Order;
use App\Models\OrderCanceled;
use App\Models\User;
use App\Notifications\Customer\Order\OrderCancelledByTimeout;
use Illuminate\Console\Command;
use Illuminate\Support\Facades\DB;

class CloseOrderPendingOfPayment extends Command
{
    const TIME = 24;
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'app:close-order-pending-of-payment';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Command description';

    /**
     * Execute the console command.
     */
    public function handle()
    {
        $orders = Order::where('status', OrderStatusEnum::PENDING_PAYMENT)->where('created_at', '<', now()->subHours(self::TIME))->get();
        $users = User::fullCustomer()
                    ->whereIn('customers.id', $orders->pluck('customer_id'))
                    ->get();
        foreach ($orders as $order) {

            DB::transaction(function () use($order, $users){

                $order->status = OrderStatusEnum::CANCELLED;
                $order->save();

                OrderCanceled::create([
                    'user_id' => null,
                    'order_id' => $order->id,
                    'reason' => __('system.order-cancelled-by-timeout', ['TIME' => self::TIME . ' hrs'])
                ]);

                $user = $users->firstWhere('customer_id', $order->customer_id);
                if($user) $user->notify(new OrderCancelledByTimeout($order, self::TIME));

            });
        }
    }
}
