<?php

namespace App\Console\Commands;

use Illuminate\Console\Command;
use App\Models\Product;
use App\Enums\BrandsEnum;

class SynchBrands extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'app:sync-brands';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Save products brands';

    /**
     * Execute the console command.
     */
    public function handle()
    {
        $products = Product::all();

        foreach ($products as $product) {
            if ( !is_null($product->name) ) {
                $brandFound = false;

                foreach (BrandsEnum::cases() as $brand) {
                    if (stripos($product->name, $brand->value) !== false) {
                        $product->brand = $brand->value;
                        $product->save();
                        $brandFound = true;
                        break;
                    }
                }

                if (!$brandFound) {
                    $this->warn("No se encontró una marca para: {$product->name}");
                }
            } else {
                $this->alert("Este producto {$product->id} no tiene nombre.");
            }
        }

        $this->info('Las marcas de los productos se han actualizado correctamente.');
    }
}
