<?php

namespace App\Console\Commands;

use Illuminate\Console\Command;
use GuzzleHttp\Client;
use Illuminate\Support\Facades\DB;

class UpdateExchangeRate extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'app:exchange-rate:update';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Update USD to MXN exchange rate';

    /**
     * Execute the console command.
     */
    public function handle()
    {
        $client = new Client();
        $response = $client->request('GET', 'http://data.fixer.io/api/latest', [
            'query' => [
                'access_key' => env('FIXER_API_KEY'),
                'symbols' => 'USD,MXN',
            ]
        ]);

        $data = json_decode($response->getBody(), true);

        if ($data['success'] && isset($data['rates']['USD'], $data['rates']['MXN'])) {

            $usdToEur = $data['rates']['USD'];
            $mxnToEur = $data['rates']['MXN'];

            // Convertir la tasa de USD a MXN
            $usdToMxn = $mxnToEur / $usdToEur;

            DB::table('exchange_rates')->updateOrInsert(
                ['currency_pair' => 'USD/MXN'],
                ['rate' => $usdToMxn, 'updated_at' => now()]
            );

            $this->info('Exchange rate updated successfully.');
        } else {
            $this->error('Failed to update exchange rate.');
        }
    }
}
