<?php
namespace App\Helpers;

use Carbon\Carbon;

class Dates{
    /**
     * - Transformar una fecha UTC a la zona horaria y lenguaje indicados
     *
     * @param Carbon $date Un objeto Carbon que debe estar ya configurado con la zona horaria UTC.
     * @param string $timezone La zona horaria en la que se desea obtener la fecha.
     * @param string $language El idioma en el que se desea mostrar la fecha.
     * @return Carbon.
     */
    public static function UTCToLocalTimeZone(
        Carbon $date,
        string|null $timezone = 'America/Mexico_City',
        string|null $language = 'es'){

            $date = is_string($date) ?  new Carbon($date, 'UTC') : $date;
            $dateTransformed = $date->copy()->tz($timezone)->locale($language);

            return $dateTransformed;
    }
    /**
     *- Transformar una fecha UTC a la zona horaria y lenguaje indicados
     *
     * @param Carbon $date Un objeto Carbon que debe estar ya configurado con la zona horaria UTC.
     * @param string $format El formato deseado para la fecha. Por defecto, es: d/m/Y h:i a.
     * @param string $timezone La zona horaria en la que se desea obtener la fecha.
     * @param string $language El idioma en el que se desea mostrar la fecha.
     * @return string La fecha formateada según los parámetros especificados.
     */
    public static function formatForUser(
        Carbon $date,
        string|null $format = 'd/m/Y h:i a',
        string|null $timezone = 'America/Mexico_City',
        string|null $language = 'es'){

            $dateTransformed = self::UTCToLocalTimeZone($date, $timezone, $language);

            return $dateTransformed->format($format);
    }
    /**
     * Transformacion de una fecha a UTC
     *
     * @param string $date
     * @param string $formatOfDate
     * @param string $timezone Zona horaria de la fecha
     * @return Carbon
     */
    public static function localTimezoneToUTC(
        string $date,
        string|null $formatOfDate = 'Y-m-d H:i:s',
        string|null $timezone = 'America/Mexico_City'){

        $dateCarbon = Carbon::createFromFormat($formatOfDate, $date, $timezone);

        return $dateCarbon->copy()->tz('UTC');
    }

}
