<?php

namespace App\Http\Controllers\CustomerSupport;

use App\Http\Controllers\Controller;
use App\Http\Resources\CustomerSupport\Address;
use App\Http\Resources\CustomerSupport\Customer as CustomerSupportCustomer;
use Illuminate\Http\Request;
use App\Models\Customer;
use App\Mail\AccountActivated;
use App\Models\CustomerAddress;
use App\Models\Location;
use App\Models\User;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Mail;

class CustomerController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $customers = Customer::select(
                            'customers.id',
                            'customers.user_id',
                            'customers.location_id',
                            'customers.company_name',
                            'customers.netsuite_key',
                            'customers.rfc',
                            'customers.status',
                            'customers.created_at',
                            'customers.updated_at',
                            'customers.deleted_at',
                            DB::raw('users.name AS username'))
                        ->join('users', 'users.id', '=', 'customers.user_id')
                        ->orderBy('id', 'DESC')
                        ->get();
        $address = CustomerAddress::whereIn('customer_id', $customers->pluck('id'))
                    ->get();

        return view('customer_support.customers.index', [
                    'customers' => CustomerSupportCustomer::collection($customers),
                    'address' => Address::collection($address)
                ]);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Customer $customer)
    {
        return view('customer_support.customers.edit', [
            'customer' => $customer,
            'locations' => is_numeric($customer->location_id) ? [] : Location::get()
        ]);
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, Customer $customer)
    {
        DB::beginTransaction();

        try {
            //Si viene  los datos de una sucursal se los asignamos, caso se usan los ya establecidos
            $currentStatus = $customer->status;
            $customer->location_id = $request->input('location_id', $customer->location_id);
            $customer->netsuite_key = $request->netsuite_key;

            if(isset($request->password) && strlen($request->password) > 0) $customer->user->password = Hash::make($request->password);

            $customer->status = 'active';
            $customer->save();
            $customer->user->save();

            if($currentStatus == 'pending')
                Mail::to($customer->user->email )->send( new AccountActivated($customer->user->email, $request->password) );

            DB::commit();

            $ms = $currentStatus == 'pending' ? 'Nuevo cliente activo' : 'Cliente actualizado';
            session()->flash('message', $ms);
            session()->flash('icon', 'success');

        } catch (\Exception $e) {
            session()->flash('message', 'Ups! Algo salió mal, contacta a soporte');
            session()->flash('icon', 'error');
        }

        return redirect()->route('admin.customers.index');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        DB::beginTransaction();

        try {

            $customer = Customer::findOrFail($id);
            $customer->deleted_at = now();
            $customer->save();
            $user = User::findOrFail($customer->user_id);
            $user->deleted_at = now();
            $user->save();
            DB::commit();
            $message = __('Cliente eliminado');

        } catch (\Throwable $th) {
            \Log::error($th->getMessage());
            \Log::error($th->getTraceAsString());
            DB::rollback();
            $message = __('alerts.error');
        }

        session()->flash('message', $message);
        return redirect()->route('admin.customers.index');
    }
}
