<?php

namespace App\Http\Controllers\CustomerSupport;

use App\Http\Controllers\Controller;
use App\Models\Shipment;
use App\Services\ShippingServiceFactory;
use App\UseCases\Shipment\Guide;

class ShipController extends Controller
{
    protected $shippingServiceFactory;

    public function __construct(ShippingServiceFactory $factory)
    {
        $this->shippingServiceFactory = $factory;
    }

    public function handle(int $shipment_id){

        $shipment = Shipment::findOrFail($shipment_id);

        $handler = new Guide($shipment, $this->shippingServiceFactory->make($shipment->carrier));
        $result = $handler->handle();

        return response()->json([
            'trackingNumber' => $result->getTrackingNumber(),
            'urlPdf' => route('admin.orders.shipment.label', ['shipment_id' => $shipment->id]),
            'message' => __('Instrucción procesada')
        ]);

    }
}
