<?php

namespace App\Http\Controllers\CustomerSupport;

use App\Http\Controllers\Controller;
use App\Models\Shipment;
use App\Services\ShippingServiceFactory;
use Illuminate\Support\Facades\Storage;
use App\Services\Contracts\ShipmentLabel as ContractShipmentLabel;

class ShipmentLabel extends Controller
{
    protected $shippingServiceFactory;

    public function __construct(ShippingServiceFactory $factory)
    {
        $this->shippingServiceFactory = $factory;
    }

    public function handle(int $shipment_id){

        if (Storage::disk(Shipment::DISK_LABEL_PDF)->exists($shipment_id . '.pdf')) {

            $path = Storage::disk(Shipment::DISK_LABEL_PDF)->path($shipment_id . '.pdf');

            return response()->file($path, [
                'Content-Type' => 'application/pdf',
            ]);

        } else {

            $shipment = Shipment::findOrFail($shipment_id);
            $shippingService = $this->shippingServiceFactory->make($shipment->carrier);

            if ($shippingService instanceof ContractShipmentLabel) {

                $streamFile = $shippingService->shipmentLabel($shipment->id, $shipment->master_tracking_number);

                return $streamFile ?
                        response()->file($streamFile, [
                            'Content-Type' => 'application/pdf',
                            'Content-Disposition'=> 'inline; filename="documento.pdf"'
                        ])
                        : response('Archivo no encontrado, contacta a soporte', 404);

            }else
                return response('Archivo no encontrado, contacta a soporte', 404);
        }
    }
}
