<?php

namespace App\Http\Controllers\CustomerSupport;

use App\Http\Controllers\Controller;
use App\Models\Shipment;
use App\Models\ShippingBox;
use App\Services\Shipments\Addresess;
use App\Services\Shipments\Address;
use App\Services\Shipments\PackagedShipping;
use App\Services\Shipments\ShippingQuote as ShippingQuoteShipment;
use App\Services\ShippingServiceFactory;

class ShippingController extends Controller
{
    private $shippingServiceFactory;

    public function __construct(ShippingServiceFactory $factory)
    {
        $this->shippingServiceFactory = $factory;
    }

    public function handle(int $shipment_id){
        $shipmentDb = Shipment::findOrFail($shipment_id);
        $shipment = $this->parseShipment($shipmentDb);
        $carriers = ShippingServiceFactory::all();
        $carriers = array_filter($carriers, fn($carrier) => $carrier != $shipmentDb->carrier);
        $responses = [];

        $shipment->calculate();

        foreach ($carriers as $carrier) {
            try {
                $shippingService = $this->shippingServiceFactory->make($carrier);
                $data['quoteType'] = $shipmentDb->is_local_shipping == 1 ? 'Local' : 'Nacional';
                $quoteResponse = $shippingService->getQuote($shipment);
                // Convertir $quoteResponse a array si es una instancia de JsonResponse
                if ($quoteResponse instanceof \Illuminate\Http\JsonResponse) {
                    $quoteResponse = $quoteResponse->getData(true);
                }

                $responses[$carrier] = $quoteResponse;
            } catch (\Exception $e) {
                \Log::error("Error al obtener cotización de {$carrier}: " . $e->getMessage());
                $responses[$carrier] = [
                    'error' => $e->getMessage()
                ];
            }
        }

        return response()->json($responses);
    }
    /**
     *
     *
     * @param Shipment $shipmentDb
     * @return ShippingQuoteShipment
     */
    private function parseShipment(Shipment $shipmentDb){
        $addresses = new Addresess([new Address($shipmentDb->location_id, $shipmentDb->origin_postal_code, $shipmentDb->origin_neighborhood)]);
        $shipment = new ShippingQuoteShipment(
                        new Address($shipmentDb->customer_address_id, $shipmentDb->destination_postal_code, $shipmentDb->destination_neighborhood),
                        $addresses,
                        ShippingBox::boxList(),
                        PackagedShipping::byShipment($shipmentDb->id)
                    );


        return $shipment;
    }
}
