<?php

namespace App\Http\Controllers\CustomerSupport;

use App\Http\Controllers\Controller;
use App\Http\Requests\CustomerSupport\UpdateShipment;
use App\Models\Order;
use App\Models\Shipment;
use App\Services\Helpers\Money;
use App\Services\ShippingServiceFactory;
use Illuminate\Support\Facades\Auth;
use App\UseCases\Shipment\UpdateGuide;

class UpdateShipController extends Controller
{
    protected $shippingServiceFactory;

    public function __construct(ShippingServiceFactory $factory)
    {
        $this->shippingServiceFactory = $factory;
    }

    public function handle(UpdateShipment $request, int $shipment_id){

        $shipment = Shipment::findOrFail($shipment_id);

        $handler = new UpdateGuide(
                        Order::findOrFail($shipment->order_id),
                        $shipment,
                        $this->shippingServiceFactory->make($request->input('carrier')),
                        $request->input('carrier'),
                        $request->input('service_code'),
                        Money::convertToDolar($request->input('shipping_cost')),
                        $request->input('reason'),
                        Auth::id()
                    );
        $result = $handler->handle();

        if($result)
            return response()->json([
                'trackingNumber' => $result->getTrackingNumber(),
                'urlPdf' => route('admin.orders.shipment.label', ['shipment_id' => $shipment->id]),
                'message' => __('Instrucción procesada')
            ]);

        abort(500, 'Hubo un error al solicitar la guía');
    }
}
