<?php

namespace App\Http\Controllers\Marketing;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Http\Requests\BannerGroupRequest;
use App\Models\BannerGroup;
use Illuminate\Support\Facades\Storage;

class BannerGroupController extends Controller
{
    public function index()
    {
        $banners = BannerGroup::orderBy('id', 'DESC')->get();
        return view('marketing.banner-group.index', ['banners' => $banners]);
    }

    public function create()
    {
        $totalBanners = BannerGroup::count();

        if($totalBanners >= 3) {
            session()->flash('message', 'No puede haber más de 3 Banners, elimina o actualiza uno');
            session()->flash('icon', 'warning');
            return redirect()->route('admin.banner-group.index');
        } else {
            return view('marketing.banner-group.create');
        }
    }

    public function store(BannerGroupRequest $request)
    {
        $validated = $request->validated();

        // Subir la imagen
        if ($request->hasFile('image')) {
            $validated['image'] = $request->file('image')->store('banner_group', 'public');
        }

        BannerGroup::create($validated);

        session()->flash('message', 'Banner Creado exitosamente');
        session()->flash('icon', 'success');

        // Redireccionar con un mensaje de éxito
        return redirect()->route('admin.banner-group.index');
    }

    public function update(BannerGroupRequest $request, string $id)
    {
        $banner = BannerGroup::findOrFail($id);
        $validated = $request->validated();

        // Si hay una nueva imagen, eliminar la anterior y subir la nueva
        if ($request->hasFile('image')) {
            if ($banner->image) {
                Log::info("storage public");
                Storage::disk('public')->delete($banner->image);
                Log::info("pasa");
            }

            $validated['image'] = $request->file('image')->store('banner_group', 'public');
        } else {
            unset($validated['image']);
        }

        $banner->update($validated);

        session()->flash('message', 'Banner Actualizado exitosamente');
        session()->flash('icon', 'success');

        return response()->json(['success' => true]);
    }

    public function destroy(string $id)
    {
        $banner = BannerGroup::findOrFail($id);

        // Eliminar la imagen del almacenamiento
        if (!empty($banner->image)) {
            Storage::disk('public')->delete($banner->image);
        }

        // Eliminar el banner de la base de datos
        $banner->delete();

        session()->flash('message', 'Banner Eliminado exitosamente');
        session()->flash('icon', 'success');

        // Redireccionar con un mensaje de éxito
        return redirect()->route('admin.banner-group.index')->with('success', 'Banner eliminado exitosamente');
    }
}
