<?php

namespace App\Http\Controllers\Marketing;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Http\Requests\HeroSliderRequest;
use Illuminate\View\View;
use App\Models\HeroSlider;
use Illuminate\Support\Facades\Storage;

class HeroSliderController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index(): View
    {
        $sliders = HeroSlider::orderBy('id', 'DESC')->get();
        // dd($sliders);
        return view('marketing.hero-slider.index', ['sliders' => $sliders]);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create(): View
    {
        return view('marketing.hero-slider.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(HeroSliderRequest $request)
    {
        // Validar los datos
        $validated = $request->validated();

        // Subir la imagen
        if ($request->hasFile('image')) {
            $validated['image'] = $request->file('image')->store('hero_sliders', 'public');
        }

        // Crear el slider
        HeroSlider::create($validated);

        session()->flash('message', 'Slider Creado exitosamente');
        session()->flash('icon', 'success');

        // Redireccionar con un mensaje de éxito
        return redirect()->route('admin.hero-slider.index');
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(HeroSliderRequest $request, $id)
    {
        $slider = HeroSlider::findOrFail($id);
        $validated = $request->validated();

        // Si hay una nueva imagen, eliminar la anterior y subir la nueva
        if ($request->hasFile('image')) {
            // Eliminar la imagen anterior
            if ($slider->image) {
                Storage::disk('public')->delete($slider->image);
            }

            // Subir la nueva imagen
            $validated['image'] = $request->file('image')->store('hero_sliders', 'public');
        } else {
            // Si no hay nueva imagen, no incluir el campo image en la actualización
            unset($validated['image']);
        }

        // Actualizar el slider
        $slider->update($validated);

        session()->flash('message', 'Slider Actualizado exitosamente');
        session()->flash('icon', 'success');

        // Confirmar la actualización
        return response()->json(['success' => true]);
    }




    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $slider = HeroSlider::findOrFail($id);

        // Eliminar la imagen del almacenamiento
        if (!empty($slider->image)) {
            Storage::disk('public')->delete($slider->image);
        }

        // Eliminar el slider de la base de datos
        $slider->delete();

        session()->flash('message', 'Slider Eliminado exitosamente');
        session()->flash('icon', 'success');

        // Redireccionar con un mensaje de éxito
        return redirect()->route('admin.hero-slider.index')->with('success', 'Slider eliminado exitosamente');
    }
}
