<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;

class HeroSliderRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     */
    public function authorize(): bool
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, \Illuminate\Contracts\Validation\ValidationRule|array<mixed>|string>
     */
    public function rules(): array
    {
        $rules = [
            'text_small' => 'required|string|max:255',
            'text_medium' => 'required|string|max:255',
            'text_large' => 'required|string|max:255',
            'button_text' => 'required|string|max:255',
            'button_url' => 'required|string|max:255',
        ];

        if ($this->isMethod('post')) {
            $rules['image'] = 'required|file|image|max:2048';
        } elseif ($this->isMethod('put') || $this->isMethod('patch')) {
            $rules['image'] = 'nullable|file|image|max:2048';
        }

        return $rules;
    }

    public function messages(): array
    {
        return [
            'text_small.required' => 'Por favor escribe el texto correspondiente para el campo Texto 1.',
            'text_small.string' => 'El campo Texto 1 debe contener caracteres válidos.',
            'text_small.max' => 'El campo Texto 1 no debe ser mayor a 255 caracteres.',

            'text_medium.required' => 'Por favor escribe el texto correspondiente para el campo Texto 2.',
            'text_medium.string' => 'El campo Texto 2 debe contener caracteres válidos.',
            'text_medium.max' => 'El campo Texto 2 no debe ser mayor a 255 caracteres.',

            'text_large.required' => 'Por favor escribe el texto correspondiente para el campo Texto 3.',
            'text_large.string' => 'El campo Texto 3 debe contener caracteres válidos.',
            'text_large.max' => 'El campo Texto 3 no debe ser mayor a 255 caracteres.',

            'button_text.required' => 'Por favor escribe el texto correspondiente para el botón.',
            'button_text.string' => 'El texto del botón debe contener caracteres válidos.',
            'button_text.max' => 'El texto del botón no debe ser mayor a 255 caracteres.',

            'button_url.required' => 'Por favor escribe la URL correspondiente para el botón.',
            'button_url.string' => 'La URL del botón debe contener caracteres válidos.',
            'button_url.max' => 'La URL del botón no debe ser mayor a 255 caracteres.',

            'image.required' => 'Por favor sube una imagen.',
            'image.file' => 'El campo debe ser un archivo.',
            'image.image' => 'El archivo debe ser una imagen válida.',
            'image.max' => 'El tamaño de la imagen no debe ser mayor a 2MB.',
        ];
    }
}
