<?php

namespace App\Http\Resources\CustomerSupport;

use App\Helpers\Dates;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Collection;

class Customer extends JsonResource
{
    /**
     *Conjunto de direcciones de los clientes, se filtran para poder permitir direcciones de
     *varios clientes
     *
     * @var Collection
     */
    public static $allAddress;
    /**
     * Transform the resource into an array.
     *
     * @return array<string, mixed>
     */
    public function toArray(Request $request): array
    {
        $alerts = [];

        if(!is_numeric($this->location_id)) $alerts[] = __('alerts.admin-customer-without-location');

        return [
            'id' => $this->id,
            'user_id' => $this->user_id,
            'location_id' => $this->location_id,
            'company_name' => $this->company_name,
            'netsuite_key' => $this->netsuite_key,
            'rfc' => $this->rfc,
            'status' => $this->status,
            'username' => $this->username,
            'statusView' => __('customers.admin-customer-status-' . $this->status),
            'createdFormatted' => Dates::formatForUser($this->created_at),
            'links' => [
                'edit' => route('admin.customers.edit', $this),
                'destroy' => route('admin.customers.destroy', $this)
            ],
            'alerts' => $alerts,
            'address' => self::$allAddress ? self::$allAddress->filter(fn($addres)=> $addres->customer_id == $this->id) : []
        ];
    }
}
