<?php

namespace App\Http\Resources\CustomerSupport;

use App\Helpers\Dates;
use App\Models\Order as ModelsOrder;
use App\Services\Helpers\Money;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;

class Order extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @return array<string, mixed>
     */
    public function toArray(Request $request): array
    {
        return [
            'id' => $this->id,
            'folio' => $this->folio(),
            'company_name' => $this->company_name,
            'status' => $this->status,
            'statusView' => __('order.status-' . $this->status),
            'statusTextColor' => ModelsOrder::statusTextColor($this->status),
            'totalFormatted' => Money::format($this->total),
            'createdFormatted' => Dates::formatForUser($this->created_at),
            'cancellationRequest' => $this->cancellationRequest && $this->canCancellationRequest() ? Dates::formatForUser(new Carbon($this->cancellationRequest)) : null,
            'links' => [
                'edit' => route('admin.orders.edit', ['id' => $this->id])
            ]
        ];
    }
}
