<?php
namespace App\Logging;

use App\Helpers\Dates;
use Monolog\Handler\AbstractProcessingHandler;
use GuzzleHttp\Client;
use Monolog\Level;
use Monolog\LogRecord;

class TeamsHandler extends AbstractProcessingHandler
{
    protected $webhookUrl;

    public function __construct($webhook_url, int|string|Level $level = Level::Debug, bool $bubble = true)
    {
        parent::__construct($level, $bubble);
        $this->webhookUrl = $webhook_url;
    }

    protected function write(LogRecord $record): void
    {
        $this->sendToTeams($record);
    }

    protected function sendToTeams(LogRecord $record): void
    {
        $client = new Client();
        $adaptiveCard = [
            "type" => "AdaptiveCard",
            "attachments" => [
                [
                    "contentType" => "application/vnd.microsoft.card.adaptive",
                    "content" => [
                        '$schema' => "http://adaptivecards.io/schemas/adaptive-card.json",
                        "type" => "AdaptiveCard",
                        "version" => "1.4",
                        "msteams" => [
                            "width" => "Full"
                        ],
                        "body" => [
                            [
                                "type" => "Container",
                                "items" => [
                                    [
                                        "type" => "TextBlock",
                                        "text" => config('app.name'),
                                        "weight" => "Bolder",
                                        "size" => "ExtraLarge",
                                        "fontType" => "Monospace"
                                    ],
                                    [
                                        "type" => "Container",
                                        "items" => [
                                            [
                                                "type" => "TextBlock",
                                                "text" => $record->level->getName(),
                                                "wrap" => true,
                                                "fontType" => "Monospace",
                                                "size" => "Medium"
                                            ]
                                        ]
                                    ],
                                    [
                                        "type" => "ColumnSet",
                                        "columns" => [
                                            [
                                                "type" => "Column",
                                                "width" => "stretch",
                                                "items" => [
                                                    [
                                                        "type" => "TextBlock",
                                                        "text" => Dates::formatForUser(now()),
                                                        "wrap" => true
                                                    ]
                                                ]
                                            ]
                                        ]
                                    ]
                                ]
                            ],
                            [
                                "type" => "CodeBlock",
                                "codeSnippet" => $record->message,
                                "language" => "php",
                                "size" => ""
                            ],
                            [
                                "type" => "TextBlock",
                                "text" => "Contexto",
                                "wrap" => true
                            ],
                            [
                                "type" => "CodeBlock",
                                "codeSnippet" => json_encode($record->context, JSON_PRETTY_PRINT),
                                "language" => "php",
                            ]
                        ]
                    ]
                ]
            ]
        ];
        $response = $client->post($this->webhookUrl, [
            'json' => $adaptiveCard
        ]);

        if ($response->getStatusCode() !== 202) {
            throw new \Exception('Failed to send message to Microsoft Teams: ' . $response->getBody());
        }
    }
}
