<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Database\Eloquent\Model;
use DVDoug\BoxPacker\Rotation;
use Illuminate\Database\Eloquent\Collection;

class OrderItem extends Model
{
    private bool $rotateY = false;
    public int $keepFlat = Rotation::BestFit;

    use HasFactory, SoftDeletes;

    protected $fillable = [
        'order_id',
        'product_id',
        'quantity',
        'price',
        'shipment_id',
        'weight',
        'length',
        'width',
        'height'
    ];

    public function product()
    {
        return $this->belongsTo(Product::class);
    }
    /**
     *Obtener todos los productos que seran enviados
     *
     * @param integer $shipment_id
     * @return Collection
     */
    public static function forShipment(int $shipment_id){
        return self::select(
                'order_items.id',
                'order_items.product_id',
                'products.name',
                'order_items.order_id',
                'order_items.length',
                'order_items.width',
                'order_items.height',
                'order_items.weight',
                'order_items.quantity',
                'order_items.price',
                'products.sat_clave_producto_servicio',
                'products.sat_clave_unidad_peso')
                ->join('products', 'products.id', '=', 'order_items.product_id')
                ->where('order_items.shipment_id', $shipment_id)
                ->get();
    }
    /**
     *Toda la información disponible de un producto
     *
     * @return object
     */
    public static function withProduct(){
        return self::select(
                'order_items.id',
                'order_items.product_id',
                'products.name',
                'products.netsuite_item',
                'order_items.order_id',
                'order_items.shipment_id',
                'order_items.length',
                'order_items.width',
                'order_items.height',
                'order_items.weight',
                'order_items.quantity',
                'order_items.price',
                'products.sat_clave_producto_servicio',
                'products.sat_clave_unidad_peso',
                'products.featured')
                ->join('products', 'products.id', '=', 'order_items.product_id');
    }

}
