<?php

namespace App\Models;

use App\Services\Shipments\Sent\ListPackages;
use App\Services\Shipments\Contracts\PackageSent as ContractPackageSent;
use App\Services\Shipments\Sent\RegularContainer;
use App\Services\Shipments\Sent\SelfContainer;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class PackageSent extends Model
{
    use HasFactory;
    protected $table = 'packages_sent';
    protected $guarded = [];

    /**
     * Guardar todos los paquetes enviados de un envio
     * @param int $shipmentId
     * @param ListPackages $packedBox
     * @return bool
     */
    public static function savePackedBoxWithContentByShipment(ListPackages $listPackagesSent){
        //Guardar el paquete enviado
        DB::beginTransaction();

        $callback = function(ContractPackageSent $packageSent){
            return self::create([
                'shipping_box_id' => $packageSent instanceof RegularContainer ? $packageSent->shipping_box_id : null,
                'shipment_id' => $packageSent->getShipmentId(),
                'total_items' => $packageSent->getTotalItems(),
                'tracking_id' => $packageSent->getTrackingId()
            ]);
        };
        //Guardar el contenido de un paquete envidado
        foreach ($listPackagesSent as $packageSent) {

            $model = $callback($packageSent);
            //Cuando es un embalaje normal se guardan los items dentro de el
            if($packageSent instanceof RegularContainer){
                if(!OrderedItemInPackagesSent::savePackedItems($model->id, $packageSent->items)){
                    DB::rollback();
                    throw new \Exception("Hubo un problema al guardar el lugar los items de la caja", 1);
                }
            }
            //Cuandoun producto es el mismo embalaje se guarda solo el identificador del producto
            if($packageSent instanceof SelfContainer)
                OrderedItemInPackagesSent::create([
                    'packages_sent_id' => $model->id,
                    'order_item_id' => $packageSent->orderItemId,
                    'x' => 0,
                    'y' => 0,
                    'z' => 0,
                    'width' => 0,
                    'length' => 0,
                    'depth' => 0
                ]);

        }
        DB::commit();
    }
}
