<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class ProductStock extends Model
{
    use HasFactory;

    protected $fillable = [
        'product_id',
        'location_id',
        'quantity_available',
        'quantity_on_hand',
        'quantity_on_order',
        'quantity_in_transit',
    ];

    public function product()
    {
        return $this->belongsTo(Product::class);
    }

    public function location()
    {
        return $this->belongsTo(Location::class);
    }
    /**
     * Verificar si hay suficiente stock de un producto
     *
     * @param integer $productId
     * @param integer $quantity
     * @param integer|null|null $locationId
     * @return boolean
     */
    public static function hasEnough(int $productId, int $quantity, int|null $locationId = null){
        $query = Product::queryExistsStock();
        $result = $query->where('products.id', $productId)
                    ->when(isset($locationId), function($where) use ($locationId){
                        $where->where('product_stocks.location_id', $locationId);
                    })
                    ->where('product_stocks.quantity_available', '>=' , $quantity)
                    ->first();

        return isset($result);

    }
}
