<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use App\Services\Shipments\Contracts\Box;
use DVDoug\BoxPacker\BoxList;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Support\Collection;

class ShippingBox extends Model implements Box
{
    use HasFactory, SoftDeletes;
    protected $guarded = [];
    protected $table = 'shipping_boxes';
    /**
     * ID
     *
     * @return integer
     */
    public function identification(): int
    {
        return $this->id;
    }
    /**
     * Reference for box type (e.g. SKU or description).
     */
    public function getReference(): string{
        return $this->name;
    }

    /**
     * Outer width in mm.
     */
    public function getOuterWidth(): int{
        return $this->outer_width;
    }

    /**
     * Outer length in mm.
     */
    public function getOuterLength(): int{
        return $this->outer_length;
    }

    /**
     * Outer depth in mm.
     */
    public function getOuterDepth(): int{
        return $this->outer_height;
    }

    /**
     * Empty weight in g.
     */
    public function getEmptyWeight(): int{
        return $this->weight;
    }

    /**
     * Inner width in mm.
     */
    public function getInnerWidth(): int{
        return $this->inner_width;
    }

    /**
     * Inner length in mm.
     */
    public function getInnerLength(): int{
        return $this->inner_length;
    }

    /**
     * Inner depth in mm.
     */
    public function getInnerDepth(): int{
        return $this->inner_height;
    }

    /**
     * Max weight the packaging can hold in g.
     */
    public function getMaxWeight(): int{
        return $this->max_weight;
    }
    /**
     *
     *
     * @return Collection
     */
    public static function boxList(){
        //Es importante el ordenamiento, ayudara al algoritmo de empaquetado
        return self::orderBy('inner_length', 'DESC')
                ->orderBy('inner_width', 'DESC')
                ->orderBy('inner_height', 'DESC')
                ->orderBy('max_weight', 'DESC')
                ->orderBy('weight', 'DESC')
                ->get();
    }
}
