<?php

namespace App\Providers;

use App\Models\Category;
use App\Models\User;
use Illuminate\Support\ServiceProvider;
use Illuminate\Pagination\Paginator;
use Illuminate\Support\Facades\Schema;
use Illuminate\Support\Facades\View;
use App\View\Composers\CategoriesComposer;
use App\View\Composers\BrandsComposer;
use Carbon\Carbon;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\DB;

class AppServiceProvider extends ServiceProvider
{
    /**
     * Register any application services.
     */
    public function register(): void
    {
        //
    }

    /**
     * Bootstrap any application services.
     */
    public function boot(): void
    {
        Schema::defaultStringLength(191);
        Paginator::useBootstrapFive();
        View::composer('*', BrandsComposer::class);

        // Obtiene el tipo de cambio actual:
        View::share('categories', Category::all());
        View::share('exchangeRate', \App\Models\ExchangeRate::where('currency_pair', 'USD/MXN')->orderBy('updated_at', 'desc')->first());
        if(config('app.debug')) $this->debugQuery();
    }
    /**
     * Funcion para depurar todas las conslutas en la BD
     *
     * @return void
     */
    private function debugQuery(){
        DB::listen(function($query) {
            File::append(
                storage_path('/logs/query.log'),
                $query->sql . ' [' . implode(', ', $query->bindings) . ']' . PHP_EOL
            );
        });
    }

}
