<?php

namespace App\Services\Cart;

use App\Models\AdditionalCharge;
use App\Models\AdditionalChargeApplied;
use Illuminate\Support\Collection;
use Darryldecode\Cart\CartCondition as DarryldecodeCartCondition;

class CartCondition{

    private array $general = [];

    public function __construct(public readonly Collection $additionalCharges)
    {

    }
    public function handle(){
        foreach ($this->additionalCharges as $additionalCharge) {

            switch ($additionalCharge->entity_type) {
                case 'all':
                    $this->addGeneral($additionalCharge);
                    break;

                default:
                    break;
            }
        }

        \Cart::clearCartConditions();
        $this->chargeGeneral();

        return true;
    }
    public static function getIdsOfConditionals(){
        $cartConditions = \Cart::getConditions();
        $ids = [];

        foreach($cartConditions as $condition)
        {
            $attributes = $condition->getAttributes();
            if(key_exists('charge_entity_id', $attributes)) $ids[] = $attributes['charge_entity_id'];
        }

        return $ids;
    }
    /**
     * Guardar las condiciones que fueron aplicadas a una orden
     *
     * @param integer $orderId
     * @return void
     */
    public static function saveConditionsByOrder(int $orderId){
        $insert = array_map(function($chargeId) use($orderId){
            return [
                'order_id' => $orderId,
                'charge_entity_id' => $chargeId,
                'created_at' => now(),
                'updated_at' => now()
            ];
        }, self::getIdsOfConditionals());

        AdditionalChargeApplied::insert($insert);
    }
    private function chargeGeneral(){
        \Cart::condition($this->general);
    }
    /**
     * Crear costos adicionales generales para posteriormente ser aplicados
     * Ver https://github.com/darryldecode/laravelshoppingcart?tab=readme-ov-file#usage-usage-example
     *
     * @param AdditionalCharge $additionalCharge
     * @return void
     */
    private function addGeneral(AdditionalCharge $additionalCharge){
        $this->general[] = new DarryldecodeCartCondition([
            'name' => $additionalCharge->description,
            'type' => 'shipping',
            'target' => 'subtotal',
            'value' => $additionalCharge->charge_type == 'fixed' ? "+$additionalCharge->amount" : "%$additionalCharge->amount",
            'order' => 1,
            'attributes' => [
                'charge_entity_id' => $additionalCharge->charge_entity_id
            ]
        ]);
    }
}
