<?php

namespace App\Services\Cart;

use App\Services\ShippingServiceFactory;

/**
 * Esta clase determina que cargos y descuentos (aun no existen esto pero se deberan implementar), se deben aplicar,
 * esto lo hace en base a las caracteristicas del pedido
 */
class Rules{

    private $carrierLocal;
    private $carrierNational;

    public function __construct()
    {

    }
    public function setCarrierLocal(string|null $carrierLocal){
        $this->carrierLocal = $carrierLocal;
        return $this;
    }
    public function setCarrierNational(string|null $carrierNational){
        $this->carrierNational = $carrierNational;
        return $this;
    }
    /**
     * Aplica cargos y descuentos en base a la orden.
     *
     * 1. Si ambos carriers están definidos y no son el cliente, se aplica un cargo doble.
     * 2. Si solo un carrier está definido y no es el cliente, se aplica un cargo simple.
     *
     * @return array Lista de reglas a aplicar.
     */
    public function get(): array{
        $rules = [];
        $bothCarriersSet = $this->carrierLocal && $this->carrierNational;

        if($bothCarriersSet && $this->carrierLocal !== ShippingServiceFactory::CUSTOMER_CARRIER
            && $this->carrierNational !== ShippingServiceFactory::CUSTOMER_CARRIER){
            $rules[] = 'shipping_insurance_x2';
        }else{

            if(($this->carrierLocal && $this->carrierLocal !== ShippingServiceFactory::CUSTOMER_CARRIER)
                || ($this->carrierNational && $this->carrierNational !== ShippingServiceFactory::CUSTOMER_CARRIER))
                $rules[] = 'shipping_insurance';
        }

        return $rules;
    }
}
