<?php

namespace App\Services\Contracts;

use App\Services\Contracts\Shipment as ContractsShipment;
use App\Services\Shipments\ShippingQuote;

interface ShippingServiceInterface
{
    /**
     * Cotizar un envio
     *
     * @param ShippingQuote $data
     * @return array
     */
    public function getQuote(ShippingQuote $data);
    /**
     * Solicitar una guia
     *
     * @param integer $shipmentId
     * @return ContractsShipment
     */
    public function shipping(int $shipmentId) : ContractsShipment;
    /**
     * Rastrear un envio
     *
     * @param string $trackingId
     * @return Tracking
     */
    public function tracking(string $trackingId): Tracking;
    /**
     * Cancelar un envio, solo si no ha sido enviado
     *
     * @param integer $trackingId
     * @return CancelShipment
     */
    public function cancel($trackingId): CancelShipment;
    /**
     * Verificar si un envio puede ser cancelado
     *
     * @param integer $deliveryStatus Estatus actual del envio, debe haber sido obtenido recientemente de la api
     * @return boolean
     */
    public function canCancel($deliveryStatus): bool;
    /**
     * Verificar si un envio esta cancelado
     *
     * @param integer $deliveryStatus Estatus actual del envio, debe haber sido obtenido recientemente de la api
     * @return boolean
     */
    public function isCanceled($deliveryStatus): bool;
}
