<?php
namespace App\Services\Estafeta\Objects\Quote;

use App\Services\Estafeta\Packaging\Box;
use App\Services\Estafeta\Packaging\Pallet;
use App\Services\Estafeta\Packaging\DoublePallet;

class PackagingType{

    public const SOBRE = 'Sobre';
    public const PAQUETE = 'Paquete';
    public const PALLET = 'Pallet';

    /**
     * En el mismo constructor verificamos que el codigo que se haya proporcionado sea valido, para saberlo usamos las
     * propiedades estaticas de la misma clase
     *
     * @param integer $value
     */
    public function __construct(public readonly string $value)
    {
        $reflection = new \ReflectionClass(__CLASS__);
        $const = $reflection->getConstants();

        if(in_array($value, $const)) return;

        throw new \Exception("El tipo no es válido, consulta la documentacion", 1);
    }
    /**
     *
     *
     * @param float $weight Kg
     * @param float $length cm
     * @param float $width cm
     * @param float $depth cm
     * @return PackagingType
     */
    public static function equivalent(float $weight, float $length, float $width, float $depth): PackagingType{

        if (self::matches($weight, $length, $width, $depth, Box::class)) {
            return new self(self::PAQUETE);
        }

        if (self::matches($weight, $length, $width, $depth, Pallet::class)) {
            return new self(self::PALLET);
        }

        if (self::matches($weight, $length, $width, $depth, DoublePallet::class)) {
            return new self(self::PALLET);
        }

        throw new \Exception("El tipo de embalaje no encuentra un equivalente con la paqueteria,
                    DIMENSIONES: weight: $weight length: $length width: $width depth: $depth", 1);

    }
    private static function matches(float $weight, float $length, float $width, float $depth, $type): bool {
        return $depth <= $type::HEIGHT && $length <= $type::LENGTH
               && $weight <= $type::WEIGHT && $width <= $type::WIDTH;
    }
}
