<?php
namespace App\Services\Estafeta\Objects\Shipment;
use App\Services\Estafeta\Packaging\Box;
use App\Services\Estafeta\Packaging\Pallet;
use App\Services\Estafeta\Packaging\DoublePallet;

class ItemDescription{


    public const PARCEl_ID_SOBRE = 1;
    public const PARCEl_ID_PAQUETE = 4;
    public const PARCEl_ID_PALET = 5;
    private int $parcelId;
    /**
     * https://disenoweb.estafeta.com/ELRest/ES/WSEL_REST_ES.pdf
     *
     * @param float $weight Peso del envío
     *- RegExp \d{1,4}.\d{1,2}
     *- Mínimo: 71.00
     *- Máximo: 1100.00
     * @param integer $height Alto del envío (Obligatorio sólo para Pallet)
     * Max Height for Package 190 cms
     * @param integer $length Largo del envío (Obligatorio sólo para Pallet)
     * Max Length for Package 240 cms
     * @param integer $width Ancho del envío (Obligatorio sólo para Pallet)
     * Max Width for Package 120 cms
     * @param Merchandises $merchandises
     */
    public function __construct(
        public readonly float $weight,
        public readonly int $height,
        public readonly int $length,
        public readonly int $width,
        public readonly Merchandises $merchandises)
    {
        $this->parcelId($weight, $length, $width, $height);
    }
    public function array(){
        return [
            'parcelId' => $this->parcelId,
            'weight' => $this->weight,
            'height' => $this->height,
            'length' => $this->length,
            'width' => $this->width,
            'merchandises' => $this->merchandises->array()
        ];
    }

    /**
     *
     *
     * @param float $weight Kg
     * @param float $length cm
     * @param float $width cm
     * @param float $depth cm
     * @return PackagingType
     */
    private function parcelId(float $weight, float $length, float $width, float $depth){

        if($depth <= Box::HEIGHT && $length <= Box::LENGTH
            && $weight <= Box::WEIGHT && $width <= Box::WIDTH){
                $this->parcelId = self::PARCEl_ID_PAQUETE;
        }elseif($depth <= Pallet::HEIGHT && $length <= Pallet::LENGTH
            && $weight <= Pallet::WEIGHT && $width <= Pallet::WIDTH){
                $this->parcelId = self::PARCEl_ID_PALET;
        }elseif($depth <= DoublePallet::HEIGHT && $length <= DoublePallet::LENGTH
            && $weight <= DoublePallet::WEIGHT && $width <= DoublePallet::WIDTH){
                $this->parcelId = self::PARCEl_ID_PALET;
        }else
            throw new \Exception('El tipo de embalaje no encuentra un equivalente con la paqueteria', 1);

    }
}
