<?php
namespace App\Services\Estafeta\Objects\Shipment;

class Merchandise{

    /**
    *
    *
    * @param string $productServiceCode Clave de producto de los bienes o mercancías que se trasladan en los distintos medios de transporte.
        * Se debe proporcionar conforme con el catálogo catCartaPorte:c_ClaveProdServCP
        * publicado en el portal del SAT en Internet (Numérico, max: Length 18 )
    * @param float $merchandiseQuantity Cantidad de los bienes o mercancías que se trasladan en los distintos medios de transporte.
        * 6 enteros y 6 decimales.
    * @param float $measurementUnitCode Clave de unidad de medida estandarizada aplicable para la cantidad de los bienes o mercancías que se trasladan en los
        *distintos medios de transporte. La unidad debe corresponder con la descripción de los bienes o mercancías registrados
        *ver http://pys.sat.gob.mx/PyS/catUnidades.aspx
    * @param boolean $isInternational Atributo requerido para expresar si los bienes o mercancías que son transportadas ingresan o salen del territorio nacional.
        * TRUE ó FALSE
    * @param string $currency Clave de la moneda utilizada para expresar el valor de los bienes o mercancías que se trasladan en los distintos medios de
        *transporte, cuando se usa moneda nacional se registra MXN, conforme con la especificación ISO 4217
    */
    public function __construct(
        public readonly string $productServiceCode,
        public readonly float $merchandiseQuantity,
        public readonly string $measurementUnitCode,
        public readonly bool $isInternational,
        public readonly string $currency = 'MXN'
    )
    {

    }
    public function array(){
        return [
            'productServiceCode' => $this->productServiceCode,
            'currency' => $this->currency,
            'merchandiseQuantity' => sprintf("%.4f", $this->merchandiseQuantity),
            'measurementUnitCode' => $this->measurementUnitCode,
            'isInternational' => $this->isInternational,
        ];
    }
}

