<?php

namespace App\Services\Estafeta\Objects\Shipment;

use App\Services\Estafeta\Exceptions\Estafeta;
use App\Services\Shipments\Packaging;
use App\Services\Estafeta\Packaging\Box;
use App\Services\Estafeta\Packaging\Pallet as PalletConstant;
use App\Services\Estafeta\Packaging\DoublePallet;
/**
 * Ver https://disenoweb.estafeta.com/ELRest/ES/WSEL_REST_ES.pdf
 */
class Pallet{
    public const SIMPLE = 'SIMPLE';
    public const DOUBLE = 'DOUBLE';
    public const NATIONAL_ORIGIN = 'NATIONAL';
    public const IMPORTED_ORIGIN = 'IMPORTED';
    /**
     *
     *
     * @param string $merchandise ENUM: NATIONAL ó IMPORTED Origen de Pallet nacional o de importación. Obligatorio en que se solicite servicio LTL
     * @param string $genericContent Contenido en general que lleva el pallet Max length: 100
     * @param string $type  Tipo de Pallet ENUM: 1 o 2
     * 1: SIMPLE
     * 2: DOUBLE
     */
    public function __construct(
        public readonly string $merchandise,
        public readonly string $genericContent,
        public readonly string $type)
    {

    }
    public function array(){
        return [
            'merchandise' => $this->merchandise,
            'genericContent' => $this->genericContent,
            'type' => $this->type
        ];
    }
    /**
     * Devolveremos una instancia de Pallet solo si el empaquetado requiere un embalaje de ese tipo
     * caso contrario un NULL
     *
     * @param float $weight Kg
     * @param float $length cm
     * @param float $width cm
     * @param float $depth cm
     * @return null|Pallet
     */
    public static function fromDimensions(float $weight, float $length, float $width, float $depth): null|Pallet {

        if($depth <= Box::HEIGHT && $length <= Box::LENGTH
            && $weight <= Box::WEIGHT && $width <= Box::WIDTH)
            return null;

        if($depth <= PalletConstant::HEIGHT && $length <= PalletConstant::LENGTH
            && $weight <= PalletConstant::WEIGHT && $width <= PalletConstant::WIDTH)
            return new self(self::NATIONAL_ORIGIN, 'Multiples productos', self::SIMPLE);

        if($depth <= DoublePallet::HEIGHT && $length <= DoublePallet::LENGTH
            && $weight <= DoublePallet::WEIGHT && $width <= DoublePallet::WIDTH)
            return new self(self::NATIONAL_ORIGIN, 'Multiples productos', self::DOUBLE);

        throw new Estafeta('El tipo de embalaje no encuentra un equivalente con la paqueteria', 1);
    }
}
