<?php

namespace App\Services\Estafeta\Response;

use App\Services\Contracts\Shipment as ContractsShipment;
use App\Services\Estafeta\Exceptions\Estafeta;
use App\Services\Shipments\Exceptions\ContainerInvalid;
use App\Services\Shipments\Sent\ListPackages;
use App\Services\Shipments\PerSend\ListPackaging;
use App\Services\Shipments\PerSend\RegularContainer as PerSendRegularContainer;
use App\Services\Shipments\PerSend\SelfContainer as PerSendSelfContainer;
use App\Services\Shipments\Sent\RegularContainer;
use App\Services\Shipments\Sent\SelfContainer;

class ShipmentMultiple implements ContractsShipment{


    public function __construct(
        public readonly object $response,
        public readonly ListPackaging $listPackaging,
        private readonly int $shipmentId){

    }
    public function getTrackingNumber(): string{
        /**
         * No usamos el numero de rastreo si no la guia, esto debido a que el webhook
         * nos notifica mediante este valor, ademas tomamos el primero elemento como la guía madre,
         * segun las comunicaciones con Estafeta la primer guía es la guia madre
         */
        return $this->response->labelPetitionResults[0]->elements[0]->wayBill;
    }
    public function getJSONResponse() : string{
        return json_encode($this->response);
    }
    public function getTotalAmount(): ?float{
        return null;
    }
    public function getCurrency(): ?string{
        return null;
    }
    public function getPdfEncoded(){
        return $this->response->data;
    }
    public function getListPackagesSent(): ListPackages
    {
        $listPackagedSent = new ListPackages;
        $allPackages = $this->listPackaging->packages();

        foreach ($allPackages as $referenceNumber => $package) {

            $elementPetition = $this->findElementPetitionByReference($referenceNumber);

            if($package instanceof PerSendSelfContainer){
                $listPackagedSent->add(
                    new SelfContainer(
                        $this->shipmentId,
                        count($package->getItems()),
                        $elementPetition->elements[0]->wayBill,
                        $package->getOrderItemId()
                    )
                );
            }elseif($package instanceof PerSendRegularContainer){
                $listPackagedSent->add(
                    new RegularContainer(
                        $this->shipmentId,
                        count($package->getItems()),
                        $elementPetition->elements[0]->wayBill,
                        $package->packedBox->getItems(),
                        $package->shippingBox->id
                    )
                );
            }else
                throw new ContainerInvalid("El paquete no pertenece a una instancia valida " . get_class($package), 1);

        }
        return $listPackagedSent;
    }
    private function findElementPetitionByReference(string $referenceNumber){

        foreach ($this->response->labelPetitionResults as $elementPetition) {
            if($referenceNumber == $elementPetition->referenceNumber) return $elementPetition;
        }

        throw new Estafeta("El número de referencia es inválido $referenceNumber" .
                "Respuesta: " . json_encode($this->response), 1);
    }
}
