<?php
namespace App\Services\Estafeta\Response;

use App\Services\Contracts\Tracking as ContractsTracking;

class Tracking implements ContractsTracking{

    private $lastStatus;
    private $error;
    private $item;
    /**
     * Cargar la respuesta de Estafeta, hay dos posibles opciones, que exista un historial o que no, si no hay historial buscamos un codigo de error
     *
     * @param object $response
     */
    public function __construct(public readonly object $response)
    {
        $this->item = $response->items[0] ?? null;
        $statuses = $this->item->status ?? [];

        if (count($statuses) > 0) {
            $this->lastStatus = $statuses[0];
        } else {
            $this->error = $this->item->error ?? null;
        }
    }
    public function getCode(): string
    {
        return $this->lastStatus ? $this->lastStatus->code : $this->error->code;
    }
    public function getDescription(): string
    {
        return $this->lastStatus ? $this->lastStatus->spanishName : __('estafeta.tracking-error-' . $this->error->code);
    }
    public function getDelay(): ?string{
        return null;
    }
    public function getDateTime(): ?string{
        return $this->lastStatus ? $this->lastStatus->eventDateTime : null;
    }
    public function getPromiseDeliveryDateTime(): ?string{
        return null;
    }
    public function getAdditionalInfo(): ?string{

        $rowPickupDetails = $this->pickupDetails();
        $rowDeliveryDetails = $this->deliveryDetails();

        if (strlen($rowPickupDetails) > 0 || strlen($rowDeliveryDetails) > 0) {

            return view('components.tracking.additional-info', [
                'pickupDetails' => $rowPickupDetails,
                'deliveryDetails' => $rowDeliveryDetails
            ])->render();
        }

        return null;
    }
    public function getHistorical(): ?string{
        return null;
    }
    private function pickupDetails(): string{
        if(isset($this->item->pickupDetails)
            && isset($this->item->pickupDetails->warehouseName, $this->item->pickupDetails->pickupDateTime)){
                return view('components.tracking.tr', [
                        'hour' => $this->item->pickupDetails->pickupDateTime,
                        'description' => 'Recolectado',
                        'location' => $this->item->pickupDetails->warehouseName])
                        ->render();
        }
        return '';
    }
    private function deliveryDetails(): string{
        if(isset($this->item->deliveryDetails)
            && isset($this->item->deliveryDetails->receiverName)){
                return view('components.tracking.tr', [
                        'hour' => '',
                        'description' => 'Recibió: ' . $this->item->deliveryDetails->receiverName])
                        ->render();
        }
        return '';
    }
}
