<?php

namespace App\Services\Estafeta;

use App\Services\Contracts\Shipment;
use GuzzleHttp\Client;
use App\Services\Contracts\ShippingServiceInterface;
use App\Services\Contracts\Tracking;
use App\Services\Estafeta\Quote;
use App\Services\Estafeta\Response\Cancel;
use App\Services\Estafeta\Shipment as EstafetaShipment;
use App\Services\Estafeta\Tracking as EstafetaTracking;
use App\Services\Shipments\ShippingQuote as ShippingQuote;
use App\Services\Estafeta\Objects\Quote\Config as QuoteConfig;
use App\Services\Estafeta\Request\Auth;
use App\Services\Estafeta\Objects\Shipment\Config as ShipmentConfig;
use App\Services\Estafeta\Objects\Tracking\Config as TrackingConfig;

class Service implements ShippingServiceInterface
{

    public function __construct()
    {
    }
    public function getQuote(ShippingQuote $shipment)
    {
        $quote = new Quote(
            new Client,
            new QuoteConfig(
                new Auth(
                    config('estafeta.type'),
                    config('estafeta.cotizador.client_id'),
                    config('estafeta.cotizador.client_secret'),
                    config('estafeta.scope'),
                    config('estafeta.cotizador.token_url')
                )
            )
        );
        return $quote->handle($shipment);
    }
    public function shipping(int $shipmentId): Shipment
    {
        $requestShipment = new EstafetaShipment(
            new Client(),
            new ShipmentConfig(
                new Auth(
                    config('estafeta.type'),
                    config('estafeta.label_rest.client_id'),
                    config('estafeta.label_rest.client_secret'),
                    config('estafeta.scope'),
                    config('estafeta.label_rest.token_url')
                )
            )
        );
        return $requestShipment->handle($shipmentId);
    }
    public function tracking(string $trackingId): Tracking
    {
        $request = new EstafetaTracking(
            new Client(),
            new TrackingConfig(
                config('estafeta.tracking.url'),
                new Auth(
                    config('estafeta.type'),
                    config('estafeta.tracking.client_id'),
                    config('estafeta.tracking.client_secret'),
                    config('estafeta.scope'),
                    config('estafeta.tracking.token_url')
                )
            )
        );
        return $request->handle($trackingId);
    }
    /**
     * Estafeta no posee un metodo de cancelacion como tal, solo basta que la guia no sea usada
     *
     * @param mixed $trackingId
     * @return Cancel
     */
    public function cancel($trackingId): Cancel
    {
        return new Cancel();
    }
    public function canCancel($deliveryStatus): bool
    {
        return match ($deliveryStatus) {
            '1005' => true,
            default => false,
        };
    }
    public function isCanceled($deliveryStatus): bool
    {
        return match ($deliveryStatus) {
            'OCA' => true, //Orden Cancelada: Estafeta como tal no tiene un codigo de cancelacion, basta con que la guia no se use
            default => false,
        } ;
    }
}
