<?php

namespace App\Services\Estafeta;

use App\Services\Estafeta\Exceptions\Estafeta;
use App\Services\Estafeta\Objects\Tracking\Config;
use App\Services\Estafeta\Response\Tracking as ResponseTracking;
use GuzzleHttp\Client;
use App\UseCases\Api\HttpRequestExceptionHandler;
use GuzzleHttp\Exception\ClientException;
use Illuminate\Support\Facades\Log;

class Tracking extends HttpRequestExceptionHandler{

    private const MAX_INTENTS = 2;
    private  int $intents = 0;

    public function __construct(
        private readonly Client $client,
        private readonly Config $config)
    {

    }
    /**
     *
     *
     * @param string $trackingId
     * @return ResponseTracking
     */
    public function handle(string $trackingId){

        $token = Factory::token($this->config->auth);
        $data = Factory::tracking($trackingId);

        $response = $this->sendRequest($data, $token);

        $bodyResult = $this->decodeResponse($response);

        return $this->processResponse($bodyResult);
    }
    private function sendRequest(\App\Services\Estafeta\Request\Tracking $data, $token){

        try {

            $response = $this->client->post($this->config->url, [
                'headers' => [
                    'Authorization' => 'Bearer ' . $token,
                    'apiKey' => $this->config->auth->client_id
                ],
                'json' => $data->array()
            ]);

            if($response->getStatusCode() == \Symfony\Component\HttpFoundation\Response::HTTP_OK) return $response;

            throw new Estafeta('Imposible el conectarse a la paqueteria: ' . json_encode($response), 1);
        } catch (ClientException $e) {
            if ($e->getCode() === 401) {
                if($this->intents < self::MAX_INTENTS)
                    return $this->reintentAuthAndRequest($data);
            }

            $this->handleHttpRequestException($e, 'Tracking', Estafeta::class, $data->array());

        } catch (\Throwable $e) {
            $this->handleHttpRequestException($e, 'Tracking', Estafeta::class, $data->array());
        }
    }
    private function decodeResponse(\Psr\Http\Message\ResponseInterface $response): object {
        $bodyResult = json_decode($response->getBody());

        if (json_last_error() !== JSON_ERROR_NONE) {
            throw new Estafeta('Error al decodificar la respuesta JSON');
        }

        return $bodyResult;
    }
    private function processResponse(object $bodyResult){
        if($bodyResult->result->success && count($bodyResult->items) > 0) {

            return new ResponseTracking($bodyResult);
        }

        throw new Estafeta("Hubo un error al procesar la solicitud", 1);
    }
    private function reintentAuthAndRequest(\App\Services\Estafeta\Request\Tracking $data){
        $this->intents++;
        Log::info("Estafeta: Reintentando autenticacion, intentos ($this->intents)");
        $this->sendRequest($data, Factory::token($this->config->auth, true));
    }
}
