<?php

namespace App\Services\Estafeta;

use App\Models\Shipment;
use App\Services\Estafeta\Objects\Webhook\Code;
use App\Services\Estafeta\Response\Webhook as ResponseWebhook;
use Illuminate\Support\Collection;

class Webhook{

    private array $processedWaybills = [];

    public function __construct(private array $inputItems)
    {

    }
    /**
     *
     *
     * @return ResponseWebhook
     */
    public function handle()
    {
        $waybills = array_column($this->inputItems, 'Code');
        // Obtiene los envíos en un solo query usando un índice de master_tracking_number
        $shipments = Shipment::whereIn('master_tracking_number', $waybills)
            ->where('carrier', 'estafeta')
            ->get()
            ->keyBy('master_tracking_number');

        $output = new ResponseWebhook(Code::EXITOSO, Code::EXITOSO->label());

        foreach ($this->inputItems as $item) {
            $this->processItem($item, $output, $shipments);
        }

        return $output;
    }
    private function processItem(array $item, ResponseWebhook $output, Collection $shipments): void{

        $trackingNumber = $item['Code'];
        $shipment = $shipments->get($trackingNumber);

        if ($shipment) {
            $this->updateShipment($shipment, $item);
            $this->addToOutput($output, Code::EXITOSO, $trackingNumber);
        } else {
            $this->addToOutput($output, Code::FALLO, $trackingNumber);
            $output->Code = Code::FALLO;
            $output->CodeDescription = Code::FALLO->label();
        }
    }
    private function updateShipment(Shipment $shipment, array $item): void
    {
        $shipment->estimated_delivery_date = $item['EstimatedDeliveryDate'];
        $shipment->delivery_status = $item['Status']['EventCode'];
        $shipment->delivery_event = $item['Status']['Name'];
        $shipment->save();
    }

    private function addToOutput(ResponseWebhook $output, Code $code, string $trackingNumber): void
    {
        if (!in_array($trackingNumber, $this->processedWaybills)) {
            $this->processedWaybills[] = $trackingNumber;
            $output->addItem($code, $code->label(), $trackingNumber);
        }
    }
}
