<?php
namespace App\Services\Fedex;

use App\Services\Fedex\Exceptions\Fedex;
use App\Services\Fedex\Helpers\Request;
use App\Services\Fedex\Response\Cancel as ResponseCancel;
use GuzzleHttp\Client;
use App\UseCases\Api\HttpRequestExceptionHandler;

class Cancel extends HttpRequestExceptionHandler{

    use Request;
    private const API_URL = '/ship/v1/shipments/cancel';

    public function __construct(private readonly Client $client)
    {

    }
    public function handle($trackingNumber){

        $response = $this->sendRequest($trackingNumber);

        $bodyResult = $this->decodeResponse($response);

        return new ResponseCancel($bodyResult);

    }
    private function sendRequest($trackingNumber){

        $headers = Factory::credentials();
        $request = Factory::cancel($trackingNumber);

        try {

            $response = $this->client->put(self::API_URL, [
                'headers' =>[
                    'Authorization' => 'Bearer ' . $headers->authorization,
                    'X-locale' => $headers->xLocale,
                    'Content-Type' => $headers->contentType
                ],
                'json' => $request->array()
            ]);

            if($response->getStatusCode() === 200) return $response;

            throw new Fedex('La respuesta de la paqueteria es inconsistente ' . json_encode($response), 1);

        } catch (\Throwable $e) {
            $this->handleHttpRequestException($e, 'Cancel', Fedex::class, $request->array());
        }
    }
    private function decodeResponse(\Psr\Http\Message\ResponseInterface $response): object{
        $bodyResult = json_decode($response->getBody());

        if (json_last_error() !== JSON_ERROR_NONE) {
            throw new Fedex('Error al decodificar la respuesta JSON');
        }

        return $bodyResult;
    }
}
