<?php
namespace App\Services\Fedex\Objects;

use App\Services\Fedex\Objects\SubPackagingType;

/**
 * https://developer.fedex.com/api/es-mx/catalog/rate/v1/docs.html
 */
class PackageLineItem{

    /**
     *
     *
     * @param float $weight These are the package weight details.
     * @param SubPackagingType $subPackagingType
     * @param Dimensions $dimensions
     * @param string $units_weight Indicate the weight unit type. The package and commodity weight unit should be the same else the request will result in an error.
     */
    public function __construct(
        public readonly float $weight,
        public readonly SubPackagingType $subPackagingType,
        public readonly Dimensions $dimensions,
        public readonly string $itemDescriptionForClearance,
        public readonly int|null $groupPackageCount = null,
        public readonly string $units_weight = 'KG')
    {

    }
    public function array(){
        $data = [
            'weight' => [
                'units' => $this->units_weight,
                'value' => $this->weight
            ],
            'dimensions' => $this->dimensions->array(),
            'subPackagingType' => $this->subPackagingType->value,
            'itemDescriptionForClearance' => $this->itemDescriptionForClearance
        ];

        if(is_numeric($this->groupPackageCount)) $data['groupPackageCount'] = $this->groupPackageCount;

        return $data;
    }
}
