<?php
namespace App\Services\Fedex\Objects;

/**
 * https://developer.fedex.com/api/es-mx/guides/api-reference.html#pickuptypes
 */
class PickupType{

    /**
     * Indica que se comunicará con FedEx para solicitar una recolección.
     *
     * @var string
     */
    public const CONTACT_FEDEX_TO_SCHEDULE = 'CONTACT_FEDEX_TO_SCHEDULE';
    /**
     * Indica que el envío se entregará en una oficina de FedEx.
     *
     * @var string
     */
    public const DROPOFF_AT_FEDEX_LOCATION = 'DROPOFF_AT_FEDEX_LOCATION';
    /**
     * Indica que el envío se recogerá como parte de una recolección regular programada.
     *
     * @var string
     */
    public const USE_SCHEDULED_PICKUP = 'USE_SCHEDULED_PICKUP';
    /**
     * Indica que la recolección se programará llamando a FedEx.
     *
     * @var string
     */
    public const ON_CALL = 'ON_CALL';
    /**
     * Indica que la recolección será realizada por el Programa de devolución de paquetes de FedEx Ground.
     *
     * @var string
     */
    public const PACKAGE_RETURN_PROGRAM = 'PACKAGE_RETURN_PROGRAM';
    /**
     * Indica que la recolección será en el horario regular de recolección.
     *
     * @var string
     */
    public const REGULAR_STOP = 'REGULAR_STOP';
    /**
     * Indica la información de recolección específica para una solicitud de recolección con una etiqueta de Express
     * o etiqueta de llamada de Ground.
     * Solo se aplica al punto final de «Crear etiqueta» de la API de Envíos (etiqueta de envío de devolución).
     *
     * @var string
     */
    public const TAG = 'TAG';

    public function __construct(public readonly string $value)
    {
        $reflection = new \ReflectionClass(__CLASS__);
        $const = $reflection->getConstants();

        if(in_array($value, $const)) return;

        throw new \Exception("El tipo no es válido, consuulta la documentacion", 1);
    }
}
