<?php
namespace App\Services\Fedex\Objects;
/**
 * These are one or more package-attribute descriptions, each of which describes an individual package, a group of identical packages,
 * or (for the total-piece-total-weight case) common characteristics of all packages in the shipment.
 * -At least one instance containing the weight for at least one package is required for EXPRESS and GROUND shipments.
 * -Single piece requests will have one RequestedPackageLineItem.
 * -Multiple piece requests will have multiple RequestedPackageLineItems.
 * -Maximum occurrences is 30.
 * https://developer.fedex.com/api/es-mx/catalog/rate/v1/docs.html
 * https://developer.fedex.com/api/es-mx/catalog/ship/v1/docs.html
 */
class RequestedPackageLineItems{

    private $items = [];

    public function __construct(...$args)
    {
        foreach ($args as $item) {
            $this->add($item);
        }
    }
    public function add(PackageLineItem $item){
        $this->items[] = $item;
    }
    public function array(){
        return array_map(function(PackageLineItem $item){
            return $item->array();
        }, $this->items);
    }
}
