<?php
namespace App\Services\Fedex\Objects;

use App\Services\Fedex\Exceptions\Fedex;

/**
 * https://developer.fedex.com/api/es-mx/guides/api-reference.html#servicetypes
 */
class ServiceType{

    public const FEDEX_INTERNATIONAL_PRIORITY_EXPRESS = 'FEDEX_INTERNATIONAL_PRIORITY_EXPRESS';

    public const FEDEX_INTERNATIONAL_PRIORITY = 'FEDEX_INTERNATIONAL_PRIORITY';

    public const INTERNATIONAL_PRIORITY_FREIGHT = 'INTERNATIONAL_PRIORITY_FREIGHT';

    public const FIRST_OVERNIGHT = 'FIRST_OVERNIGHT';

    public const PRIORITY_OVERNIGHT = 'PRIORITY_OVERNIGHT';

    public const STANDARD_OVERNIGHT = 'STANDARD_OVERNIGHT';

    public const INTERNATIONAL_PRIORITY_DISTRIBUTION = 'INTERNATIONAL_PRIORITY_DISTRIBUTION';

    public const FEDEX_EXPRESS_SAVER = 'FEDEX_EXPRESS_SAVER';

    public const SAME_DAY_CITY = 'SAME_DAY_CITY';

    public const FEDEX_1_DAY_FREIGHT = 'FEDEX_1_DAY_FREIGHT';

    public const FEDEX_2_DAY_FREIGHT = 'FEDEX_2_DAY_FREIGHT';


    public function __construct(public readonly string $value)
    {
        $reflection = new \ReflectionClass(__CLASS__);
        $const = $reflection->getConstants();

        if(in_array($value, $const)) return;

        throw new Fedex("El tipo no es válido, consulta la documentacion", 1);
    }
    /**
     * Valida si un tipo de servicio es válido en el contexto de FedEx.
     * Nota: Algunos servicios pueden no estar disponibles en ciertos países.
     *
     * @param string $type El tipo de servicio a validar.
     * @param bool $isProduction Indica si la validación se realiza en un entorno de producción.
     * @return bool True si el tipo es válido, false de lo contrario.
     */
    public static function isValid(string $type){
        $reflection = new \ReflectionClass(__CLASS__);
        $const = $reflection->getConstants();

        return in_array($type, $const);
    }
}
