<?php
namespace App\Services\Fedex\Objects\Shipment;

use App\Services\Fedex\Objects\PickupType;
use App\Services\Fedex\Objects\RequestedPackageLineItems;
use App\Services\Fedex\Objects\ServiceType;

class RequestedShipment{
    public function __construct(
        public readonly Shipper $shipper,
        public readonly array $recipients,
        public readonly PickupType $pickupType,
        public readonly ServiceType $serviceType,
        public readonly ShippingChargesPayment $shippingChargesPayment,
        public readonly LabelSpecification $labelSpecification,
        public readonly RequestedPackageLineItems $requestedPackageLineItems,
        public readonly string $packagingType = 'YOUR_PACKAGING')
    {
        if(count($recipients) == 0) throw new \Exception("Se requiere como mínimo un destino de entrega para notificar", 1);

        array_walk($recipients, function($recipient) {
            if(get_class($recipient) != Recipient::class) throw new \Exception("Es necesario que el item sea de la clase Recipient", 1);

        });
    }
    public function array(){
        return [
            'shipper' => $this->shipper->array(),
            'recipients' => array_map(fn(Recipient $recipient) => $recipient->array(), $this->recipients),
            'pickupType' => $this->pickupType->value,
            'serviceType' => $this->serviceType->value,
            'packagingType' => $this->packagingType,
            'shippingChargesPayment' => $this->shippingChargesPayment->array(),
            'labelSpecification' => $this->labelSpecification->array(),
            'requestedPackageLineItems' => $this->requestedPackageLineItems->array()
        ];
    }
}
