<?php
namespace App\Services\Fedex\Objects;

use App\Services\Fedex\Exceptions\Fedex;
use App\Services\Fedex\Packaging\Box;
use App\Services\Fedex\Packaging\Pallet;
use App\Services\Fedex\Packaging\DoublePallet;
/**
 * Ver https://developer.fedex.com/api/es-mx/guides/api-reference.html#subpackagetypes
 */
class SubPackagingType{

    public const PACKAGE = 'PACKAGE';
    public const PALLET = 'PALLET';

    /**
     * En el mismo constructor verificamos que el codigo que se haya proporcionado sea valido, para saberlo usamos las
     * propiedades estaticas de la misma clase
     *
     * @param integer $value
     */
    public function __construct(public readonly string $value)
    {
        $reflection = new \ReflectionClass(__CLASS__);
        $const = $reflection->getConstants();

        if(in_array($value, $const)) return;

        throw new Fedex("El tipo no es válido, consulta la documentacion", 1);
    }
    /**
     *
     *
     * @param float $weight Kg
     * @param float $length cm
     * @param float $width cm
     * @param float $depth cm
     * @return SubPackagingType
     */
    public static function equivalent(float $weight, float $length, float $width, float $depth): SubPackagingType{

        if (self::matches($weight, $length, $width, $depth, Box::class)) {
            return new self(self::PACKAGE);
        }

        if (self::matches($weight, $length, $width, $depth, Pallet::class)) {
            return new self(self::PALLET);
        }

        if (self::matches($weight, $length, $width, $depth, DoublePallet::class)) {
            return new self(self::PALLET);
        }

        throw new Fedex('El tipo de embalaje no encuentra un equivalente con la paqueteria', 1);

    }
    private static function matches(float $weight, float $length, float $width, float $depth, $type): bool {
        return $depth <= $type::HEIGHT && $length <= $type::LENGTH
               && $weight <= $type::WEIGHT && $width <= $type::WIDTH;
    }
}
