<?php
namespace App\Services\Fedex\Request;

use App\Services\Fedex\Objects\Shipment\RequestedShipment;

class Shipment{
    /**
     *
     *
     * @param RequestedShipment $requestedShipment The descriptive data of the requested shipment.
     * @param string $accountNumber The account number associated with the shipment.
     * @param string $labelResponseOptions This is to specify whether the encoded bytecode or the Label URL to be returned in the response
     * Valid values:
     * LABEL – Indicates request is for encoded bytecode.
     * URL_ONLY – Indicates label URL request.
     * @param string mergeLabelDocOption It specifies the content of the merged pdf URL in the response.
     * The merged pdf URL is generated only if the labelResponseOption is indicated as URL_ONLY.
     * If the value is 'LABELS_AND_DOCS', then merged (all shipping labels and shipping documents) pdf URL will be returned.
     * If the value is 'LABELS_ONLY', merged (all shipping labels only) pdf URL will be returned.
     * If the value is 'NONE', then no merged pdf URL will be returned.
     */
    public function __construct(
        public readonly RequestedShipment $requestedShipment,
        public readonly string $accountNumber,
        public readonly string $labelResponseOptions = 'URL_ONLY',
        public readonly string $mergeLabelDocOption = 'LABELS_AND_DOCS')
    {

    }
    public function array(){
        return [
            'mergeLabelDocOption' => $this->mergeLabelDocOption,
            'requestedShipment' => $this->requestedShipment->array(),
            'accountNumber' => [
                'value' => $this->accountNumber
            ],
            'labelResponseOptions' => $this->labelResponseOptions
        ];
    }
}
