<?php

namespace App\Services\Fedex\Response;

use App\Services\Contracts\Shipment as ContractsShipment;
use App\Services\Fedex\Exceptions\Fedex;
use App\Services\Shipments\Exceptions\ContainerInvalid;
use App\Services\Shipments\PerSend\ListPackaging;
use App\Services\Shipments\Sent\ListPackages;
use App\Services\Shipments\PerSend\RegularContainer as PerSendRegularContainer;
use App\Services\Shipments\PerSend\SelfContainer as PerSendSelfContainer;
use App\Services\Shipments\Sent\RegularContainer;
use App\Services\Shipments\Sent\SelfContainer;

class Shipment implements ContractsShipment{


    public function __construct(
        public readonly object $response,
        public readonly ListPackaging $listPackaging,
        private readonly int $shipmentId){

    }
    public function getTrackingNumber(): string{
        return $this->response->output->transactionShipments[0]->masterTrackingNumber;
    }
    public function getJSONResponse() : string{
        return json_encode($this->response);
    }
    public function getTotalAmount(): ?float{
        return $this->response->output->transactionShipments[0]->pieceResponses[0]->netRateAmount;
    }
    public function getCurrency(): string{
        return $this->response->output->transactionShipments[0]->pieceResponses[0]->currency;
    }
    public function getUrlPdfForDownload(){
        return $this->response->output->transactionShipments[0]->pieceResponses[0]->packageDocuments[0]->url;
    }
    public function getListPackagesSent(): ListPackages{
        $listPackagedSent = new ListPackages;
        $allPackages = $this->listPackaging->packages();
        //En las pruebas se devolvia tambien el master como parte de los paquetes enviados, de ser asi lo "brincamos"
        $hasMaster = count($allPackages) === count($this->response->output->transactionShipments[0]->pieceResponses) ? false : true;

        foreach ($allPackages as $key => $package) {
            $packageId = $hasMaster ? $key + 1 : $key;
            $trackingId = $this->response->output->transactionShipments[0]->pieceResponses[$packageId]->trackingNumber;

            if($package instanceof PerSendSelfContainer){
                $listPackagedSent->add(
                    new SelfContainer(
                        $this->shipmentId,
                        count($package->getItems()),
                        $trackingId,
                        $package->getOrderItemId()
                    )
                );
            }elseif($package instanceof PerSendRegularContainer){
                $listPackagedSent->add(
                    new RegularContainer(
                        $this->shipmentId,
                        count($package->getItems()),
                        $trackingId,
                        $package->packedBox->getItems(),
                        $package->shippingBox->id
                    )
                );
            }else
                throw new ContainerInvalid("El paquete no pertenece a una instancia valida " . get_class($package), 1);

        }
        return $listPackagedSent;
    }

}
