<?php
namespace App\Services\Fedex;

use App\Services\Contracts\CancelShipment;
use GuzzleHttp\Client;
use App\Services\Contracts\ShippingServiceInterface;
use App\Services\Fedex\Helpers\Request;
use App\Services\Fedex\Response\Shipment as ResponseShipment;
use App\Services\Fedex\Response\Tracking as ResponseTracking;
use App\Services\Shipments\ShippingQuote;

class Service implements ShippingServiceInterface{
    use Request;

    public function __construct(private readonly Client $client)
    {

    }
    public function getQuote(ShippingQuote $shipment){
        $handler = new Quote($this->client);
        return $handler->handle($shipment);
    }
    public function shipping(int $shipmentId): ResponseShipment{
        $handler = new Shipment($this->client);
        return $handler->handle($shipmentId);
    }
    public function tracking(string $trackingId): ResponseTracking
    {
        $handler = new Tracking($this->client);
        return $handler->handle($trackingId);
    }
    public function cancel($trackingId): CancelShipment
    {
        $handler = new Cancel($this->client);
        return $handler->handle($trackingId);
    }
    public function canCancel($deliveryStatus): bool
    {
        return match ($deliveryStatus) {
            'OC' => true,
            default => false,
        };
    }
    public function isCanceled($deliveryStatus): bool
    {
        return match ($deliveryStatus) {
            'CA' => true,
            default => false,
        };;
    }
}
