<?php

namespace App\Services\Fedex;

use App\Exceptions\Handler;
use App\Models\Shipment as ModelsShipment;
use App\Services\Fedex\Exceptions\Fedex;
use GuzzleHttp\Client;
use App\Services\Fedex\Helpers\Request;
use App\UseCases\Api\HttpRequestExceptionHandler;

class ShipmentLabel extends HttpRequestExceptionHandler{

    use Request;

    public function __construct(public readonly Client $client)
    {

    }

    public function handle(string $url,  int $shipmentId): ?string{
        try {

            $response = $this->sendRequest($url);

            return $this->processResponse($response, $shipmentId);

        } catch (\Throwable $th) {
            Handler::log($th);
        }

        return null;
    }
    /**
     * Guardar el pdf retornado por la API
     *
     * @param \Psr\Http\Message\ResponseInterface $response
     * @param bool $saveInStorage Hacer que persista el pdf en el almacenamiento local
     * @param int $shipmentId
     * @return string
     */
    private function processResponse(\Psr\Http\Message\ResponseInterface $response, int $shipmentId): string{
        $pdfContent = $response->getBody()->getContents();

        if($pdfContent)
            ModelsShipment::saveShipmentLabel($shipmentId, $pdfContent);
        else
            throw new Fedex("Hubo un problema al descargar el pdf del envio $shipmentId", 1);

        return $pdfContent;
    }
    private function sendRequest(string $url): \Psr\Http\Message\ResponseInterface{
        try {

            $response = $this->client->get($url);

            if($response->getStatusCode() !== 200) throw new Fedex('No es posible conectarse a la paqueteria ' . json_encode($response), 1);

            return $response;

        } catch (\Throwable $e) {
            $this->handleHttpRequestException($e, 'ShipmentLabel', Fedex::class);
        }
    }
}
