<?php

namespace App\Services\Fedex;

use App\Services\Fedex\Exceptions\Fedex;
use App\Services\Fedex\Helpers\Request;
use GuzzleHttp\Client;
use App\Services\Fedex\Response\Tracking as ResponseTracking;
use App\UseCases\Api\HttpRequestExceptionHandler;
use GuzzleHttp\Exception\ClientException;
use Illuminate\Support\Facades\Log;

class Tracking extends HttpRequestExceptionHandler{

    use Request;
    private const MAX_INTENTS = 2;
    private int $intents = 0;
    private const API_URL = '/track/v1/associatedshipments';

    public function __construct(private readonly Client $client)
    {

    }
    /**
     * Maneja el seguimiento de un envío.
     *
     * @param string $trackingId
     * @return ResponseTracking
     * @throws Fedex
     */
    public function handle(string $trackingId): ResponseTracking{


        $response = $this->sendRequest($trackingId);

        $bodyResult = $this->decodeResponse($response);

        return new ResponseTracking($bodyResult);

    }
    private function sendRequest(string $trackingId): \Psr\Http\Message\ResponseInterface{

        $request = Factory::track($trackingId);
        $headers = Factory::credentialsTracking($this->intents > 0);

        try {
            $response = $this->client->post(self::API_URL, [
                'headers' =>[
                    'Authorization' => 'Bearer ' . $headers->authorization,
                    'X-locale' => $headers->xLocale
                ],
                'json' => $request->array()
            ]);

            if($response->getStatusCode() !== 200) throw new Fedex('La respuesta de la paqueteria es inconsistente ' . json_encode($response), 1);

            return $response;

        } catch (\Throwable $e) {
            $this->handleHttpRequestException($e, 'Tracking', Fedex::class, $request->array());
        }
    }
    private function decodeResponse(\Psr\Http\Message\ResponseInterface $response): object {
        $bodyResult = json_decode($response->getBody());

        if (json_last_error() !== JSON_ERROR_NONE) {
            throw new Fedex('Error al decodificar la respuesta JSON');
        }

        return $bodyResult;
    }
    private function reintentAuthAndRequest(string $trackingId){
        $this->intents++;
        Log::info("Fedex: Reintentando autenticacion, intentos ($this->intents)");
        $this->sendRequest($trackingId);
    }
}
