<?php

namespace App\Services\Helpers;

use App\Models\ExchangeRate;
/**
 * Para calculos monetarios siempre usar la extension BCMath
 */
class Money{
    private const DEFAULT = 20;
    /**
     * Número de dígitos después del punto decimal, debe usarse en todos los lugares donde se calcule dinero,
     * esto debido a posibles errores con valores flotantes,
     * para mas detalles lee lo siguiente:
     * https://medium.com/@dotcom.software/floating-dangers-in-php-c4a2220bd8dc
     * https://andycarter.dev/blog/don-t-trust-php-floating-point-numbers-when-equating
     */
    public const SCALAR = 2;

    public static function convertToDolar($value): string{
        if (!is_numeric($value)) {
            throw new \InvalidArgumentException('Los valores deben ser numéricos');
        }

        return \bcdiv($value, self::getExchangeRate(), self::SCALAR);
    }
    public static function convertToPeso($value): string{
        if (!is_numeric($value)) {
            throw new \InvalidArgumentException('Los valores deben ser numéricos');
        }

        return \bcmul($value, self::getExchangeRate(), self::SCALAR);
    }
    /**
     * Cuando se sumen valores monetarios hay que usar esta funcion para garantizar la precision
     *
     * @param string $first
     * @param string $second
     * @return string
     */
    public static function add(string $first, string $second): string{
        if (!is_numeric($first) || !is_numeric($second)) {
            throw new \InvalidArgumentException('Los valores deben ser numéricos');
        }

        return bcadd($first, $second, self::SCALAR);
    }
    /**
     * Cuando se sumen valores monetarios hay que usar esta funcion para garantizar la precision
     *
     * @param string $first
     * @param string $second
     * @return string
     */
    public static function sub(string $first, string $second): string{
        if (!is_numeric($first) || !is_numeric($second)) {
            throw new \InvalidArgumentException('Los valores deben ser numéricos');
        }

        return bcsub($first, $second, self::SCALAR);
    }
    /**
     * Cuando se multipliquen valores monetarios hay que usar esta funcion para garantizar la precision
     *
     * @param string $first
     * @param string $second
     * @return string
     */
    public static function mul(string $first, string $second): string {
        if (!is_numeric($first) || !is_numeric($second)) {
            throw new \InvalidArgumentException('Los valores deben ser numéricos');
        }

        return \bcmul($first, $second, self::SCALAR);
    }
    public static function div(string $first, string $second): string {
        if (!is_numeric($first) || !is_numeric($second)) {
            throw new \InvalidArgumentException('Los valores deben ser numéricos');
        }

        return \bcdiv($first, $second, self::SCALAR);
    }
    /**
     * Dar formato a un numero
     *
     * @param float $value
     * @return string
     */
    public static function format(float $value,  string $currencySymbol = '$'){
        return $currencySymbol . number_format($value, 2);
    }
    private static function getExchangeRate(){
        $exchangeRate = ExchangeRate::where('currency_pair', 'USD/MXN')->orderBy('updated_at', 'desc')->first();

        if (!$exchangeRate)
            \Log::error('No se pudo obtener la tasa de cambio. Usando valor por defecto.');

        return $exchangeRate ? $exchangeRate->rate : self::DEFAULT;
    }
}
