<?php

namespace App\Services\Netsuite;

use App\Traits\OAuth1NetsuiteClientCreator;
use GuzzleHttp\Exception\RequestException;
use Illuminate\Support\Facades\Log;

class NetsuiteCustomersService
{
    use OAuth1NetsuiteClientCreator;

    public function getNetsuiteClient()
    {
        $client = $this->createOAuth1Client(
            config('netsuite.sb_clients_endpoint'),
            config('netsuite.sb_clients_consumer_key'),
            config('netsuite.sb_clients_consumer_secret'),
            config('netsuite.sb_clients_token_secret'),
            config('netsuite.sb_clients_token'),
            config('netsuite.sb_clients_realm')
        );
        return $client;
    }

    public function fetchCustomersFromNetsuite($client, $page)
    {
        Log::info("fetchCustomersFromNetsuite()");
        try {
            $response = $client->get('site/hosting/restlet.nl', [
                'query' => ['script' => 2376, 'deploy' => 1, 'page' => 0],
                'headers' => ['Content-Type' => 'application/json', 'Accept' => 'application/json']
            ]);

            $customers = json_decode($response->getBody(), true);

            if (json_last_error() !== JSON_ERROR_NONE) {
                throw new \Exception('JSON decode error: ' . json_last_error_msg());
            }

            return $customers;

        } catch (RequestException $e) {
            $responseBody = json_decode($e->getResponse()->getBody()->getContents(), true);
            if (isset($responseBody['error']['code']) && $responseBody['error']['code'] === 'INVALID_PAGE_RANGE') {
                return []; // Retornar array vacío para detener la paginación
            }
            Log::error('Request to NetSuite failed: ' . $e->getMessage());
            throw $e;
        } catch (\Exception $e) {
            Log::error('Error fetching customers from NetSuite: ' . $e->getMessage());
            throw $e;
        }
    }
}