<?php

namespace App\Services\Paquetexpress;

use App\Services\Paquetexpress\Exceptions\Paquetexpress;
use GuzzleHttp\Client;
use App\Services\Paquetexpress\Helpers\Request;
use App\Services\Paquetexpress\Response\CancelShipment as ResponseCancelShipment;
use App\Services\Paquetexpress\Request\CancelShipment as RequestCancelShipment;
use App\UseCases\Api\HttpRequestExceptionHandler;

class CancelShipment extends HttpRequestExceptionHandler{

    use Request;

    public function __construct(public readonly Client $client)
    {

    }
    /**
     * Cancelar una guía en Paquetexpress usando el número de rastreo.
     *
     * @param string $trackingNumber
     * @return ResponseCancelShipment
     */
    public function handle($trackingNumber): ResponseCancelShipment{
        $data = Factory::cancelShipment($trackingNumber, Factory::credentials($this->client));

        $response = $this->sendRequest($data);

        $bodyResult = $this->decodeResponse($response);

        return $this->processResponse($bodyResult);
    }
    private function sendRequest(RequestCancelShipment $data): \Psr\Http\Message\ResponseInterface{
        try {
            $response = $this->client->post('/RadRestFul/api/rad/v1/cancelguia', ['json' => $data->array()]);

            if($response->getStatusCode() !== 200) throw new Paquetexpress('No es posible conectarse a la paqueteria ' . json_encode($response), 1);

            return $response;

        } catch (\Throwable $e) {
            $this->handleHttpRequestException($e, 'CancelShipment', Paquetexpress::class, $data->array());
        }
    }
    private function decodeResponse(\Psr\Http\Message\ResponseInterface $response): object{
        $bodyResult = json_decode($response->getBody());

        if (json_last_error() !== JSON_ERROR_NONE) throw new Paquetexpress('Error al decodificar la respuesta JSON');

        return $bodyResult;
    }
    private function processResponse($bodyResult): ResponseCancelShipment{
        if($bodyResult->body->response->success){

            return new ResponseCancelShipment($bodyResult);

        };

        $this->errorResponse($bodyResult->body->response);
    }
}
