<?php
namespace App\Services\Paquetexpress\Objects;

use App\Services\Paquetexpress\Exceptions\Paquetexpress;
use App\Services\Paquetexpress\Packaging\Box;
use App\Services\Paquetexpress\Packaging\Pallet;
use App\Services\Paquetexpress\Packaging\DoublePallet;

class Code{

    public const SOBRE = '1';
    public const TAMBOR = '10';
    public const CAJA = '2';
    public const PAQUETE = '3';
    public const BOLSA = '4';
    public const PIEZA = '5';
    public const CUBETA = '6';
    public const BIDON = '7';
    public const PORRON = '8';
    public const GALON = '9';
    public const COSTAL = '12';
    public const PALETT = '14';
    public const HUACAL = '15';
    public const TERMO = '16';
    public const TARIMA = '11';
    public const REJA_MEDE = '22';
    public const SACO = '23';
    public const ATADO_A = '24';
    public const LOTE = '25';
    public const ROLLOS = '26';
    public const CAJA_A = '28';
    public const BULTO = '27';
    public const HUACAL_CON_ASTERISCO = '32';
    public const SOBRE_ANEXO = '33';
    public const HIELERA = '42';
    public const VALIJA = '50';
    public const EMBALAJE_PE_MED = '61';
    public const EMBALAJE_PE_GDE = '62';
    public const EMBALAJE_PE_EXGDE = '63';
    public const EMBALAJE_PE_CH = '60';

    /**
     * En el mismo constructor verificamos que el codigo que se haya proporcionado sea valido, para saberlo usamos las
     * propiedades estaticas de la misma clase
     *
     * @param integer $value
     */
    public function __construct(public readonly int $value)
    {
        $reflection = new \ReflectionClass(__CLASS__);
        $const = $reflection->getConstants();

        if(in_array($value, $const)) return;

        throw new \Exception("El tipo no es válido, consulta la documentacion", 1);
    }
    /**
     *
     *
     * @param float $weight Kg
     * @param float $length cm
     * @param float $width cm
     * @param float $depth cm
     * @return Code
     */
    public static function equivalent(float $weight, float $length, float $width, float $depth): Code{

        if (self::matches($weight, $length, $width, $depth, Box::class)) {
            return new self(self::CAJA);
        }

        if (self::matches($weight, $length, $width, $depth, Pallet::class)) {
            return new self(self::TARIMA);
        }

        if (self::matches($weight, $length, $width, $depth, DoublePallet::class)) {
            return new self(self::TARIMA);
        }

        throw new Paquetexpress('El tipo de embalaje no encuentra un equivalente con la paqueteria', 1);

    }
    private static function matches(float $weight, float $length, float $width, float $depth, $type): bool {
        return $depth <= $type::HEIGHT && $length <= $type::LENGTH
               && $weight <= $type::WEIGHT && $width <= $type::WIDTH;
    }
}
