<?php
namespace App\Services\Paquetexpress\Objects\Shipment;

use App\Services\Paquetexpress\Exceptions\Paquetexpress;
use App\Services\Paquetexpress\Packaging\Box;
use App\Services\Paquetexpress\Packaging\Pallet;
use App\Services\Paquetexpress\Packaging\DoublePallet;

class SrvcId{

    public const PACKETS = "PACKETS";
    public const ENVELOP = "ENVELOP";
    public const TARIMA = "TARIMA";
    public const ATADO = "ATADO";
    public const BULTO = "BULTO";
    public const BOLSA = "BOLSA";
    public const PIEZA = "PIEZA";
    public const CUBETA = "CUBETA";
    public const HUACAL = "HUACAL";
    public const BIDON = "BIDON";
    public const COSTAL = "COSTAL";
    public const GALON = "GALON";
    public const HIELERA = "HIELERA";
    public const PALETT = "PALETT";
    public const PORRON = "PORRON";
    public const ROLLOS = "ROLLOS";
    public const SACO = "SACO";
    public const TAMBOR = "TAMBOR";
    public const TERMO = "TERMO";
    public const REJA = "REJA MEDE";
    public const UPS = "UPS BOLSA PLASTIFICADA";
    public const LOTE = "LOTE";
    public const PAQUETE = "PAQUETE";
    public const CAJA = "CAJA";
    public const EMB = "EMB-CAJA";

    /**
     * En el mismo constructor verificamos que el codigo que se haya proporcionado sea valido, para saberlo usamos las
     * propiedades estaticas de la misma clase
     *
     * @param integer $value
     */
    public function __construct(public readonly string $value)
    {
        $reflection = new \ReflectionClass(__CLASS__);
        $const = $reflection->getConstants();

        if(in_array($value, $const)) return;

        throw new \Exception("El tipo no es válido, consulta la documentacion", 1);
    }
    /**
     *
     *
     * @param float $weight Kg
     * @param float $length cm
     * @param float $width cm
     * @param float $depth cm
     * @return Code
     */
    public static function equivalent(float $weight, float $length, float $width, float $depth): SrvcId{

        if (self::matches($weight, $length, $width, $depth, Box::class)) {
            return new self(self::PACKETS);
        }

        if (self::matches($weight, $length, $width, $depth, Pallet::class)) {
            return new self(self::TARIMA);
        }

        if (self::matches($weight, $length, $width, $depth, DoublePallet::class)) {
            return new self(self::TARIMA);
        }

        throw new Paquetexpress('El tipo de embalaje no encuentra un equivalente con la paqueteria', 1);

    }
    private static function matches(float $weight, float $length, float $width, float $depth, $type): bool {
        return $depth <= $type::HEIGHT && $length <= $type::LENGTH
               && $weight <= $type::WEIGHT && $width <= $type::WIDTH;
    }
}
