<?php
namespace App\Services\Paquetexpress\Request;

use App\Services\Paquetexpress\Objects\Quote\Device;
use App\Services\Paquetexpress\Objects\Quote\Security;
use App\Services\Paquetexpress\Objects\Quote\Target;
use App\Services\Paquetexpress\Objects\Shipment\BillRad;
use App\Services\Paquetexpress\Objects\Shipment\ListSrvcItemDTO;
use App\Services\Paquetexpress\Objects\Shipment\RadGuiaAddrDTOList;
use App\Services\Paquetexpress\Objects\Shipment\RadSrvcItemDTOList;
use App\Services\Paquetexpress\Objects\Shipment\TypeSrvcId;

class Shipment{
    /**
     *
     *
     * @param Security $security
     * @param Device $device
     * @param Target $target
     * @param BillRad $billRad
     * @param string $billClntId No encontre documentacion, creo es el id del cliente
     * @param RadGuiaAddrDTOList $radGuiaAddrDTOList
     * @param RadSrvcItemDTOList $radSrvcItemDTOList
     * @param ListSrvcItemDTO $listSrvcItemDTO
     * @param TypeSrvcId $typeSrvcId
     * @param string $pymtMode Modo de pago:
     * PAID=PAGADO
     * TO_PAY=Flete por cobrar
     * @param string $pymtType Tipo de pago:
     * C = CREDITO
     * N = CONTADO
     * @param string $comt No encontre documentacion, pero esta en el ejemplo de la solicitud
     */
    public function __construct(
        private readonly Security $security,
        private readonly Device $device,
        private readonly Target $target,
        private readonly BillRad $billRad,
        private readonly string $billClntId,
        private readonly RadGuiaAddrDTOList $radGuiaAddrDTOList,
        private readonly RadSrvcItemDTOList $radSrvcItemDTOList,
        private readonly ListSrvcItemDTO $listSrvcItemDTO,
        private readonly TypeSrvcId $typeSrvcId,
        private readonly string $pymtMode = 'PAID',
        private readonly string $pymtType = 'C',
        private readonly string $comt = 'Na'
    )
    {

    }
    public function array(){
        return [
            'header' => [
                'security' => [
                    'user' => $this->security->credentials->user,
                    'type' => $this->security->type,
                    'token' => $this->security->token
                ],
                'device' => $this->device->array(),
                'target' => null,
                'output' => 'JSON'
            ],
            'body' => [
                'request' => [
                    'data' => [
                        [
                            'billRad' => $this->billRad->value,
                            'billClntId' => $this->billClntId,
                            'pymtMode' => $this->pymtMode,
                            'pymtType' => $this->pymtType,
                            'comt' => $this->comt,
                            'radGuiaAddrDTOList' => $this->radGuiaAddrDTOList->array(),
                            'radSrvcItemDTOList' => $this->radSrvcItemDTOList->array(),
                            'listSrvcItemDTO' => $this->listSrvcItemDTO->array(),
                            'typeSrvcId' => $this->typeSrvcId->value
                        ]
                    ]
                ]
            ]
        ];
    }
}
