<?php

namespace App\Services\Paquetexpress\Response;

use App\Services\Contracts\Shipment as ContractsShipment;
use App\Services\Paquetexpress\Exceptions\Paquetexpress;
use App\Services\Shipments\Exceptions\ContainerInvalid;
use App\Services\Shipments\Sent\ListPackages;
use App\Services\Shipments\PerSend\ListPackaging;
use App\Services\Shipments\PerSend\RegularContainer as PerSendRegularContainer;
use App\Services\Shipments\PerSend\SelfContainer as PerSendSelfContainer;
use App\Services\Shipments\Sent\RegularContainer;
use App\Services\Shipments\Sent\SelfContainer;

class Shipment implements ContractsShipment{

    public function __construct(
        public readonly object $response,
        public readonly ListPackaging $listPackaging,
        private readonly int $shipmentId)
    {

    }
    public function getTrackingNumber(): string
    {
        return $this->response->body->response->data;
    }
    public function getJSONResponse() : string{
        return json_encode($this->response);
    }
    public function getTotalAmount(): ?float{
        return $this->response->body->response->additionalData->totalAmnt;
    }
    public function getCurrency():string {
        return 'MXN';
    }
    public function getListPackagesSent(): ListPackages
    {
        $listPackagedSent = new ListPackages;

        $allPackages = $this->listPackaging->packages();

        foreach ($allPackages as $package) {
            if($package instanceof PerSendSelfContainer){
                $listPackagedSent->add(
                    new SelfContainer(
                        $this->shipmentId,
                        count($package->getItems()),
                        $this->getTrackingNumber(),
                        $package->getOrderItemId()
                    )
                );
            }elseif($package instanceof PerSendRegularContainer){
                $listPackagedSent->add(
                    new RegularContainer(
                        $this->shipmentId,
                        count($package->getItems()),
                        $this->getTrackingNumber(),
                        $package->packedBox->getItems(),
                        $package->shippingBox->id
                    )
                );
            }else
                throw new ContainerInvalid("El paquete no pertenece a una instancia valida " . get_class($package), 1);

        }

        return $listPackagedSent;
    }
}
