<?php
namespace App\Services\Paquetexpress\Response;

use App\Services\Contracts\Tracking as ContractsTracking;

class Tracking implements ContractsTracking{

    private const MILLISECONDS_TO_SECONDS = 1000;

    private $lastStatus;
    private $statusCauseDelayDelivery = ['CBD','CDG','CGS','CLS','DEC','EOP', 'ERS','HCE'];
    private ?string $delay = null;

    public function __construct(public readonly object $response)
    {
        $lastPosition = count($response->body->response->data) - 1;
        $this->lastStatus = $this->response->body->response->data[$lastPosition];
    }
    public function getCode(): string
    {
        return $this->lastStatus->eventoId;
    }
    public function getDescription(): string
    {
        return $this->lastStatus->status;
    }
    public function getDelay(): ?string{

        if (in_array($this->lastStatus->status, $this->statusCauseDelayDelivery)) {
            $this->delay = $this->lastStatus->status;
        }

        return $this->delay;


    }
    public function getDateTime(): ?string{
        return $this->lastStatus->fecha . ' ' . $this->lastStatus->hora;
    }
    public function getPromiseDeliveryDateTime(): ?string{
        return $this->lastStatus?->promesa;
    }
    public function getAdditionalInfo(): ?string{
        return null;
    }
    public function getHistorical(): ?string{
        if(count($this->response->body->response->data) > 1){

            $groupedData = $this->historicalGroupByDate();
            $rows = '';

            foreach ($groupedData as $date => $events) {
                $rows .= view('components.tracking.tr_date_group', [ 'date' => $date])->render();
                $rows .= $this->rowsEvents($events);

            }

            return "<table class='table table-sm'>
                        $rows
                    </table>";
        }
        return null;
    }
    private function rowsEvents($events): string{
        $rows = '';
        foreach ($events as $event) {
            $hour = date('h:i:s a', $this->parseToSeconds($event->fechahora));
            $rows .= view('components.tracking.tr', [ 'hour' => $hour, 'description' => $event->status, 'location' => $event->ciudadEvento])
                            ->render();
        }
        return $rows;
    }
    private function historicalGroupByDate(): array{

        $groupedData = [];

        foreach ($this->response->body->response->data as $event) {
            $date = date('d/m/Y', $this->parseToSeconds($event->fechahora));

            if (!isset($groupedData[$date])) {
                $groupedData[$date] = [];
            }
            $groupedData[$date][] = $event;
        }

        return $groupedData;
    }
    private function parseToSeconds(int $fechaHora){
        return $fechaHora / self::MILLISECONDS_TO_SECONDS;
    }
}
