<?php

namespace App\Services\Paquetexpress;

use GuzzleHttp\Client;
use App\Services\Contracts\ShippingServiceInterface;
use App\Services\Paquetexpress\Request\Quotation;
use App\Services\Paquetexpress\Response\CancelShipment as ResponseCancelShipment;
use App\Services\Paquetexpress\Response\Quotation as ResponseQuotation;
use App\Services\Paquetexpress\Response\Shipment as ResponseShipment;
use App\Services\Paquetexpress\Response\Tracking as ResponseTracking;
use App\Services\Shipments\ShippingQuote;
use App\Services\Contracts\ShipmentLabel as ContractShipmentLabel;
use App\Services\Paquetexpress\ShipmentLabel;

/**
 * Consultar la API de paquetexpress
 * OJO: Si mandas mal la estructura, cambiando el nombre de alguna variable la solicitud
 * puede fallar y no indicar porque, la misma api devolvera un error generico
 */
class Service implements ShippingServiceInterface, ContractShipmentLabel{

    public function __construct(private readonly Client $client)
    {}

    /**
     * Cotizar N envios, de manera predeterminada solicitamos todos los tipos de envios
     *
     * @param Quotation $data
     * @return ResponseQuotation
     */
    public function getQuote(ShippingQuote $shipment)
    {
        $handler = new Quote($this->client);
        return $handler->handle($shipment);
    }

    /**
     * Solicitar una guia y guardarla
     *
     * @param int $shipmentId
     * @return ResponseShipment
     */
    public function shipping(int $shipmentId): ResponseShipment
    {
        $handler = new Shipment($this->client);
        return $handler->handle($shipmentId);
    }
    /**
     * Solicitar el pdf de una guia
     *
     * @param integer $shipmentId
     * @param string $track_id
     * @param boolean $saveInStorage guardar o no en el almacenamiento local
     * @return string
     */
    public function shipmentLabel(int $shipmentId, string $track_id, bool $saveInStorage = true): string
    {
        $handler = new ShipmentLabel($this->client);
        return $handler->handle($shipmentId, $track_id);
    }
    /**
     *
     *
     * @param string $trackingId
     * @return ResponseTracking
     */
    public function tracking(string $trackingId): ResponseTracking
    {
        /**
        * Uso un cliente nuevo porque no se usa la misma base uri
        */
        $handler = new Tracking(new Client());
        return $handler->handle($trackingId);
    }
    public function cancel($trackingId): ResponseCancelShipment
    {
        $handler = new CancelShipment($this->client);
        return $handler->handle($trackingId);
    }
    public function canCancel($deliveryStatus): bool
    {
        //Ver lang/paquetexpress.php
        return match ($deliveryStatus) {
            'SWB' =>  true, //Documentación de Servicios WEB
            default => false,
        };
    }
    public function isCanceled($deliveryStatus): bool
    {
        //Ver lang/paquetexpress.php
        return match ($deliveryStatus) {
            'CWB' =>  true,
            'CBD' => true,
            'CDG' => true,
            'CGS' => true,
            'CLS' => true,
            'DEC' => true,
            'EOP' => true,
            'ERS' => true,
            'HCE' => true,
            'SIN' => true,
            default => false,
        };
    }
}
