<?php

namespace App\Services\Paquetexpress;

use App\Exceptions\Handler;
use App\Models\Shipment as ModelsShipment;
use App\Services\Paquetexpress\Exceptions\Paquetexpress;
use GuzzleHttp\Client;
use App\Services\Paquetexpress\Helpers\Request;
use App\UseCases\Api\HttpRequestExceptionHandler;

class ShipmentLabel extends HttpRequestExceptionHandler{

    use Request;

    public function __construct(public readonly Client $client)
    {

    }

    public function handle(int $shipmentId, string $trackId, bool $saveInStorage = true): ?string{
        try {

            $response = $this->sendRequest($trackId);

            return $this->processResponse($response, $saveInStorage, $shipmentId);

        } catch (\Throwable $th) {
            Handler::log($th);
        }

        return null;
    }
    /**
     * Guardar el pdf retornado por la API
     *
     * @param \Psr\Http\Message\ResponseInterface $response
     * @param bool $saveInStorage Hacer que persista el pdf en el almacenamiento local
     * @param int $shipmentId
     * @return string
     */
    private function processResponse(\Psr\Http\Message\ResponseInterface $response, bool $saveInStorage, int $shipmentId): string{
        $pdfContent = $response->getBody()->getContents();

        if($pdfContent && $saveInStorage) ModelsShipment::saveShipmentLabel($shipmentId, $pdfContent);

        return $pdfContent;
    }
    private function sendRequest(string $trackId): \Psr\Http\Message\ResponseInterface{
        try {

            $url = config('paquetexpress.url_carta_porte') . $trackId;

            $response = $this->client->get($url);

            if($response->getStatusCode() !== 200) throw new Paquetexpress('No es posible conectarse a la paqueteria ' . json_encode($response), 1);

            return $response;

        } catch (\Throwable $e) {
            $this->handleHttpRequestException($e, 'ShipmentLabel', Paquetexpress::class);
        }
    }
}
