<?php

namespace App\Services\SelfPickup\Response;

use App\Services\Contracts\Shipment as ContractsShipment;
use App\Services\Shipments\Exceptions\ContainerInvalid;
use App\Services\Shipments\PerSend\ListPackaging;
use App\Services\Shipments\Sent\ListPackages;
use DVDoug\BoxPacker\PackedBox;
use App\Services\Shipments\PerSend\RegularContainer as PerSendRegularContainer;
use App\Services\Shipments\PerSend\SelfContainer as PerSendSelfContainer;
use App\Services\Shipments\Sent\RegularContainer;
use App\Services\Shipments\Sent\SelfContainer;
use Ramsey\Uuid\Uuid;

class Shipment implements ContractsShipment{

    /**
     * Cada envio debe tener un indentificador único
     *
     * @var string
     */
    private string $trackingId;

    public function __construct(
        public readonly ListPackaging $listPackaging,
        private readonly int $shipmentId)
    {
        $uuid = Uuid::uuid4();
        $this->trackingId = $uuid->toString();
    }
    /**
     * Identificador unico para rastrear el envio
     *
     * @return string
     */
    public function getTrackingNumber(): string {
        return $this->trackingId;
    }
    /**
     * Respuesta del servidor
     *
     * @return string
     */
    public function getJSONResponse(): string {
        return '{}';
    }
    /**
     * Costo total del servicio de envio
     *
     * @return float
     */
    public function getTotalAmount(): ?float{
        return null;
    }
    /**
     * Moneda bajo la cual a sido cotizado el envio
     *
     * @return string|null
     */
    public function getCurrency(): ?string{
        return null;
    }
    /**
     * Caja donde serian enviados los productos
     *
     * @return PackedBox
     */
    public function getListPackagesSent(): ListPackages
    {
        $listPackagedSent = new ListPackages;

        $allPackages = $this->listPackaging->packages();

        foreach ($allPackages as $package) {
            if($package instanceof PerSendSelfContainer){
                $listPackagedSent->add(
                    new SelfContainer(
                        $this->shipmentId,
                        count($package->getItems()),
                        $this->getTrackingNumber(),
                        $package->getOrderItemId()
                    )
                );
            }elseif($package instanceof PerSendRegularContainer){
                $listPackagedSent->add(
                    new RegularContainer(
                        $this->shipmentId,
                        count($package->getItems()),
                        $this->getTrackingNumber(),
                        $package->packedBox->getItems(),
                        $package->shippingBox->id
                    )
                );
            }else
                throw new ContainerInvalid("El paquete no pertenece a una instancia valida " . get_class($package), 1);

        }

        return $listPackagedSent;
    }
}
