<?php

namespace App\Services\SelfPickup;

use App\Models\Order;
use App\Models\Shipment as ModelsShipment;
use App\Models\User;
use App\Notifications\Customer\Order\OrderReadyForCollect;
use App\Services\Contracts\CancelShipment;
use App\Services\Contracts\ShippingServiceInterface;
use App\Services\Shipments\ShippingQuote;
use App\Services\Contracts\Shipment as ContractsShipment;
use App\Services\Contracts\Tracking;
use App\Services\SelfPickup\Response\Shipment;
use App\Services\SelfPickup\Response\Tracking as ResponseTracking;
use App\Services\Shipments\Packer;

class Service implements ShippingServiceInterface{
     /**
     * Cotizar un envio
     *
     * @param ShippingQuote $data
     * @return array
     */
    public function getQuote(ShippingQuote $data){
        return [];
    }
    /**
     * Solicitar una guia
     *
     * @param integer $shipmentId
     * @return ContractsShipment
     */
    public function shipping(int $shipmentId) : ContractsShipment{
        $listPackagin = Packer::byShipment($shipmentId);
        $shipment = ModelsShipment::findOrFail($shipmentId);
        $user = User::fullCustomer()
                    ->where('customers.id', $shipment->customer_id)
                    ->firstOrFail();

        $user->notify(new OrderReadyForCollect(Order::findOrFail($shipment->order_id), $shipment));

        return new Shipment($listPackagin , $shipmentId);
    }
    /**
     * Rastrear un envio
     *
     * @param string $trackingId
     * @return Tracking
     */
    public function tracking(string $trackingId): Tracking{
        return new ResponseTracking();
    }
    /**
     * Cancelar un envio, solo si no ha sido enviado
     *
     * @param integer $trackingId
     * @return CancelShipment
     */
    public function cancel($trackingId): CancelShipment{
        return new CancelShipment();
    }
    /**
     * Verificar si un envio puede ser cancelado
     *
     * @param integer $deliveryStatus Estatus actual del envio, debe haber sido obtenido recientemente de la api
     * @return boolean
     */
    public function canCancel($deliveryStatus): bool{
        return false;
    }
    /**
     * Verificar si un envio esta cancelado
     *
     * @param integer $deliveryStatus Estatus actual del envio, debe haber sido obtenido recientemente de la api
     * @return boolean
     */
    public function isCanceled($deliveryStatus): bool{
        return false;
    }
    /**
     * Costo predeterminado del servicio de pasar a recoger
     *
     * @return float
     */
    public static function defaultCost(): float{
        return 0;
    }
}
