<?php
namespace App\Services\Shipments\Contracts;

use DVDoug\BoxPacker\Item;
/**
 * Esta interfaz representa un producto para ser empaquetado mediante la libreria DVDoug\BoxPacker,
 * ademas de poder cotizar y enviar mediante una paqueteria
 */
interface Product extends Item{

    /**
     * Subtotal del costo de este producto resultado de multiplicar cantidad * costo por unidad
     *
     * @return float
     */
    public function subtotal(): float;
    /**
     * Cantidad de unidades del producto
     *
     * @return float
     */
    public function quantity(): float;
    /**
     * Identificador unico del producto, por ejemplo el ID en la BD
     *
     * @return integer
     */
    public function identification(): int;
    /**
     * Costo del producto
     *
     * @return float
     */
    public function cost(): float;
    /**
     * Rotar el producto 90 grados, lo que significa que width es ahora su height (depth) y su height (depth) es ahora su width
     * -(Ejemplo: Apartir de 10 paneles estos deben ir en posicion vertical)
     * -(Esta funcion debe combinarse con KeepFlat para que surta efecto)
     * @return void
     */
    public function rotate90Y(): void;
    /**
     * Indicar si el producto puede ser rotado
     *
     * @param integer $rule
     * @return void
     */
    public function setKeepFlat(int $rule): void;

    public function isRotateIn90Y(): bool;
    /**
     * Informacion que requiere un producto para ser enviado segun los requerimientos del SAT
     * http://omawww.sat.gob.mx/tramitesyservicios/Paginas/complemento_carta_porte.htm
     *  http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/Carta_Porte_31.pdf (Verificar que sea la actual aqui http://omawww.sat.gob.mx/tramitesyservicios/Paginas/complemento_carta_porte.htm)
     */
    public function claveProductoServicioCP(): string;

    public function claveUnidadPeso(): string;

}
