<?php
namespace App\Services\Shipments;

use App\Models\OrderItem;
use App\Services\Shipments\Packaging\Panels;
use DVDoug\BoxPacker\ItemList;
use App\Services\Shipments\Product;
/**
 * Esta clase representa  un envio que por empaquetar, aqui se aplican reglas de operaciones para que el empaquetado sea el correcto,
 * esto antes de que el algoritmo de empaquetado sea ejecutado
 */
class PackagedShipping{
    /**
     * Todos aquellos productos que no son paneles
     *
     * @var array
     */
    private array $others = [];
    /**
     *
     *
     * @var Panels
     */
    private $panelsHandler;

    public function __construct(private array $products)
    {
        $this->handlers();
    }
    public function handlers(){
        $this->panelsHandler = new Panels;
    }
    public function getProducts(): array{
        return $this->products;
    }
    public function handle(): void{
        $this->splitProducts();
    }
    public function getPanelList(): ItemList{
        return $this->panelsHandler->getPanelList();
    }
    public function getOthersList(): ItemList{
        $itemList = new ItemList();

        foreach ($this->others as $item) {
            $itemList->insert($item, $item->quantity());
        }

        return $itemList;
    }
    /**
     * Separar los paneles del resto de productos
     *
     * @return void
     */
    private function splitProducts(){
        array_walk($this->products, function(Product $product){
            if(Panels::isPanel($product)){
                $this->panelsHandler->addProduct($product);
            }
            else
                $this->others[] = $product;
        });
    }

    public static function byShipment(int $shipmentId): PackagedShipping{
        $orderItems = OrderItem::forShipment($shipmentId);
        $products = $orderItems->reduce(function(array $acc, OrderItem $item){
            $acc[] = new Product(
                $item->id,
                $item->name,
                $item->length,
                $item->width,
                $item->height,
                $item->weight,
                $item->quantity,
                $item->price,
                $item->sat_clave_producto_servicio,
                $item->sat_clave_unidad_peso
            );
            return $acc;
        }, []);

        return new PackagedShipping($products);
    }
}
