<?php

namespace App\Services\Shipments\PerSend;
/**
 * Lista de paquetes que seran enviados, tanto embalados como sin embalaje
 *No confundir paquetes con productos, un paquete puede contener multiples productos, un producto no, un paquete siempre sera el embalaje,
 *un producto no siempre.
 */
class ListPackaging {
    /**
     *Items embalados, ya sea en caja o pallet
     *
     *  @var RegularContainer[]
     */
    public $packaged = [];
    /**
     *Items que puedieron ser embalados, se consideran aptos para ser transportados sin embalaje
     *
     * @var SelfContainer[]
     */
    public $unpackaged = [];
    /**
     * Total de paquetes
     *
     * @var int
     */
    private $totalPackages;
    /**
     * Es necesario mantener este arreglo inmutable una vez que lo calculamos pues si
     * se envian los paquetes lo usaremos como guia para saber que tracking id corresponde a que paquete, las paqueterias usan el orden de envio
     * de los paquetes y nos retornan las guias conforme al orden de los paquetes en la solicitud
     *
     *
     * @var array
     */
    public $allPackages;

    public function __construct() {
    }
    public function addPackage(RegularContainer $item){

        if(is_array($this->allPackages))
            throw new \Exception("Ya no puedes agregar ningun paquete, ya fueron empaquetados", 1);

        $this->packaged[] = $item;
    }
    public function addUnpackage(SelfContainer $item){
        if(is_array($this->allPackages))
            throw new \Exception("Ya no puedes agregar ningun paquete, ya fueron empaquetados", 1);

        $this->unpackaged[] = $item;
    }
    /**
     * Obtener todos los paquetes por ser enviados, tanto aquellos que van en embalaje como los que no
     *
     * @return array
     */
    public function packages(): array{
        if(is_array($this->allPackages)) return $this->allPackages;

        $this->allPackages = array_merge($this->packaged, $this->unpackaged);
        $this->totalPackages = count($this->allPackages);

        if($this->totalPackages == 0) throw new \Exception("Sin paquetes empaquetados", 1);

        return $this->allPackages;
    }
    /**
     * Obtener el total de paquetes a enviar
     *
     * @return int
     */
    public function total(): int{
        $this->packages();
        return $this->totalPackages;
    }
}
