<?php
namespace App\Services\Shipments;

use App\Services\Helpers\Money;
use App\Services\Shipments\Contracts\Product as ContractProduct;
use DVDoug\BoxPacker\Rotation;
/**
 * Esta clase representa un producto que sera enviado, esta clase trabaja en conjunto con la libreria https://boxpacker.io/en/3.x/getting-started.html
 * para poder resolver bin packing/knapsack problem, dicho de otra forma: para saber en que empaque debera ir el envio
 */
class Product implements ContractProduct{

    private bool $rotate90InY = false;
    public int $keepFlat = Rotation::BestFit;
    /**
     *
     * @param int $id Identificador unico del producto, por ejemplo, el ID de la BD
     * @param string $name Nombre del producto
     * @param float $length Longitud del producto (cm)
     * @param float $width Ancho del producto (cm)
     * @param float $height Alto del producto (cm)
     * @param float $weight El peso del producto (kg)
     * @param float $quantity Cantidad de items del producto seleccionado
     * @param float $price Costo del producto
     */
    public function __construct(
        public readonly int $id,
        public readonly string $name,
        public readonly float $length,
        public readonly float $width,
        public readonly float $height,
        public readonly float $weight,
        public readonly float $quantity,
        public readonly float $price,
        public readonly string $claveProductoServicioCP,
        public readonly string $claveUnidadPeso) {
    }
    //Contract ContractProduct
    public function subtotal(): float{

        if(!isset($this->price, $this->quantity)) throw new \Exception("Imposible calcular el subtotal, faltan parametros", 1);

        return Money::mul($this->price, $this->quantity);
    }
    public function cost(): float{

        if(!isset($this->price)) throw new \Exception("Faltan parametros", 1);

        return $this->price;
    }
    public function quantity(): float
    {
        return $this->quantity;
    }
    public function identification(): int{
        return $this->id;
    }
    /**
     * Item SKU etc.
     */
    public function getDescription(): string{
        return $this->name;
    }

    /**
     * Item width in mm.
     */
    public function getWidth(): int{
        $width = $this->width * 10;

        return $this->rotate90InY ? $this->height * 10 : $width;
    }

    /**
     * Item length in mm.
     */
    public function getLength(): int{
        return $this->length * 10;
    }

    /**
     * Item depth in mm.
     */
    public function getDepth(): int{
        $height = $this->height * 10;

        return $this->rotate90InY ? $this->width * 10 : $height;
    }

    /**
     * Item weight in g.
     */
    public function getWeight(): int{
        return $this->weight * 1000;
    }

    /**
     * Does this item need to be kept flat / packed "this way up"?
     */
    public function getKeepFlat(): bool{
        return $this->keepFlat;
    }
    public function setKeepFlat(int $rule): void
    {
        $this->keepFlat = $rule;
    }
    public function rotate90Y(): void
    {
        $this->rotate90InY = true;
    }
    public function isRotateIn90Y(): bool
    {
        return $this->rotate90InY;
    }
    /**
     * Un producto
     *
     * @return string
     */
    public function claveProductoServicioCP(): string{
        return $this->claveProductoServicioCP;
    }

    public function claveUnidadPeso(): string{
        return $this->claveUnidadPeso;
    }
}
