<?php
namespace App\Services\Shipments;

use App\Services\Helpers\Money;
use App\Services\Shipments\Packer as ShipmentsPacker;
use App\Services\Shipments\PerSend\ListPackaging;
use Illuminate\Support\Collection;

/**
 * Esta clase representa una cotizacion de un envio, calcula el costo de los productos, que tipo de embalaje debe ser usado,
 * para que posteriormente cada paqueteria traduzca esta informacion segun sus necesidades
 */
class ShippingQuote {

    /**
     * Productos dentro del envio
     *
     * @var array
     */
    private $products = [];
    /**
     * Total de unidades de productos
     *
     * @var int
     */
    private $totalProducts = 0;
    /**
     * Costo total en USD del envio
     *
     * @var float
     */
    private $totalValue = 0;
    /**
     *Represemtacion del embalaje compuesto por una caja y una caja ya empaquetada
     *
     * @var ListPackaging
     */
    private $listPackaging;
    /**
     *
     *
     * @param Address $destination Direccion de envio
     * @param Addresess $addresses direcciones de origen de envio, si es mas de uno significa que el envio esta disponible en
     * multiples sucursales por lo cual hay que buscar el mas barato para encontrar el mejor costo de envio
     * @param Collection $shipmentBoxes Coleccion de cajas predeterminadas para embalar
     */
    public function __construct(
        public readonly Address $destination,
        public readonly Addresess $addresses,
        private readonly Collection $shipmentBoxes,
        private readonly PackagedShipping $packagedShipping)
    {
    }
    public function addProduct(Product $product) {
        $this->totalProducts += $product->quantity;
        $this->totalValue = Money::add($this->totalValue, $product->subtotal());
    }

    /**
     * Calcular el tipo de embalaje (dimensiones y peso)
     * en el que ira el envio ademas  del costo total de los productos
     *
     * @return void
     */
    public function calculate(){
        $products = $this->packagedShipping->getProducts();
        foreach ($products as $product) {
            $this->addProduct($product);
        }
        $this->calculatePackaging();
    }
    /**
     * Valor total del envio
     *
     * @return float
     */
    public function getTotalValue(): float{
        return $this->totalValue;
    }
    /**
     * Total de unidades de productos
     *
     * @return integer
     */
    public function getTotalProducts(): int{
        return $this->totalProducts;
    }
    public function getListPackaging(): ListPackaging{
        if (!isset($this->listPackaging)) {
            throw new \RuntimeException("listPackaging has not been calculated yet.");
        }

        return $this->listPackaging;
    }
    private function calculatePackaging(){
        $this->listPackaging = ShipmentsPacker::calculatePackaging($this->shipmentBoxes, $this->packagedShipping);
    }
}
