<?php
namespace App\Services\Shipments;

use DVDoug\BoxPacker\ItemList;
use DVDoug\BoxPacker\Item;
/**
 * Debemos determinar si por las dimensiones de los productos el envio debe ser mediante pallet o no
 */
enum TypeOfPackaging: string{

    case BOX = 'BOX';
    case PALLET = 'PALLET';
    /**
     * Usaremos un factor de conversion universal para calcular (se podria modificar para usar el de cada paqueteria...)
     */
    private const CONVERSION_FACTOR = 5000;
    /**
     * Cualquier envio mayor o igual a este valor se considera pallet
     */
    private const PALLET_WEIGHT = 68;
    /**
     * Debemos determinar si por las dimensiones de los productos el envio debe ser mediante pallet o no
     *
     * @param ItemList $itemList
     * @return TypeOfPackaging
     */
    public static function fromItems(ItemList $itemList): TypeOfPackaging {

        $weight = 0;
        $volumetricWeight = 0;

        foreach ($itemList as $item) {
            $weight += $item->getWeight() / 1000;
            $volumetricWeight += self::calculateVolumetricWeight($item);
        }

        return $weight >= self::PALLET_WEIGHT || $volumetricWeight >= self::PALLET_WEIGHT ?  self::PALLET : self::BOX;
    }
    private static function calculateVolumetricWeight(Item $item){
        //Dividimos entre diez debido a que los valores son en mm
        $width = $item->getWidth() / 10;
        $length = $item->getLength() / 10;
        $depth = $item->getDepth() / 10;

        return ($width * $length * $depth) / self::CONVERSION_FACTOR;
    }
}
