<?php

namespace App\Services;

use App\Services\Contracts\ShippingServiceInterface;
use App\Services\Paquetexpress\Factory as PaquetexpressApiService;
use App\Services\Fedex\Factory as FedexApiService;
use App\Services\Estafeta\Service as EstafetaService;
use Illuminate\Support\Facades\Log;
use App\Services\SelfPickup\Service as SelfPickup;

class ShippingServiceFactory
{
    public const CUSTOMER_CARRIER = 'customer';

    public function make($carrier): ShippingServiceInterface
    {
        Log::info("factory $carrier");
        switch ($carrier) {
            case 'estafeta':
                return new EstafetaService();
            case 'fedex':
                return FedexApiService::service();
            case 'paquetexpress':
                return PaquetexpressApiService::service();
            case Self::CUSTOMER_CARRIER:
                return new SelfPickup();
            default:
                throw new \InvalidArgumentException("Invalid carrier type: {$carrier}");
        }
    }
    /**
     * Proveedores actuales de paqueterias
     *
     * @return array
     */
    public static function companies(): array{
        return ['paquetexpress', 'fedex', 'estafeta'];
    }
    /**
     * Manejadores disponibles para envios, incluyendo aquellos que no son operados por una paqueteria,
     * por ejemplo pasar a recoger el paquete
     *
     * @return array
     */
    public static function all(): array{
        return ['estafeta', 'paquetexpress', 'fedex', self::CUSTOMER_CARRIER];
    }
}
