<?php
namespace App\Services\Teams;

use App\Models\Customer;
use App\Models\Order;
use App\Services\Teams\AdaptiveCards\OrderPaid as AdaptiveCardOrderPaid;
use App\UseCases\Api\HttpRequestExceptionHandler;
use Exception;
use GuzzleHttp\Client;
use Illuminate\Support\Facades\Log;

class OrderPaid extends HttpRequestExceptionHandler{

    public function __construct(
        private readonly Client $client,
        private readonly string $webhookUrl,
        private readonly Customer $customer,
        private readonly Order $order,
        private readonly array $products)
    {

    }

    public function send(): bool
    {
        try {

            $adaptiveCard = (new AdaptiveCardOrderPaid($this->customer, $this->order, $this->products))->build();

            $response = $this->client->post($this->webhookUrl, [
                'json' => $adaptiveCard
            ]);

            if ($response->getStatusCode() !== 202) {
                Log::error('Failed to send message to Microsoft Teams: ' . $response->getBody());
                return false;
            }

            return true;

        } catch (\Throwable $e) {
            $this->handleHttpRequestException($e, 'Teams:OrderPaid', Exception::class, ['json' => $adaptiveCard]);
        }
    }
}
