<?php
namespace App\UseCases\Api;

use GuzzleHttp\Exception\ClientException;
use GuzzleHttp\Exception\RequestException;
use GuzzleHttp\Exception\ConnectException;
use GuzzleHttp\Exception\ServerException;
use Illuminate\Support\Facades\Log;
use App\Exceptions\Handler;

abstract class HttpRequestExceptionHandler {

    protected function handleHttpRequestException(\Throwable $e, string $serviceName, string $classException, $dataSended = null){

        $exceptionMessages = [
            ConnectException::class => "No se pudo conectar a $serviceName, intente más tarde.",
            ClientException::class => "Error en la solicitud a $serviceName: " . ($e instanceof ClientException ? $e->getResponse()->getStatusCode() : ''),
            ServerException::class => "El servidor de $serviceName encontró un problema " .
                                        ($e instanceof ServerException ? ($e->hasResponse() ? json_encode($e->getResponse()) : '') : ''),
            RequestException::class => "Ocurrió un error inesperado con $serviceName.",
        ];

        $ms = $exceptionMessages[get_class($e)] ?? "Ocurrió un error crítico con $serviceName, contacte al soporte.";

        if($dataSended) Log::error("Data enviada del error en $serviceName: " . json_encode($dataSended, JSON_PRETTY_PRINT));
        Handler::log($e);
        throw new $classException($ms);

    }
}
