<?php

namespace App\UseCases\Order\Customer;

use App\Enums\OrderStatusEnum;
use App\Models\CancellationRequest as ModelsCancellationRequest;
use App\Models\Order;
use App\Models\User;
use App\Notifications\Customer\Order\CancellationRequest as OrderCancellationRequest;
use Illuminate\Support\Facades\DB;

class CancellationRequest{

    public function __construct(
        private readonly Order $order,
        private readonly User $owner)
    {

    }

    public function handle(){

        if ($this->order->hasPendingCancellationRequest()) throw new \Exception("La orden {$this->order->id} ya cuenta con una solicitud de cancelación pendiente.");

        DB::transaction(function () {

            $this->logOfCancellationRequest();

            $this->owner->notify(new OrderCancellationRequest($this->order));
        });
    }
    private function logOfCancellationRequest(){

        ModelsCancellationRequest::create([
            'customer_id' => $this->order->customer_id,
            'order_id' => $this->order->id
        ]);

    }
    public static function canByStatus(Order $order){
        // Verifica si la orden está en un estado que permite solicitar su cancelacion
        return match ($order->status) {
            OrderStatusEnum::PAYMENT_SUBMITTED => true,
            OrderStatusEnum::PENDING_PAYMENT => true,
            OrderStatusEnum::PENDING => true,
            OrderStatusEnum::APPROVED => true,
            OrderStatusEnum::WITH_GUIDE => true,
            OrderStatusEnum::DELIVERED => true,
            default => false
        };
    }
}
