<?php
namespace App\UseCases\Order\Customer\SaveByRequest;

use App\Exceptions\Handler;
use App\Mail\PaidOrder;
use App\Mail\PaidOrderAdmin;
use App\Models\Customer;
use App\Models\Order;
use App\Models\Shipment;
use App\Services\Teams\Factory as NotificationTeams;
use Illuminate\Support\Facades\Mail;

class Notification{
    /**
     * Enviar notificaciones
     * 1. Email para recibir notificaciones generales
     * 2. Notificar mediante Teams, a un grupo general
     * 3. Notificar mediante Teams en base a la sucursal que recibio la orden, una orden puede enviarse a dos sucursales diferentes y resultar en dos envios
     *
     * @return void
     */
    public function __construct(
        public readonly Customer $customer,
        public readonly Order $order,
        public readonly array $productsForNotificationLocal,
        public readonly array $productsForNotificationNational,
        public readonly Shipment|null $localShipment = null,
        public readonly Shipment|null $nationalShipment = null)
    {

    }
    public function handle(){
            try {
                $allProductsForNotification = array_merge($this->productsForNotificationLocal, $this->productsForNotificationNational);

                // Notificación a Teams
                NotificationTeams::notificationOrderPaid($this->customer, $this->order, $allProductsForNotification);
                if($this->localShipment)
                    $this->notifySellers($this->productsForNotificationLocal, $this->localShipment->location_id);
                if($this->nationalShipment)
                    $this->notifySellers($this->productsForNotificationNational, $this->nationalShipment->location_id);
                // Enviar correos
                Mail::to($this->customer->user->email)->send(new PaidOrder($this->order));
                Mail::to(config('app.email_support'))->send(new PaidOrderAdmin($this->order));

            } catch (\Throwable $th) {
                Handler::log($th);
            }
    }

    private function notifySellers($productsForNotification, $locationId){
        if (count($productsForNotification) > 0) {
            NotificationTeams::notificationOrderPaidSellers($this->customer, $this->order, $productsForNotification, $locationId);
        }
    }
    public static function notify(
        Customer $customer,
        Order $order,
        array $productsForNotificationLocal,
        array $productsForNotificationNational,
        Shipment|null $localShipment = null,
        Shipment|null $nationalShipment = null){

            $handler = new self(
                $customer,
                $order,
                $productsForNotificationLocal,
                $productsForNotificationNational,
                $localShipment,
                $nationalShipment);

            return $handler->handle();
        }
}
