<?php

namespace App\UseCases\Order;

use App\Exceptions\Handler;
use App\Models\Order;
use App\Models\OrderItem;
use App\Models\ProductStock;
use Illuminate\Support\Facades\DB;
/**
 * Esta clase restablece el stock vinculado a una orden
 */
class RestockOrderItems
{
    public function __construct(
        private readonly Order $order
    ) {}

    public function handle()
    {
        try {
            DB::transaction(function() {

                $orderItems = OrderItem::select(
                                    'order_items.id',
                                    'order_items.order_id',
                                    'order_items.shipment_id',
                                    'order_items.product_id',
                                    'order_items.quantity',
                                    'order_items.price',
                                    'shipments.location_id')
                                ->join('shipments', 'shipments.id', '=' ,'order_items.shipment_id')
                                ->where('order_items.order_id', $this->order->id)
                                ->get();

                $productStocks = ProductStock::where(function($query) use($orderItems){
                                    foreach ($orderItems as $item) {
                                        $query->orWhere(function($q) use($item){
                                            $q->where('product_id', $item->product_id)
                                                ->where('location_id', $item->location_id);
                                        });
                                    }
                                })
                                ->get();
                $productStocks = $productStocks->groupBy(['product_id', 'location_id']);

                foreach ($orderItems as $item) {

                    $productStock = $productStock = $productStocks[$item->product_id][$item->location_id]->first() ?? null;

                    if ($productStock) {
                        // Incrementa la cantidad disponible
                        $productStock->quantity_available += $item->quantity;
                        $productStock->save();
                    } else {
                        // Opcional: Maneja el caso donde no hay stock registrado
                        \Log::error("Sin registro del stock del producto $item->product_id,
                            en el almacen $item->location_id en la orden $item->order_id");;
                    }
                }

            });

            return true;

        } catch (\Throwable $th) {
            Handler::log($th);
        }

        return false;
    }

}
