<?php

namespace App\UseCases\Shipment;

use App\Models\Shipment;
use App\Models\ShipmentCanceled;
use App\Services\Contracts\ShippingServiceInterface;
use App\Services\Helpers\Result;
use Illuminate\Support\Facades\DB;
/**
 * Cancelar un envío
 * 1- Verifica el estado de entrega del envío
 * 2- Si es cancelable, se solicita la cancelación a la paquetería
 * 3- Se registra la cancelación en la base de datos
 */
class Cancel{

    public function __construct(
        public readonly int $userId,
        public readonly Shipment $shipment,
        public readonly ShippingServiceInterface $shippingService)
    {

    }
    /**
     * Cancelar un envío
    * 1- Verifica el estado de entrega del envío
    * 2- Si es cancelable, se solicita la cancelación a la paquetería
    * 3- Se registra la cancelación en la base de datos
     * @return Result
     */
    public function handle(){
        try {
            $resultTracking = $this->shipment->tracking();

            if (isset($resultTracking->delivery_status)) {

                if ($this->shippingService->canCancel($resultTracking->delivery_status)) {
                    $resultCancel = $this->shippingService->cancel($this->shipment->tracking_number);

                    if ($resultCancel->result()) {

                        $this->logCancellation($resultCancel);

                        return Result::create(true);
                    }

                    return Result::create(false, $resultCancel->error());
                }

                return Result::create(false, __('alerts.admin-shipment-cancel-error-for-status', ['STATUS' => $resultTracking->description]));
            }

            return Result::create(false, __('No es posible obtener el estado del envío'));

        } catch (\Exception $e) {
            DB::rollBack();

            return Result::create(false, __('Ha ocurrido un error al intentar cancelar el envío.'));
        }
    }
    private function logCancellation($resultCancel) {
        DB::beginTransaction();

        ShipmentCanceled::create([
            'shipment_id' => $this->shipment->id,
            'user_id' => $this->userId,
            'tracking_number' => $this->shipment->master_tracking_number,
            'response' => json_encode($resultCancel->data()),
        ]);

        $this->shipment->delivery_status = $resultCancel->code();
        $this->shipment->save();

        DB::commit();
    }
}
