<?php

namespace App\UseCases\Shipment;

use App\Models\Order;
use App\Models\PackageSent;
use App\Models\Shipment;
use App\Models\ShippingBoxUsed;
use App\Services\Contracts\ShippingServiceInterface;
use App\Services\Helpers\Money;
use Illuminate\Support\Facades\DB;

/**
 * Crear una carta porte o guia
 * 1. Solicitar a la paqueteria la carta porte
 * 2. Vincular el tracking al envio
 * 3. Actualizar el estatus de la orden
 * 4. Guardar el embalaje donde sera enviado el paquete
 */
class Guide{

    public function __construct(
        public readonly Shipment $shipment,
        public readonly ShippingServiceInterface $shippingService)
    {

    }

    public function handle(){
        //throw new \Exception("Vamos a probar las paqueterias", 1);

        DB::beginTransaction();

        $result = $this->shippingService->shipping($this->shipment->id);

        $this->shipment->master_tracking_number =  $result->getTrackingNumber();
        $this->shipment->carrier_response =  $result->getJSONResponse();
        $totalAmount = $result->getTotalAmount();

        if($totalAmount) $this->shipment->delivery_amount = $result->getCurrency() === 'MXN' ? Money::convertToDolar($totalAmount) : $totalAmount;

        $this->shipment->save();

        Order::updateStatusWithGuide($this->shipment->order_id);

        PackageSent::savePackedBoxWithContentByShipment($result->getListPackagesSent());

        DB::commit();

        return $result;
    }
}
