<?php

namespace App\UseCases\Shipment;

use Illuminate\Contracts\Cache\Store;
use Illuminate\Support\Facades\Session;

/**
 * Cada que se cotiza el costo del envio de un carrito, necesitamos guardar el costo de dicha cotizacion
 * esto para cuando creemos la orden de compra tengamos la informacion de la cotizacion
 */
class QuotationInCache{

    public function __construct(private Store $storage)
    {

    }
    /**
     * Guardamos la cotizacion, usamos el tiempo de vida de la sesion del usuario como indicador, de igual forma
     *
     * @return void
     */
    public function put(string $type, string $carrier, string $service, string $cost){
        $id = $this->getId($type, $carrier, $service);
        $expires = config('session.lifetime') * 60;
        $this->storage->put($id, $cost, $expires);
    }
    public function get(string $type, string $carrier, string $service): string{
        $id = $this->getId($type, $carrier, $service);
        $cost = $this->storage->get($id);

        if(is_null($cost)) throw new \Exception("No se encontró una cotización disponible ID: $id   COST: $cost", 1);

        return $cost;
    }
    private function getId(string $type, string $carrier, string $service): string {
        $sessionId = Session::getId();
        return "cart_{$sessionId}_quote_{$carrier}_{$type}_{$service}";
    }
}
