<?php

namespace App\UseCases\Shipment;

use App\Models\Shipment;
use App\Services\Contracts\ShippingServiceInterface;
use App\Services\Contracts\Tracking as ShipmentTracking;

class Tracking{

    public function __construct(
        public readonly Shipment $shipment,
        public readonly ShippingServiceInterface $shippingService)
    {

    }

    public function handle(){

        if($this->shipment->isCanceled()) return null;

        try {

            $result = $this->shippingService->tracking($this->shipment->master_tracking_number);

        } catch (\Throwable $th) {
            \Log::error($th->getMessage());
            \Log::error($th->getTraceAsString());

            $data = new \stdClass();
            $data->error = $th->getMessage();

            return $data;
        }
        //Solo actualizamos si el estatus es diferente
        if($this->shipment->delivery_status != $result->getCode()) $this->shipment->updateDeliveryStatusByTracking($result);

        return $this->buildTrackingData($result);
    }
    /**
     * Transformar el resultado del rastreo a un objeto.
     *
     * @param ShipmentTracking $result
     * @return object
     */
    private function buildTrackingData(ShipmentTracking $result)
    {
        $data = new \stdClass();
        $data->description = $result->getDescription();
        $data->delay = $result->getDelay();
        $data->dateTime = $result->getDateTime();
        $data->promiseDeliveryDateTime = $result->getPromiseDeliveryDateTime();
        $data->additionalInfo = $result->getAdditionalInfo();
        $data->historical = $result->getHistorical();
        $data->delivery_status = $result->getCode();
        return $data;
    }
}
