<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('additional_charges', function (Blueprint $table) {
            $table->id();
            $table->decimal('amount', 10, 2);
            $table->enum('charge_type', ['fixed', 'percentage']);
            $table->char('key_name')->unique();
            $table->string('description');
            $table->unsignedBigInteger('user_id');

            $table->foreign('user_id')->references('id')->on('users');
            $table->softDeletes();
            $table->timestamps();
        });

        Schema::create('charge_entities', function (Blueprint $table) {
            $table->id();
            $table->unsignedBigInteger('charge_id');
            $table->char('entity_type', 50)
                ->comment('Tipo de entidad a la que se le debe aplicar el cargo, puede ser a general, categoria, producto, etc.');
            $table->unsignedBigInteger('entity_id')
                ->nullable()
                ->comment('Id de la identidad a la que se le aplica el descuento, de ser general sera nulo');

            $table->foreign('charge_id')->references('id')->on('additional_charges');
            $table->timestamps();
        });

        Schema::create('additional_charges_applied', function (Blueprint $table) {
            $table->id();
            $table->unsignedBigInteger('order_id');
            $table->unsignedBigInteger('charge_entity_id');

            $table->foreign('order_id')->references('id')->on('orders');
            $table->foreign('charge_entity_id')->references('id')->on('charge_entities');
            $table->timestamps();
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::dropIfExists('additional_charges');
        Schema::dropIfExists('charge_entities');
        Schema::dropIfExists('additional_charges_applied');
    }
};
