<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::rename('shipping_boxes_used', 'packages_sent');

        Schema::table('packages_sent', function (Blueprint $table) {
            $table->unsignedBigInteger('shipping_box_id')->nullable()->comment('Si el valor es nulo se considera que el paquete es autoembalaje')->change();
            $table->string('tracking_id', 100)->after('total_items')->comment('Identificador de rastreo unico');

            $table->renameIndex('shipping_boxes_used_shipment_id_foreign', 'packages_sent_shipment_id_foreign');
            $table->renameIndex('shipping_boxes_used_shipping_box_id_foreign', 'packages_sent_shipping_box_id_foreign');
        });

        Schema::rename('shipping_order_item_in_box', 'ordered_items_in_packages_sent');

        Schema::table('ordered_items_in_packages_sent', function (Blueprint $table) {
            $table->renameColumn('shipping_box_used_id', 'packages_sent_id');

            $table->renameIndex('shipping_order_item_in_box_shipping_box_used_id_foreign', 'ordered_items_in_packages_sent_packages_sent_id_foreign');
            $table->renameIndex('shipping_order_item_in_box_order_item_id_foreign', 'ordered_items_in_packages_sent_order_item_id_foreign');
        });

        Schema::table('shipments', function (Blueprint $table) {
            $table->renameColumn('tracking_number', 'master_tracking_number');
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::rename('packages_sent', 'shipping_boxes_used');

        Schema::table('shipping_boxes_used', function (Blueprint $table) {

            $table->string('shipping_box_used_id')->nullable(false)->change();
            $table->dropColumn('tracking_id');

            $table->renameIndex('packages_sended_shipment_id_foreign', 'shipping_boxes_used_shipment_id_foreign');
            $table->renameIndex('packages_sended_shipping_box_id_foreign', 'shipping_boxes_used_shipping_box_id_foreign');
        });

        Schema::rename('ordered_items_in_packages_sent', 'shipping_order_item_in_box');

        Schema::table('shipping_order_item_in_box', function (Blueprint $table) {
            $table->renameColumn('packages_sent_id', 'shipping_box_used_id');

            $table->renameIndex('ordered_items_in_packages_sent_packages_sent_id_foreign', 'shipping_order_item_in_box_shipping_box_used_id_foreign');
            $table->renameIndex('ordered_items_in_packages_sent_order_item_id_foreign', 'shipping_order_item_in_box_order_item_id_foreign');
        });

        Schema::table('shipments', function (Blueprint $table) {
            $table->renameColumn('master_tracking_number', 'tracking_number');
        });
    }
};
