import {Request} from "../../../Helpers/Request";
import { Response } from "../../../Exceptions/Response";

export const CancellationRequest = {
    labels: {
        title: "Confirmación requerida",
        text: `¿Solicitar la cancelación de tu orden?, verificaremos el estatus y, si es posible, procederemos con la cancelación.
        En caso de que tu orden ya haya sido enviada, nos pondremos en contacto contigo para brindarte más detalles.`,
        confirmButtonText: "¡Solicitar cancelación!",
        cancelButtonText: "Cerrar",
    },
    init:function(className){
        document.querySelectorAll("." + className).forEach(element => element.addEventListener('click', CancellationRequest.ask));
    },
    ask: function(){
        const url = this.dataset.url;

        Swal.fire({
            title: CancellationRequest.labels.title,
            text: CancellationRequest.labels.text,
            icon: "warning",
            showCancelButton: true,
            confirmButtonText: CancellationRequest.labels.confirmButtonText,
            showLoaderOnConfirm: true,
            cancelButtonText: CancellationRequest.labels.cancelButtonText,
            confirmButtonColor: "#F34770",
        }).then((result) => {
            if (result.isConfirmed) {
                Request.loadingAlert("Solicitando guía...", () => {
                    CancellationRequest.request(url);
                })
            }
        });
    },
    request: async (url) => {
        try {
            const response = await fetch(url, {
                method: 'POST',
                headers: Request.headers()
            })

            const result = await response.json();

            if(Response.isException(response.status))
                Response.handle(result)
            else{
                Swal.fire({
                    title: result.message,
                    icon: "success"
                  })
                  .then(() => location.reload());
            }
        } catch (error) {
            Swal.fire({ title: "Hubo un problema, intenta en otro momento"})
        }
    },
}
