import { CustomerCarrier } from "./CustomerCarrier";

export const SelfPickup = {
    config: {},
    init(){
        document.getElementById("quote-shipment").addEventListener("click", function(event) {
            if (event.target.classList.contains("selfPickup")) {
                SelfPickup.ask(event.target.dataset.quote);
            }
        });
    },
    /**
     * Hay que cargar la información del envio, en especifico los almacenes donde estan disponibles los
     * productos
     * @param {object} shipment
     * @param {string} quoteType
     */
    load: function(shipment, quoteType){
        SelfPickup.config[quoteType] = shipment;
    },
    htmlOption: function(quoteType, destination, totalAmount, productIds){
        return `
                <tr>
                    <td>
                        <label for="self-pickup-${quoteType}" class="w-100">
                            <input
                                type="radio"
                                name="option-shipment-${quoteType}"
                                id="self-pickup-${quoteType}"
                                class="form-check-input selfPickup"
                                value="self-pickup"
                                data-quote="${quoteType}"
                                data-total="${totalAmount}"
                                data-products="${productIds}"
                                data-destination="${destination}">
                            ${CustomerCarrier.serviceName}
                        </label>
                    </td>
                    <td>$${totalAmount} </td>
                    <td></td>
                </tr>
                <tr>
                    <td colspan="3">
                        <div id="self-pickup-selected-${quoteType}"></div>
                    </td>
                </tr>
                    `;
    },
    ask: function(quoteType){
        Swal.fire({
            title: "<strong>Configurar recogida</strong>",
            icon: "info",
            html: SelfPickup.htmAsk(quoteType),
            allowEscapeKey: false,
            allowOutsideClick: false,
            confirmButtonText: "Aceptar",
            preConfirm: () => {
                const input = document.getElementById(`self-pickup-${quoteType}`);
                const select = document.getElementById(`select-location-for-pickup-${quoteType}`);

                if (select.value === "null") {
                    Swal.showValidationMessage('Debes seleccionar una sucursal');
                    return false;
                }

                SelfPickup.drawLocationSelected(Number(select.value), quoteType);

                return {
                    quoteType: input.dataset.quote,
                    origin: select.value,
                    shippingCost: input.dataset.total,
                    productIds: input.dataset.products,
                    destination: input.dataset.destination,
                };
            }
        }).then((result) => {
            if (result.isConfirmed) {
                const selectedServiceData = {
                    ...CustomerCarrier,
                    ...result.value,
                };

                const storageKey = quoteType === 'Nacional' ? 'selectedNationalShippingService' : 'selectedLocalShippingService';
                sessionStorage.setItem(storageKey, JSON.stringify(selectedServiceData));

                this.validateSelections();
            }
        });
    },
    htmAsk: function(quoteType){
        const addresses = this.config[quoteType]?.addresses?.list || [];

        return `
        <select id="select-location-for-pickup-${quoteType}" class="form-select">
            <option value="null" selected disabled>Selecciona la sucursal</option>
            ${ addresses.map(this.optionAddress).join('') }
        </select>`;
    },
    optionAddress: function(address){
        return `<option value="${address.id}">
                    ${SelfPickup.fullAddress(address)}
                </option>`;
    },
    fullAddress: function(address){
        return `${address.street} ${address.number_ext}, ${address.colonyName}, ${address.city}, ${address.state}`
    },
    validateSelections: function() {
        const localShipping = sessionStorage.getItem('selectedLocalShippingService');
        const nationalShipping = sessionStorage.getItem('selectedNationalShippingService');
        const proceedToPaymentBtn = document.getElementById('proceedToPayment');
        const shippingSelects = document.querySelectorAll('.selectLocation');

        if (shippingSelects.length == 2 && localShipping && nationalShipping) {
            proceedToPaymentBtn.style.display = 'block';
        } else if(shippingSelects.length == 1 && (localShipping || nationalShipping)) {
            proceedToPaymentBtn.style.display = 'block';
        }else
            proceedToPaymentBtn.style.display = 'block';
    },
    drawLocationSelected: function(locationId, quoteType){
        const div = document.getElementById(`self-pickup-selected-${quoteType}`);
        const address = SelfPickup.config[quoteType].addresses.list.find((address) => address.id === locationId);

        if(div && address){
            div.innerHTML = SelfPickup.fullAddress(address);
        }
    },
    clearDrawSelected: function(quoteType){
        const div = document.getElementById(`self-pickup-selected-${quoteType}`);

        if(div) div.innerHTML = "";
    }
}
