import { defaultConfig } from "../../../Helpers/datatables";
import { Addresses } from "./Addresses";

export const List = {
    table: null,
    classDetailAddress: 'details-address',
    config: function() {
        return {
            stateSave: true,
            stateDuration: -1,
            columnDefs: [
                { orderable: false, targets: 0 }
            ],
            createdRow: List.styleToRow,
            columns: [
                {
                    data: null,
                    render: List.renderAlerts
                },
                { data: "username" },
                { data: "rfc" },
                {
                    data: null,
                    render: List.renderStatus
                },
                {
                    data: null,
                    render: List.renderActions
                }
            ]
        }
    },
    init: function(id, data, address){
        List.table = new DataTable(`#${id}`, { ...defaultConfig, ...List.config(), ...{ data: data } });
        Addresses.init(address, `#${id} .${List.classDetailAddress}`);
    },
    renderActions: function(data, type){
        return `
                <div class="btn-group" role="group">
                    <a class="btn btn-info btn-sm" href="${data.links.edit}">
                        Editar
                    </a>
                    <button class="btn btn-danger btn-sm" onclick="confirmDelete(this, '${data.links.destroy}')">
                        Eliminar
                    </button>
                    <button class="btn btn-info btn-sm ${List.classDetailAddress}" data-customer="${data.id}">
                        Direcciones
                    </button>
                </div>`;

    },
    renderStatus: function(data, type){
        return `
            <span class="badge ${data.status == 'active' ? 'bg-success' : 'bg-warning text-dark'}">
                ${data.statusView}
            </span>`;
    },
    renderAlerts: function(data, type){

        const alerts = data.alerts.reduce((html, alert) => {
            html += `
                <i class="bi bi-exclamation-triangle-fill text-danger"></i>
                    <i class="text-danger fs-6">
                        ${alert}
                    </i>
                </i>
            `;
            return html;
        }, '')

        return `
            <div>
                ${data.company_name}
                <div>
                    ${alerts}
                </div>
            </div>
        `;
    },
    styleToRow: function(row, data, dataIndex) {
        if (data.location_id == null) {
            $(row).addClass('table-danger');
        }
    }
}
