import { defaultConfig } from "../../../Helpers/datatables";

export const List = {
    table: null,
    meta: {},
    properties: {
        filter: {
            value: [],
            text: null
        }
    },
    init: function(id, data, meta){
        List.meta = meta;
        List.table = new DataTable(`#${id}`, {
            ...defaultConfig,
            ...List.config(),
            ...{ data: data }
        });
    },
    config: function() {
        return {
            stateSave: true,
            stateDuration: -1,
            order: [[0, 'desc']],
            columns: [
                { data: 'folio' },
                { data: 'company_name' },
                {
                    data: 'totalFormatted',
                    render: List.renderTotalFormatted
                },
                {
                    data: null,
                    render: List.renderStatusView
                },
                { data: 'createdFormatted' },
                {
                    data: 'links',
                    render: List.renderCreatedFormatted
                }
            ],
            layout: {
                topStart: List.selectStatus()
            },
            stateSaveParams: function (settings, data) {
                data.myProperties = List.properties;
            },
            stateLoadParams: List.loadSavedSettings,
            initComplete: List.loadProperties
        }
    },
    renderTotalFormatted: function(data){
        return `
            <div class="text-accent text-center">
                ${data}
            </div>
        `;
    },
    renderStatusView: function(data){
        let cancellationRequest = "";
        if(data.cancellationRequest)
            cancellationRequest = `<br><span class="badge rounded-pill text-light bg-danger">Solicitud de cancelacion</span>`;

        return `
            <span class="badge rounded-pill ${data.statusTextColor}">
                ${data.statusView}
            </span>
            ${cancellationRequest}
        `;
    },
    renderCreatedFormatted: function(data){
        return `
            <div class="d-flex align-items-center justify-content-center">
                <a href="${data.edit}" class="btn btn-info me-2 btn-sm">
                    Detalle
                </a>
            </div>
        `;
    },
    /**
     * Configuraciones extra
     * @param {object} settings
     * @param {object} data
     */
    loadProperties: function(settings, data){
        const select = new TomSelect("#select-options",{
            plugins: ['remove_button'],
            create: true,
            options: List.meta.status,
            valueField: "id",
            labelField: "name",
            items: List.properties.filter.value
        });
        select.on('change', (value) => {
            List.properties.filter.value = value

            List.table
                .search(List.filterByStatus)
                .draw()
        });
    },
    /**
     * Cargar la configuracion guardada en la memoria
     * @param {object} settings
     * @param {object} data
     */
    loadSavedSettings: function (settings, data) {
        if (data.myProperties !== undefined) {
            List.properties = data.myProperties;
            if(List.properties.filter.value.length > 0){

                const table = new $.fn.dataTable.Api( settings );
                table.search(List.filterByStatus)
                    .draw();

            }
        }
    },
    filterByStatus: function(d, row){
        return List.properties.filter.value.length == 0 ? true : List.properties.filter.value.includes(row.status);
    },
    selectStatus: function(){
        const div = document.createElement("DIV");
        div.innerHTML = `
            <select id="select-options" class="swal2-input" multiple="multiple" style="width: 100%;" placeholder="Estatus">
            </select>
        `;
        return div;
    }
}
