import { Response } from "../Exceptions/Response";
import { Request } from "../Helpers/Request";

export const Cancel = {
    labels: {
        title: "Confirmación requerida",
        confirmButtonText: "¡Cancelar y cerrar orden!",
        cancelButtonText: "Cerrar",
    },
    ask: function(){
        const cancellation = this.dataset.cancellation;
        const customerReason = cancellation.length > 0 ? "A petición del cliente" : "";

        Swal.fire({
            title: Cancel.labels.title,
            html: Cancel.html(customerReason),
            icon: "warning",
            showCancelButton: true,
            confirmButtonText: Cancel.labels.confirmButtonText,
            showLoaderOnConfirm: true,
            cancelButtonText: Cancel.labels.cancelButtonText,
            preConfirm: () => {
                const reason = document.getElementById("reason-cancel-order").value;

                if (!reason && reason.trim().length == 0) {
                    Swal.showValidationMessage('Debes indicar un motivo');
                    return false;
                }
                return {
                    reason: reason
                };
            }
        }).then((result) => {
            if (result.isConfirmed) {
                Request.loadingAlert("Cancelando...", () => {
                    Cancel.request(result.value.reason);
                })
            }
        });
    },
    request: async (reason) => {
        try {
            const response = await fetch(window.$routes['orders.cancel'], {
                method: 'POST',
                headers: Request.headers(),
                body: JSON.stringify({
                    reason: reason
                })
            })

            const result = await response.json();

            if(Response.isException(response.status))
                Response.handle(result)
            else{
                Swal.fire({
                    title: result.message,
                    icon: "success"
                  })
                  .then(() => location.reload());
            }
        } catch (error) {
            Swal.fire({ title: "Hubo un problema, intenta en otro momento"})
        }
    },
    html: function(defaultReason){
        return `
                <div>
                    ¿Cancelar y eliminar esta orden?, esta acción es irreversible
                </div>
                <div class="mt-3">
                    <label for="reason-cancel-order">*Motivo</label>
                    <textarea class="form-control" id="reason-cancel-order" rows="3">${defaultReason}</textarea>
                </div>`;
    }
}
