import { Response } from "./../Exceptions/Response";
import { Request } from "./../Helpers/Request";

export const Cancel = {
    labels: {
        title: "Confirmación requerida",
        text: `¿Cancelar y eliminar este envío? Se enviará una solicitud para cancelar la guía a la paqueteria. Esta acción es irreversible
        (dependiendo de la paqueteria podría tener un costo)`,
        confirmButtonText: "¡Cancelar guía!",
        cancelButtonText: "Cerrar",
    },
    ask: function(){
        const shipmentId = this.dataset.shipment;

        Swal.fire({
            title: Cancel.labels.title,
            text: Cancel.labels.text,
            icon: "warning",
            showCancelButton: true,
            confirmButtonText: Cancel.labels.confirmButtonText,
            showLoaderOnConfirm: true,
            cancelButtonText: Cancel.labels.cancelButtonText,
        }).then((result) => {
            if (result.isConfirmed) {
                Request.loadingAlert("Cancelando guía...", () => {
                    Cancel.request(shipmentId);
                })
            }
        });
    },
    request: async (shipmentId) => {
        try {
            const response = await fetch(`${window.$routes['orders.ship.cancel']}/${shipmentId}`, {
                method: 'POST',
                headers: Request.headers()
            })

            const result = await response.json();

            if(Response.isException(response.status))
                Response.handle(result)
            else{
                Swal.fire({
                    title: result.message,
                    icon: "success"
                  })
                  .then(() => location.reload());
            }
        } catch (error) {
            Swal.fire({ title: "Hubo un problema, intenta en otro momento"})
        }
    },
}
