import { Response } from "../../Exceptions/Response";
import { Request } from "../../Helpers/Request";
import { Labels } from "./Labels";
import { Update } from "./Update";
import { CustomerCarrier } from "../../Customer/Shipping/CustomerCarrier";

export const Quotations = {
    /**
     * Respuesta del servidor
     */
    responseQuotations: null,
    /**
     * PAqueterias actuales
     */
    currenCarriers: ["estafeta", "paquetexpress", "fedex"],
    /**
     * Cotizar envio con otras paqueterias
     */
    quote: function(){
        const shipmentId = this.dataset.shipment;
        const carrier = this.dataset.carrier;

        Request.loadingAlert("Cotizando...", () => {
            Quotations.request(shipmentId, carrier);
        })
    },
    /**
     * Solicitar al servidor
     * @param {Number} shipmentId
     * @param {string} currentCarrier
     */
    request: async (shipmentId, currentCarrier) => {
        try {
            const response = await fetch(`${window.$routes['orders.quote']}/${shipmentId}`);
            const result = await response.json();

            if(Response.isException(response.status))
                Response.handle(result)
            else
                Quotations.processResponse(result, shipmentId, currentCarrier);
        } catch (error) {
            Swal.fire({ title: "Hubo un problema", text: error.message })
        }
    },
    /**
     * Procesar respuesta del servidor, le mostramos un swalt con la informacion
     * provista por las paqueterias
     * @param {object} result
     * @param {Number} shipmentId
     * @param {string} currentCarrier
     */
    processResponse: (result, shipmentId, currentCarrier) => {

        Quotations.responseQuotations = result;

        Swal.fire({
            title: 'Seleccione una opción',
            html: Quotations.htmlQuote(result, currentCarrier),
            showCancelButton: true,
            confirmButtonText: 'Aceptar',
            preConfirm: Quotations.processSwalSelection
        }).then((result) => {
            if (result.isConfirmed)
                Update.askUpdateShipment(
                    Quotations.infoByCarrierName(result.value.carrier),
                    result.value.reason,
                    shipmentId
                );
        });
    },
    /**
     *
     * @returns Procesar
     */
    processSwalSelection: function(){

        const selectedOption = document.querySelector('input[name="options"]:checked');
        const reasonCarrier = document.getElementById("reason-carrier").value;

        if (!selectedOption) {
            Swal.showValidationMessage('Debe seleccionar una opción');
            return false;
        }
        if (!reasonCarrier) {
            Swal.showValidationMessage('Debes indicar un motivo');
            return false;
        }
        return {
            carrier: selectedOption.value,
            reason: reasonCarrier
        };
    },
    htmlQuote: (result, currentCarrier) => {
        return `<table class="table">
                    ${ Quotations.rowCustomerCarrier(currentCarrier) }
                    ${ Quotations.rowsQuotations(result) }
                </table>
                <div class="mb-3">
                    <label for="reason-carrier" class="form-label">*Motivo</label>
                    <textarea class="form-control" id="reason-carrier" rows="3"></textarea>
                </div>`;
    },
    rowsQuotations: function(result){
        return Quotations.currenCarriers.reduce((rows, carrierName) => {
            rows += Quotations.rowQuote(carrierName,  result);
            return rows;
        }, "");
    },
    rowCustomerCarrier: function(currentCarrier){
        return currentCarrier !== 'customer' ? Quotations.htmlRowQuote(CustomerCarrier) : '';
    },
    rowQuote: (carrierName, result) => {
        if(result.hasOwnProperty(carrierName)){
            return result[carrierName].hasOwnProperty("error") ?
                    Quotations.htmlRowQuoteError(result[carrierName].error) :
                    Quotations.htmlRowQuote(
                        Quotations.infoByCarrierName(carrierName)
                    );
        }
        return "";
    },
    htmlRowQuote: (carrierInfo) => {
        return `<tr>
                    <td class="bg-primary text-white" colspan="2">
                        <label for="${carrierInfo.carrier}">
                            <strong>${Labels.carrierName(carrierInfo.carrier)}</strong>
                            <input type="radio" id="${carrierInfo.carrier}" name="options" value="${carrierInfo.carrier}">
                        </labelcarrierInfo.>
                    </td>
                </tr>
                <tr>
                    <td class="bg-primary text-white">
                        <span>Costo</span>:
                    </td>
                    <td>
                        <strong>$${carrierInfo.cost} MNX</strong>
                    </td>
                </tr>
                <tr>
                    <td class="bg-primary text-white">
                        <span>Servicio</span>:
                    </td>
                    <td>
                        <strong>${carrierInfo.serviceCode}</strong>
                    </td>
                </tr>`
    },
    htmlRowQuoteError: (error) => {
        return `<tr>
                    <td colspan="2">${error}</td>
                </tr>`
    },
    /**
     * Obtener la informacion del proveedor del envio, puede ser provista por el servidor o la clase CustumerCarrier,
     * que es cuando el cliente se hace cargo del envio
     * @param {string} carrier
     */
    infoByCarrierName: function(carrier){

        if(carrier == CustomerCarrier.carrier) return CustomerCarrier;

        return {
            carrier : Quotations.responseQuotations[carrier].carrier,
            cost: Quotations.responseQuotations[carrier].Quotation[0].Service[0].TotalAmount,
            serviceName: Quotations.responseQuotations[carrier].Quotation[0].Service[0].ServiceName,
            serviceCode: Quotations.responseQuotations[carrier].Quotation[0].Service[0].ServiceCode
        }
    }
}
