import { Shipment } from "../Shipment";
import { Response } from "../../Exceptions/Response";
import { Request } from "../../Helpers/Request";
import { Labels } from "./Labels";

export const Update = {
    askUpdateShipment(carrierInfo, reason, shipmentId){

        const labels = Labels.byCarrier(carrierInfo);

        Swal.fire({
            title: labels.title,
            html: labels.html,
            icon: "warning",
            showCancelButton: true,
            confirmButtonText: labels.confirmButtonText,
            showLoaderOnConfirm: true,
            cancelButtonText: labels.cancelButtonText,
          }).then((result) => {
                if (result.isConfirmed) {
                    Request.loadingAlert("Solicitando guía", () => {
                        Update.request(carrierInfo, reason, shipmentId);
                    })
                }
          });
    },
    request: async (carrierInfo, reason, shipmentId) => {
        try {
            const response = await fetch(
                `${window.$routes['orders.update.ship']}/${shipmentId}`,
                {
                    method: 'POST',
                    headers: Request.headers(),
                    body: JSON.stringify({
                        carrier: carrierInfo.carrier,
                        service_code: carrierInfo.serviceCode,
                        shipping_cost: carrierInfo.cost,
                        reason: reason
                    })
                }
            );
            const result = await response.json();

            if(Response.isException(response.status)){
                Response.handle(result, () => location.reload())
            }
            else
                Shipment.processResponse(result, carrierInfo.carrier);
        } catch (error) {
            Swal.fire({ title: "Hubo un problema", text: error.message })
        }
    },
}
