import { Shipment } from "./Shipment";
import { Response } from "./../Exceptions/Response";
import { Request } from "./../Helpers/Request";
import { Labels } from "./Labels";

export const Ship = {
    askToShip: function(){

        const shipmentId = this.dataset.shipment;
        const labels = Labels.byCarrier(this.dataset.carrier);

        Swal.fire({
            title: labels.title,
            text: labels.text,
            icon: "warning",
            showCancelButton: true,
            confirmButtonText: labels.confirmButtonText,
            showLoaderOnConfirm: true,
            cancelButtonText: labels.cancelButtonText,
        }).then((result) => {
            if (result.isConfirmed) {
                Request.loadingAlert("Procesando ...", () => {
                    Ship.requestShip(shipmentId, this.dataset.carrier);
                })
            }
        });
    },
    requestShip: async (shipmentId, carrier) => {
        try {
            const response = await fetch(`${window.$routes['orders.ship']}/${shipmentId}`, {
                method: 'POST',
                headers: Request.headers()
            })

            const result = await response.json();

            if(Response.isException(response.status))
                Response.handle(result)
            else
                Shipment.processResponse(result, carrier);
        } catch (error) {
            Swal.fire({ title: "Hubo un problema, intenta en otro momento"})
        }
    },
}
