document.addEventListener('DOMContentLoaded', function () {
    // Filter by Product (Desktop):
    const searchInput = document.getElementById('search-products');
    const autocompleteList = document.getElementById('autocomplete-list');
    const searchIcon = document.querySelector('.bi-search');

    if (searchInput) {

        searchInput.addEventListener('input', (e) => {
            const searchTerm = e.target.value;
            document.body.style.backgroundColor = "transparent";

            if (searchTerm.length) {
                searchIcon.style.display = 'none'; // Ocultar el ícono al escribir
                fetch(`/buscar-productos?search_term=${searchTerm}`)
                .then(response => response.json())
                .then(data => {
                    // Asegura que la lista esté vacía antes de agregar nuevos resultados
                    autocompleteList.innerHTML = '';
                    autocompleteList.classList.remove('invisible');

                    // Asegúrate de que data.products exista y tenga elementos
                    if (data.products && data.products.length > 0) {
                        const list = document.createElement('ul');
                        list.classList.add('list-group');
                        data.products.forEach(product => {
                            const item = document.createElement('li');
                            item.classList.add('list-group-item');
                            item.textContent = `${product.name} - ${product.brand}`;
                            item.style.cursor = 'pointer';

                            // Evento click para cada ítem
                            item.addEventListener('click', () => {
                                // Redirigir al usuario. Modifica según la lógica de tu aplicación.
                                window.location.href = `/producto/${product.id}`;
                            });

                            list.appendChild(item);
                        });

                        autocompleteList.appendChild(list);
                    } else {
                        autocompleteList.classList.add('invisible');
                    }
                })
                .catch(error => console.error('Error:', error));
            } else {
                autocompleteList.classList.add('invisible');
                searchIcon.style.display = ''; // Mostrar el ícono si el input está vacío
            }
        });

        // Ocultar la lista desplegable cuando se hace clic fuera del área del buscador o la lista
        document.addEventListener('click', (e) => {
            if (!autocompleteList.contains(e.target) && !searchInput.contains(e.target)) {
                autocompleteList.classList.add('invisible');
                if (searchInput.value === '') {
                    searchIcon.style.display = ''; // Mostrar el ícono si el input está vacío
                }
            }
        });
    }

    // Repite el mismo proceso para la versión móvil
    const searchInputM = document.getElementById('search-products-m');
    const autocompleteListM = document.getElementById('autocomplete-list-m');
    const searchIconM = document.querySelector('.search-m');

    searchInputM.addEventListener('input', (e) => {
        const searchTerm = e.target.value;

        if (searchTerm.length) {
            searchIconM.style.display = 'none'; // Ocultar el ícono al escribir
            fetch(`/buscar-productos?search_term=${searchTerm}`)
            .then(response => response.json())
            .then(data => {
                // Asegura que la lista esté vacía antes de agregar nuevos resultados
                autocompleteListM.innerHTML = '';
                autocompleteListM.classList.remove('invisible');

                // Asegúrate de que data.products exista y tenga elementos
                if (data.products && data.products.length > 0) {
                    const list = document.createElement('ul');
                    list.classList.add('list-group');
                    data.products.forEach(product => {
                        const item = document.createElement('li');
                        item.classList.add('list-group-item');
                        item.textContent = `${product.name} - ${product.brand}`;
                        item.style.cursor = 'pointer';

                        // Evento click para cada ítem
                        item.addEventListener('click', () => {
                            // Redirigir al usuario. Modifica según la lógica de tu aplicación.
                            window.location.href = `/producto/${product.id}`;
                        });

                        list.appendChild(item);
                    });

                    autocompleteListM.appendChild(list);
                } else {
                    autocompleteListM.classList.add('invisible');
                }
            })
            .catch(error => console.error('Error:', error));
        } else {
            autocompleteListM.classList.add('invisible');
            searchIconM.style.display = ''; // Mostrar el ícono si el input está vacío
        }
    });

    // Ocultar la lista desplegable cuando se hace clic fuera del área del buscador o la lista
    document.addEventListener('click', (e) => {
        if (!autocompleteListM.contains(e.target) && !searchInputM.contains(e.target)) {
            autocompleteListM.classList.add('invisible');
            if (searchInputM.value === '') {
                searchIconM.style.display = ''; // Mostrar el ícono si el input está vacío
            }
        }
    });


    // ----------------------------------------------------------
    // Filter By Category
    const categorySelect = document.getElementById('category-id');

    if (categorySelect) {
        categorySelect.addEventListener('change', function() {
            const categoryId = this.value;
            const searchParams = new URLSearchParams(window.location.search);

            // Actualiza o añade category_id a los parámetros de búsqueda
            searchParams.set('category_id', categoryId);

            // Redirige manteniendo el parámetro de marca si ya estaba establecido
            window.location.href = `${window.location.origin}/productos/?${searchParams.toString()}`;
        });
    }

    // ----------------------------------------------------------
    // Filter By Brand (Asegúrate de corregir esto para que funcione con la lógica de filtro actualizada)
    const brandSelect = document.getElementById('brand');

    if (brandSelect) {

        brandSelect.addEventListener('change', function() {
            const brand = this.value;
            const searchParams = new URLSearchParams(window.location.search);

            // Actualiza o añade brand a los parámetros de búsqueda
            if(brand) {
                searchParams.set('brand', brand);
            } else {
                searchParams.delete('brand'); // Remueve el parámetro si "Todos" es seleccionado
            }

            // Redirige manteniendo los parámetros existentes
            window.location.href = `${window.location.origin}/productos/?${searchParams.toString()}`;
        });
    }

});
