import { SelfPickup } from "./Customer/Shipping/SelfPickup";

const ErrorRequest = {
    async handler(response) {
        try {
            const data = await response.json();
            if(data.hasOwnProperty("message"))
                Swal.fire({
                    title: data.message,
                    icon: "error"
                });
            else
                Swal.fire({
                    title: 'Hubo un problema al cotizar, intenta de nuevo o contacta a soporte',
                    icon: "error"
                });
        } catch (error) {
            console.log(error);
        }
    }
}
document.addEventListener('DOMContentLoaded', function () {
    SelfPickup.init();
    sessionStorage.removeItem('selectedLocalShippingService');
    sessionStorage.removeItem('selectedNationalShippingService');

    const proceedToPaymentBtn = document.getElementById('proceedToPayment');
    const shippingSelects = document.querySelectorAll('.selectLocation');

    function validateSelections() {
        const localShipping = sessionStorage.getItem('selectedLocalShippingService');
        const nationalShipping = sessionStorage.getItem('selectedNationalShippingService');

        if (shippingSelects.length == 2 && localShipping && nationalShipping) {
            proceedToPaymentBtn.style.display = 'block';
        } else if(shippingSelects.length == 1 && (localShipping || nationalShipping)) {
            proceedToPaymentBtn.style.display = 'block';
        }else
            proceedToPaymentBtn.style.display = 'none';
    }
    // Cotización de envíos por APIs de paqueterías:
    shippingSelects.forEach(select => {
        select.addEventListener('change', function() {
            let location = this.name.split('[')[1].split(']')[0];
            let addressId = this.value;
            let subtableContainer = document.getElementById(`subtable-${location}`);
            let loader = document.getElementById('shippingLoader');
            subtableContainer.querySelector('tbody').innerHTML = "";
            // Mostrar el loader
            loader.classList.remove('d-none');

            fetch('/shipping/quoter', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                    'X-CSRF-TOKEN': document.querySelector('meta[name="csrf-token"]').getAttribute('content'),
                    'Accept': 'application/json'
                },
                body: JSON.stringify({ location: location, address: addressId })
            })
            .then(async response => {
                // Ocultar el loader después de recibir la respuesta
                loader.classList.add('d-none');

                if(response.status !== 200 ) return ErrorRequest.handler(response);

                let subtableHtml = '';

                const data = await response.json();

                SelfPickup.load(data.shipment, data.quoteType);

                Object.keys(data.quotes).forEach(carrier => {
                    const quote = data.quotes[carrier];

                    if (quote.error) {
                        console.warn(`Error from ${carrier}: ${quote.error}`);
                        return;
                    }

                    const origin = quote.origin;
                    const destination = quote.destination;

                    const cheapestService = quote.Quotation[0].Service.reduce((prev, curr) => {
                        return (prev.TotalAmount < curr.TotalAmount) ? prev : curr;
                    });

                    const totalAmount = new Intl.NumberFormat('es-MX', { style: 'currency', currency: 'MXN' }).format(cheapestService.TotalAmount);

                    subtableHtml += `
                        <tr>
                            <td>
                                <label for="${cheapestService.ServiceName}-${data.quoteType}" class="w-100">
                                    <input
                                        type="radio"
                                        name="option-shipment-${data.quoteType}"
                                        id="${cheapestService.ServiceName}-${data.quoteType}"
                                        class="form-check-input quote-option"
                                        value="${carrier}"
                                        data-service='${JSON.stringify(cheapestService)}'
                                        data-origin="${origin.id}"
                                        data-destination="${destination.id}"
                                        data-addressid="${addressId}"
                                        data-products="${data.productsIds}"
                                        data-type="${data.quoteType}">
                                    ${carrier}
                                </label>
                            </td>
                            <td> ${totalAmount} </td>
                            <td> ${cheapestService.ServiceName} </td>
                        </tr>
                    `;
                });
                subtableHtml += SelfPickup.htmlOption(
                                    data.quoteType,
                                    addressId,
                                    data.selfPickupCost,
                                    data.productsIds);

                if (subtableHtml === '') {
                    Swal.fire({
                        position: "center",
                        icon: "warning",
                        title: "No se pudo obtener cotización de ninguna paquetería.",
                        showConfirmButton: false,
                        timer: 5000,
                    });
                } else {
                    subtableContainer.querySelector('tbody').innerHTML = subtableHtml;
                    subtableContainer.classList.remove('d-none');

                    // Re-attach event listeners to the new radio buttons
                    document.querySelectorAll('.quote-option').forEach(radio => {
                        radio.addEventListener('change', function() {

                            let selectedCarrier = this.value;
                            let selectedService = JSON.parse(this.dataset.service);
                            let quoteType = this.dataset.type;
                            let originId = this.dataset.origin;
                            let destinationId = this.dataset.destination;
                            let addressId = this.dataset.addressid;
                            console.log(`Paquetería ${selectedCarrier} Tipo: ${quoteType}, Origen ${originId} Destino ${destinationId} AddressId: ${addressId}`)
                            console.log("-------------------------------------------------------------")

                            let selectedServiceData = {
                                serviceCode: selectedService.ServiceCode,
                                carrier: selectedCarrier,
                                quoteType: quoteType,
                                serviceName: selectedService.ServiceName,
                                shippingCost: selectedService.TotalAmount,
                                origin: originId,
                                destination: destinationId,
                                productIds: this.dataset.products
                            };

                            if(quoteType === 'Nacional') {
                                sessionStorage.setItem('selectedNationalShippingService', JSON.stringify(selectedServiceData));
                            } else {
                                sessionStorage.setItem('selectedLocalShippingService', JSON.stringify(selectedServiceData));
                            }
                            SelfPickup.clearDrawSelected(quoteType);
                            // Validar selecciones después de cada cambio
                            validateSelections();
                        });
                    });
                }
            })
            .catch(error => {
                console.error('Error:', error);
                Swal.fire({
                    position: "center",
                    icon: "error",
                    title: "Ocurrió un error al obtener la cotización de envío. Por favor, inténtelo de nuevo.",
                    showConfirmButton: false,
                    timer: 5000,
                });
                loader.classList.add('d-none'); // Hide loader in case of error
            });
        });
    });

    // Obtención de envios seleccionados por medio del localstorage y envio de formulario
    proceedToPaymentBtn.addEventListener('click', function(e) {
        e.preventDefault();

        let localShippingData = sessionStorage.getItem('selectedLocalShippingService');
        let nationalShippingData = sessionStorage.getItem('selectedNationalShippingService');

        if (localShippingData) {
            document.getElementById('localShippingData').value = localShippingData;
        }
        if (nationalShippingData) {
            document.getElementById('nationalShippingData').value = nationalShippingData;
        }

        // Borrar las claves de sessionStorage antes de enviar el formulario
        sessionStorage.removeItem('selectedLocalShippingService');
        sessionStorage.removeItem('selectedNationalShippingService');

        document.getElementById('shipping-form').submit();
    });
});
