@extends('layouts.app')

@section('content')
<div class="container-fluid">
    <div class="row justify-content-between">
        <h1 class="col-12">
            Orden {{$order->id}}
        </h1>
        <div class="col-xxl-8 col-xl-8 col-lg-8 col-auto">
            <div class="card bg-white">
                <div class="d-flex flex-row p-2">
                    <div class="mt-2 text-end">
                        <span class="fw-bold me-2">Status</span>
                        @include('components.order-status',['status' => $order->status])
                        @isset($order->cancellationRequest)
                            <br><span class="badge text-bg-danger">Solicitud de cancelación</span>
                        @endisset
                    </div>
                </div>
                <hr>
                <div class="table-responsive p-2">
                    <table class="table table-borderless">
                        <tbody>
                            <tr class="add">
                                <td clas>Cliente</td>
                                <td>Fecha de Orden</td>
                            </tr>
                            <tr class="content">
                                <td>
                                    <span class="fw-bold">Razón Social: </span>{{$order->customer->company_name}} <br>
                                    <span class="fw-bold">Contacto: </span> {{$order->customer->user->name}}<br>
                                    <span class="fw-bold">Correo: </span> {{$order->customer->user->email}}<br>
                                </td>
                                <td>
                                    <span class="fw-bold">{{\App\Helpers\Dates::formatForUser($order->created_at)}}</span> <br>
                                </td>
                            </tr>
                        </tbody>
                    </table>
                </div>
                <hr>
                <div class="table-responsive p-2">
                    <table class="table table-borderless">
                        <tbody>
                            <tr class="fw-bold text-center">
                                <th>Imagen</th>
                                <td>Netsuit Item</td>
                                <th>Producto</th>
                                <th>Cantidad</th>
                                <th>Precio</th>
                                <th>Total</th>
                            </tr>
                            @foreach ($shipments as $shipment)
                                <tr>
                                    <td colspan="6" class="bg-primary text-center">
                                        <strong>{{ $shipment->is_local_shipping ?  'Local' : 'Nacional' }}</strong>
                                    </td>
                                </tr>
                                @foreach ($itemsGroupedByShipping[$shipment->id] as $item)
                                    <tr class="content">
                                        <td>
                                            @if (Storage::exists($item->featured))
                                                <img src="{{ Storage::url($item->featured) }}" class="rounded"  width="100">
                                            @endif
                                        </td>
                                        <td>{{$item->netsuite_item}}</td>
                                        <td>{{$item->name}}</td>
                                        <td>{{$item->quantity}}</td>
                                        <td>${{$item->price}}</td>
                                        <td class="text-center">
                                            ${{$item->price * $item->quantity}}
                                        </td>
                                    </tr>
                                @endforeach
                            @endforeach
                        </tbody>
                    </table>
                </div>
                <hr>
                <div class="table-responsive p-2">
                    <table class="table table-borderless">
                        <tbody>
                            @if (count($additionalCharges) > 0)
                                <tr>
                                    <td colspan="4" class="text-center">
                                        <strong>
                                            Cargos extra
                                        </strong>
                                    </td>
                                </tr>
                                @foreach ($additionalCharges as $additionalCharge)
                                    <tr>
                                        <td colspan="3">
                                            {{ $additionalCharge->description }}
                                        </td>
                                        <td class="text-end">
                                            $ {{$additionalCharge->charge_type == 'fixed' ? '' : '%' }} {{ $additionalCharge->amount }}
                                        </td>
                                    </tr>
                                @endforeach
                            @endif
                            <tr class="add">
                                <td></td>
                                <td></td>
                                <td></td>
                                <td class="text-end fw-bold">Total</td>
                            </tr>
                            <tr class="content">
                                <td></td>
                                <td></td>
                                <td></td>
                                <td class="text-end fw-bold">
                                    <x-amount-formatter :amount="$order->total" />
                                </td>
                            </tr>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
        <div class="col-xxl-4 col-xl-4 col-lg-4 col-12">
            <div class="row">
                {{-- Status --}}
                @if ($can_update)
                    <div class="col-md-12 mb-3">
                        <div class="card border border-0 shadow-sm">
                            <div class="card-header border-0 bg-white">
                                <h5>Actualizar Status</h5>
                            </div>
                            <div class="card-body bg-white">
                                <form action="{{route('admin.orders.update.status', $order)}}" method="POST">
                                    @csrf
                                    <div class="container">
                                        <div class="row">
                                            <div class="col-md-12">
                                                <div class="mb-3">
                                                    <div class="form-floating @error('status') is-invalid @enderror">
                                                        <select
                                                            class="form-select @error('status') is-invalid @enderror"
                                                            id="status"
                                                            name="status">
                                                            <option value="">Selecciona una opción</option>
                                                            @foreach (App\Enums\OrderStatusEnum::catalog() as $status)
                                                                <option
                                                                        value="{{$status}}"
                                                                        @selected($order->status == $status)
                                                                    >
                                                                    {{ __('order.status-' . $status) }}
                                                                </option>
                                                            @endforeach
                                                        </select>
                                                        <label for="company-name">Status de la orden</label>
                                                    </div>
                                                    <div class="invalid-feedback">
                                                        @error('status')
                                                            <strong>{{$message}}</strong>
                                                        @enderror
                                                    </div>
                                                </div>
                                                <button type="submit" class="btn btn-primary text-center">Actualizar</button>
                                                @if ($can_cancel)
                                                    <button type="button" class="btn btn-danger btnAskForCancelOrder"
                                                        data-cancellation="{{$order->cancellationRequest}}">
                                                        Cancelar y cerrar orden
                                                    </button>
                                                @endif
                                            </div>
                                        </div>
                                    </div>
                                </form>
                            </div>
                        </div>
                    </div>
                @endif
                @if ($can_update)
                    {{-- Factura --}}
                    <div class="col-md-12 mb-3">
                        <div class="card border border-0 shadow-sm">
                            <div class="card-header border-0 bg-white">
                                <h5>Actualizar Factura</h5>
                            </div>
                            <div class="card-body bg-white">
                                <form action="{{route('admin.orders.update.invoice', $order)}}" method="POST" enctype="multipart/form-data">
                                    @csrf
                                    <div class="container">
                                        <div class="row">
                                            <div class="col-md-12">
                                                <div class="mb-3">
                                                    <div class="form-floating @error('invoice') is-invalid @enderror">
                                                        <input
                                                            class="form-control @error('invoice') is-invalid @enderror"
                                                            type="file"
                                                            id="invoice"
                                                            name="invoice"
                                                        >
                                                        <label for="name">Ficha técnica</label>
                                                    </div>
                                                    <div class="invalid-feedback">
                                                        @error('invoice')
                                                            <strong>{{$message}}</strong>
                                                        @enderror
                                                    </div>
                                                </div>
                                                <button type="submit" class="btn btn-primary text-center">Actualizar</button>
                                                @if ($order->invoice)
                                                    <a
                                                        href="{{Storage::url($order->invoice)}}"
                                                        class="btn btn-outline-accent float-end"
                                                        download="">
                                                        Descargar
                                                    </a>
                                                @endif
                                            </div>
                                        </div>
                                    </div>
                                </form>
                            </div>
                        </div>
                    </div>
                @endif
            </div>
        </div>
        <div class="col-12">
            <div class="card bg-white mt-2">
                <h5 class="text-center mt-2">Envio</h5>
                <div class="accordion accordion-flush" >
                    @foreach ($shipments as $shipment)
                        @php
                            $item = $trackings->firstWhere('shipment_id', $shipment->id);
                        @endphp
                        <x-accordion.item>
                            <x-slot:title>
                                <strong class="{{$shipment->isCanceled() ? 'text-danger' : ''}}">
                                    {{ $shipment->is_local_shipping ?  'Local' : 'Nacional' }} {{$shipment->isCanceled() ? '(Cancelado)' : ''}}
                                </strong>
                            </x-slot>
                            <x-slot:key>shipment-{{$shipment->id}}</x-slot>
                            <x-slot:content>
                                @include('customer_support.orders.shipment', [
                                    'shipment' => $shipment,
                                    'tracking' => $item['tracking'],
                                    'can_update' => $can_update,
                                    'packagesSent' => array_filter($packagesView, fn($item) => $item->shipmentId == $shipment->id),
                                    'proposePackages' => array_filter($proposePackagesView, fn($item) => $item->shipmentId == $shipment->id),
                                ])
                            </x-slot>
                        </x-accordion.item>
                    @endforeach
                </div>
            </div>
        </div>
    </div>
</div>
@endsection
@section('scripts')
    <script>
        window.$clearPathDefault = function (string){
            string = string.replace(/\/0/, '');
            if(string.match(/\/0/) == null)
                return string;
            return window.$clearPathDefault(string);
        }
        window.$routes = {
            "orders.ship": window.$clearPathDefault("{{route('admin.orders.ship', ['shipment_id' => 0])}}"),
            "orders.quote": window.$clearPathDefault("{{route('admin.orders.quote', ['shipment_id' => 0])}}"),
            "orders.update.ship": window.$clearPathDefault("{{route('admin.orders.update.ship', ['shipment_id' => 0])}}"),
            "orders.ship.cancel": window.$clearPathDefault("{{route('admin.orders.ship.cancel',  ['shipment_id' => 0])}}"),
            "orders.cancel": window.$clearPathDefault("{{route('admin.orders.cancel', ['id' => $order->id])}}")
        }
    </script>
    @vite('resources/js/CustomerSupport/Orders/Edit/app.js')
    <script type="module">
        document.addEventListener('DOMContentLoaded', () => {

            ViewerPackaging.init({{ Js::from(array_merge($packagesView, $proposePackagesView)) }});

            document.querySelectorAll(".btnAskToShip").forEach(element => element.addEventListener('click', Ship.askToShip))
            document.querySelectorAll(".btnQuoteOthers").forEach(element => element.addEventListener('click', Quotations.quote))
            document.querySelectorAll(".btnShowShippingLabel").forEach(element => element.addEventListener("click", Shipment.showShippingLabel))
            document.querySelectorAll(".btnAskToCancelShipment").forEach(element => element.addEventListener("click", Cancel.ask))
            document.querySelectorAll(".btnAskForCancelOrder").forEach(element => element.addEventListener("click", CancelOrder.ask))
            document.querySelectorAll(".btnHowToPack").forEach(element => element.addEventListener("click", ViewerPackaging.show))

        });

    </script>
    @if (session('message'))
        <script>
            Swal.fire({
                position: "center",
                icon: "{{ session('icon') }}",
                title: "{{ session('message') }}",
                showConfirmButton: false,
                timer: 5000,
            });
        </script>
    @endif
@endsection
