<!doctype html>
<html lang="{{ str_replace('_', '-', app()->getLocale()) }}">

<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">

    <link rel="apple-touch-icon" sizes="180x180" href="{{ asset('favicon/solar-center-favicon_32x32.webp') }}">
    <link rel="icon" type="image/webp" sizes="32x32" href="{{ asset('favicon/solar-center-favicon_32x32.webp') }}">
    <link rel="icon" type="image/webp" sizes="16x16" href="{{ asset('favicon/solar-center-favicon_32x32.webp') }}">
    <link rel="manifest" href="{{ asset('favicon/site.webmanifest') }}">

    <!-- CSRF Token -->
    <meta name="csrf-token" content="{{ csrf_token() }}">

    <title>Solar Center</title>

    <link rel="preconnect" href="https://fonts.googleapis.com">
    <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
    <link href="https://fonts.googleapis.com/css2?family=Rubik:wght@300;400;500;600;700&display=swap" rel="stylesheet">

    <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/tiny-slider/2.9.4/tiny-slider.css">
    <style>
        #sideDiv {
            transition: all 0.5s ease;
        }

        .hidden {
            right: -500px; /* Oculto al lado derecho */
            opacity: 0;
            z-index: -1;
            position: relative;
        }

        .visible-right {
            right: 0; /* Visible al lado derecho */
            opacity: 1;
            z-index: 1;
        }

    </style>

    <!-- Scripts -->
    @vite(['resources/sass/base.scss', 'resources/js/app.js', 'resources/js/theme.js'])
    <style>
        .filter-products {
            position: relative;
            /* Hace que el posicionamiento absoluto del hijo se base en este contenedor */
        }

        #autocomplete-list,
        #autocomplete-list-m {
            position: absolute;
            top: 100%;
            /* Sitúa el div justo debajo del input */
            left: 0;
            width: 100%;
            /* Iguala el ancho del input */
            z-index: 1000;
            /* Asegura que se muestre sobre otros elementos */
            background-color: white;
            /* O cualquier color de fondo que prefieras */
            /* border: 1px solid #ccc; */
            border-top: none;
            /* Elimina el borde superior para una transición suave desde el input */
        }

        .list-group-item {
            padding: 10px;
            /* Ajusta el padding según sea necesario */
            cursor: pointer;
            /* Indica que los elementos son clicable */
        }

        .list-group-item:hover {
            background-color: #f8f9fa;
            /* Cambia el color de fondo al pasar el ratón por encima para mejorar la interactividad */
        }
    </style>
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/simplebar@latest/dist/simplebar.css" />

    @yield('head')
</head>

<body class="bg-white">
    <div id="app" style="flex: 1 0 auto;">
        <header class="shadow-sm">
            @php
                $route_name = Route::currentRouteName();
            @endphp
            <!-- Topbar-->
            @if ($route_name != 'login')
                <!-- Remove "navbar-sticky" class to make navigation bar scrollable with the page.-->
                <div class="navbar-sticky bg-light">

                    <div class="navbar navbar-expand-lg navbar-light">
                        <div class="container">
                            <a class="navbar-brand d-none d-sm-block me-3 flex-shrink-0" href="/">
                                <img src="{{ asset('images/logo.webp') }}" width="142" alt="Solar Center">
                            </a>
                            <a class="navbar-brand d-sm-none me-2" href="/">
                                <img src="{{ asset('images/logo.webp') }}" width="74" alt="Solar Center">
                            </a>
                            <!-- Search-->
                            <div class="input-group d-none d-lg-flex flex-nowrap mx-4" class="filter-products">
                                {{-- Filter By Input --}}
                                <i class="bi bi-search z-1 position-absolute top-50 start-0 translate-middle-y ms-3" style="opacity: .5;"></i>
                                <input class="form-control rounded-start w-100" type="text" id="search-products" placeholder="">
                                <div class="position-absolute" id="autocomplete-list" style="z-index: 1000; width: 100%;"></div>
                                {{-- Filter By Category --}}
                                <select class="form-select flex-shrink-0" id="category-id" name="category_id"
                                    style="width: 10.5rem;">
                                    <option value="">Categoría</option>
                                    @foreach ($categories as $category)
                                        <option value="{{ $category->id }}" @selected(request('category_id') == $category->id)>
                                            {{ $category->name }}
                                        </option>
                                    @endforeach
                                </select>
                                {{-- Filter By Brand --}}
                                <select class="form-select flex-shrink-0" id="brand" name="brand" style="width: 10.5rem;">
                                    <option value="">Marca</option>
                                    @foreach ($brands as $brand)
                                        <option value="{{ $brand->value }}" @selected(request('brand') == $brand->value)>
                                            {{ $brand->value }}
                                        </option>
                                    @endforeach
                                </select>
                            </div>
                            <!-- Toolbar-->
                            <div class="navbar-toolbar d-flex flex-shrink-0 align-items-center">
                                <button class="navbar-toggler" type="button" data-bs-toggle="collapse"
                                    data-bs-target="#navbarCollapse">
                                    <span class="navbar-toggler-icon"></span>
                                </button>
                                <a class="navbar-tool navbar-stuck-toggler" href="#">
                                    <span class="navbar-tool-tooltip">Toggle menu</span>
                                    <div class="navbar-tool-icon-box">
                                        <i class="navbar-tool-icon ci-menu"></i>
                                    </div>
                                </a>
                                @auth
                                    <div class="navbar-tool dropdown">

                                        <div class="dropdown-menu dropdown-menu-end" aria-labelledby="userDropdown">
                                            @role('customer')
                                                <div class="dropdown mega-dropdown">
                                                    <a class="dropdown-item" href="{{ route('account.profile') }}">
                                                        <div class="d-flex">
                                                            <div class="ms-2">
                                                                <span class="d-block text-heading">Perfil de
                                                                    usuario</span>
                                                                <small class="d-block text-muted">Mis datos y
                                                                    preferencias</small>
                                                            </div>
                                                        </div>
                                                    </a>
                                                </div>

                                                <div><hr class="dropdown-divider"></div>

                                                <div class="dropdown mega-dropdown">
                                                    <a class="dropdown-item" href="{{ route('account.orders') }}">
                                                        <div class="d-flex">
                                                            <div class="ms-2">
                                                                <span class="d-block text-heading">Mis Ordenes
                                                                </span>
                                                                <small class="d-block text-muted">Historial de
                                                                    ordenes</small>
                                                            </div>
                                                        </div>
                                                    </a>
                                                </div>

                                                <div><hr class="dropdown-divider"></div>
                                            @endrole

                                            <div class="dropdown mega-dropdown">
                                                <a class="dropdown-item" href="{{ route('logout') }}"
                                                    onclick="event.preventDefault();
                                                    document.getElementById('logout-form').submit();">
                                                    <div class="d-flex">
                                                        <div class="ms-2">
                                                            <span class="d-block text-heading">Cerrar Sesión</span>
                                                        </div>
                                                    </div>
                                                </a>
                                                <form id="logout-form" action="{{ route('logout') }}"
                                                    method="POST" class="d-none">
                                                    @csrf
                                                </form>
                                            </div>
                                        </div>

                                        <div class="navbar-tool-text ms-n3">
                                            <small>Hola</small> {{ auth()->user()->name }}
                                        </div>
                                    </div>
                                    @role('customer')
                                        <div class="navbar-tool dropdown ms-3">
                                            <a class="navbar-tool-icon-box bg-secondary dropdown-toggle"
                                                href="{{ route('cart.list') }}">
                                                @if (Cart::getTotalQuantity() > 0)
                                                    <span class="navbar-tool-label">{{ Cart::getTotalQuantity() }}</span>
                                                @endif
                                                <i class="navbar-tool-icon bi bi-cart3"></i>
                                            </a>
                                            <a class="navbar-tool-text" href="{{ route('cart.list') }}">
                                                <small>Carrito</small>${{ Cart::getTotal() }}
                                            </a>
                                            <!-- Cart dropdown-->
                                            @if (count(Cart::getContent()))
                                                <div class="dropdown-menu dropdown-menu-end">
                                                    <div class="widget widget-cart px-3 pt-2 pb-3" style="width: 20rem;">
                                                        <div style="height: 15rem;" data-simplebar
                                                            data-simplebar-auto-hide="false">
                                                            @foreach (Cart::getContent() as $item)
                                                                <div class="widget-cart-item pb-2 border-bottom">
                                                                    <form action="{{ route('cart.remove') }}" method="post">
                                                                        @csrf
                                                                        <input type="hidden" name="item_id"
                                                                            value="{{ $item->id }}">
                                                                        <button class="btn-close text-danger" type="submit"
                                                                            aria-label="Remove">
                                                                            <span aria-hidden="true">&times;</span>
                                                                        </button>
                                                                    </form>
                                                                    <div class="d-flex align-items-center">
                                                                        <a class="d-block flex-shrink-0"
                                                                            href="{{route('products-by-filter', $item->id)}}">
                                                                            <img src="{{ Storage::url($item->attributes->featured) }}"
                                                                                width="64" alt="Product">
                                                                        </a>
                                                                        <div class="ps-2">
                                                                            <h6 class="widget-product-title">
                                                                                <a href="{{route('products-by-filter', $item->id)}}">
                                                                                    {{ $item->name }}
                                                                                </a>
                                                                            </h6>
                                                                            <div class="widget-product-meta">
                                                                                <x-amount-formatter :amount="$item->price" />
                                                                                <span class="text-muted">x
                                                                                    {{ $item->quantity }}</span>
                                                                            </div>
                                                                        </div>
                                                                    </div>
                                                                </div>
                                                            @endforeach
                                                        </div>
                                                        <div
                                                            class="d-flex flex-wrap justify-content-between align-items-center py-3">
                                                            <div class="fs-sm me-2 py-2">
                                                                <span class="text-muted">Subtotal:</span>
                                                                <span class="text-accent fs-base ms-1">
                                                                    <x-amount-formatter :amount="Cart::getTotal()" />
                                                                </span>
                                                            </div>
                                                            <a class="btn btn-outline-secondary btn-sm"
                                                                href="{{ route('cart.list') }}">
                                                                Expandir carrito<i class="ci-arrow-right ms-1 me-n1"></i>
                                                            </a>
                                                        </div>
                                                        <a class="btn btn-primary btn-sm d-block w-100"
                                                            href="{{ route('checkout.index') }}">
                                                            <i class="ci-card me-2 fs-base align-middle"></i>
                                                            Proceso de Compra
                                                        </a>
                                                    </div>
                                                </div>
                                            @endif
                                        </div>
                                    @endrole
                                @endauth
                            </div>
                        </div>
                    </div>
                    <div class="navbar navbar-expand-lg navbar-light navbar-stuck-menu mt-n2 pt-0 pb-2">
                        <div class="container">
                            <div class="collapse navbar-collapse" id="navbarCollapse">
                                <!-- Search-->
                                <div class="input-group d-lg-none my-3 filter-products">
                                    <i class="bi bi-search search-m z-1 position-absolute top-50 start-0 translate-middle-y ms-3"
                                        style="opacity: .5;"></i>
                                    <input class="form-control rounded-start w-100" type="text"
                                        id="search-products-m" placeholder="">
                                    <div class="position-absolute" id="autocomplete-list-m"
                                        style="z-index: 1000; width: 100%;"></div>
                                </div>
                                <!-- Departments menu-->
                                @role('operator')
                                    <ul class="navbar-nav navbar-mega-nav pe-lg-2 me-lg-2">
                                        <li class="nav-item dropdown">
                                            <a class="nav-link dropdown-toggle ps-lg-0" href="#"
                                                data-bs-toggle="dropdown" data-bs-auto-close="outside">
                                                <i class="ci-menu align-middle mt-n1 me-2"></i>
                                                Admin
                                            </a>
                                            <ul class="dropdown-menu">
                                                <li class="dropdown mega-dropdown">
                                                    <a class="dropdown-item" href="{{ route('admin.orders.index') }}">
                                                        <i class="ci-laptop opacity-60 fs-lg mt-n1 me-2"></i>
                                                        Ordenes
                                                    </a>
                                                </li>
                                                <li class="dropdown mega-dropdown">
                                                    <a class="dropdown-item" href="{{ route('admin.customers.index') }}">
                                                        <i class="ci-laptop opacity-60 fs-lg mt-n1 me-2"></i>
                                                        Clientes
                                                    </a>
                                                </li>
                                                <li class="dropdown mega-dropdown">
                                                    <a class="dropdown-item" href="{{ route('admin.products.index') }}">
                                                        <i class="ci-monitor opacity-60 fs-lg mt-n1 me-2"></i>
                                                        Productos
                                                    </a>
                                                </li>
                                                <li class="dropdown mega-dropdown">
                                                    <a class="dropdown-item" href="">
                                                        <i class="ci-monitor opacity-60 fs-lg mt-n1 me-2"></i>
                                                        Usuarios
                                                    </a>
                                                </li>
                                                <li class="dropdown mega-dropdown">
                                                    <a class="dropdown-item" href="">
                                                        <i class="ci-monitor opacity-60 fs-lg mt-n1 me-2"></i>
                                                        Dashboard
                                                    </a>
                                                </li>
                                            </ul>
                                        </li>
                                    </ul>
                                @endrole

                                @if (Auth::check() && Auth::user()->hasRole('customer'))
                                    <ul class="navbar-nav navbar-mega-nav pe-lg-2 me-lg-2 d-lg-none">
                                        <li class="nav-item dropdown">
                                            <a class="nav-link dropdown-toggle ps-lg-0" href="#"
                                                data-bs-toggle="dropdown" data-bs-auto-close="outside">
                                                <i class="ci-menu align-middle mt-n1 me-2"></i>
                                                Mi cuenta
                                            </a>
                                            <ul class="dropdown-menu">
                                                <li class="dropdown mega-dropdown">
                                                    <a class="dropdown-item" href="{{ route('account.profile') }}">
                                                        <div class="d-flex">
                                                            <div class="lead text-muted pt-1"><i class="ci-book"></i>
                                                            </div>
                                                            <div class="ms-2">
                                                                <span class="d-block text-heading">Perfil de
                                                                    usuario</span>
                                                                <small class="d-block text-muted">Mis datos y
                                                                    preferencias</small>
                                                            </div>
                                                        </div>
                                                    </a>
                                                </li>
                                                <li class="dropdown mega-dropdown">
                                                    <a class="dropdown-item" href="{{ route('account.orders') }}">
                                                        <div class="d-flex">
                                                            <div class="lead text-muted pt-1"><i class="ci-edit"></i>
                                                            </div>
                                                            <div class="ms-2">
                                                                <span class="d-block text-heading">Mis Ordenes
                                                                </span>
                                                                <small class="d-block text-muted">Historial de
                                                                    ordenes</small>
                                                            </div>
                                                        </div>
                                                    </a>
                                                </li>
                                                <li class="dropdown mega-dropdown">
                                                    <a class="dropdown-item" href="{{ route('logout') }}"
                                                        onclick="event.preventDefault();
                                                        document.getElementById('logout-form').submit();">
                                                        <div class="d-flex">
                                                            <div class="lead text-muted pt-1"><i class="ci-help"></i>
                                                            </div>
                                                            <div class="ms-2">
                                                                <span class="d-block text-heading">Cerrar Sesión</span>
                                                            </div>
                                                        </div>
                                                    </a>
                                                    <form id="logout-form" action="{{ route('logout') }}"
                                                        method="POST" class="d-none">
                                                        @csrf
                                                    </form>
                                                </li>
                                            </ul>
                                        </li>
                                    </ul>
                                @endif


                                <!-- Primary menu-->
                                <ul class="navbar-nav">
                                    <li class="nav-item dropdown {{ request()->routeIs('index') ? 'active' : '' }}">
                                        <a class="nav-link" href="/">Inicio</a>
                                    </li>
                                    <li
                                        class="nav-item dropdown {{ request()->routeIs('about-us.index') || request()->routeIs('about-us.branches') ? 'active' : '' }}">
                                        <a class="nav-link dropdown-toggle" href="#"
                                            data-bs-toggle="dropdown">Conócenos</a>
                                        <ul class="dropdown-menu">
                                            <li>
                                                <a href="{{ route('about-us.index') }}"
                                                    class="dropdown-item {{ request()->routeIs('about-us.index') ? 'active' : '' }}">
                                                    <div class="d-flex">
                                                        <div class="lead text-muted pt-1">
                                                            <i class="ci-book"></i>
                                                        </div>
                                                        <div class="ms-2">
                                                            <span class="d-block text-heading">Nosotros</span>
                                                            <small class="d-block text-muted">Nuestra cultura</small>
                                                        </div>
                                                    </div>
                                                </a>
                                            </li>
                                            <li class="dropdown-divider"></li>
                                            <li>
                                                <a href="{{ route('about-us.branches') }}"
                                                    class="dropdown-item {{ request()->routeIs('about-us.branches') ? 'active' : '' }}">
                                                    <div class="d-flex">
                                                        <div class="lead text-muted pt-1">
                                                            <i class="ci-server"></i>
                                                        </div>
                                                        <div class="ms-2">
                                                            <span class="d-block text-heading">
                                                                Sucursales
                                                            </span>
                                                            <small class="d-block text-muted">Centros de
                                                                distribución</small>
                                                        </div>
                                                    </div>
                                                </a>
                                            </li>
                                            <li class="dropdown-divider"></li>
                                            <li>
                                                <a href="{{ route('about-us.contact') }}"
                                                    class="dropdown-item {{ request()->routeIs('about-us.contact') ? 'active' : '' }}">
                                                    <div class="d-flex">
                                                        <div class="lead text-muted pt-1">
                                                            <i class="ci-edit"></i>
                                                        </div>
                                                        <div class="ms-2">
                                                            <span class="d-block text-heading">
                                                                Contacto
                                                            </span>
                                                            <small class="d-block text-muted">Ubicación y
                                                                atención</small>
                                                        </div>
                                                    </div>
                                                </a>
                                            </li>
                                        </ul>
                                    </li>
                                    <li
                                        class="nav-item dropdown {{ request()->routeIs('services.index') || request()->routeIs('services.offer') ? 'active' : '' }}">
                                        <a class="nav-link dropdown-toggle" href="#"
                                            data-bs-toggle="dropdown">Servicios</a>
                                        <ul class="dropdown-menu">
                                            <li>
                                                <a href="{{ route('services.index') }}"
                                                    class="dropdown-item {{ request()->routeIs('services.index') ? 'active' : '' }}">
                                                    <div class="d-flex">
                                                        <div class="lead text-muted pt-1">
                                                            <i class="ci-book"></i>
                                                        </div>
                                                        <div class="ms-2">
                                                            <span class="d-block text-heading">Servicios
                                                                Fundamentales</span>
                                                            <small class="d-block text-muted">Crecemos juntos</small>
                                                        </div>
                                                    </div>
                                                </a>
                                            </li>
                                            <li class="dropdown-divider"></li>
                                            <li>
                                                <a href="{{ route('services.offer') }}"
                                                    class="dropdown-item {{ request()->routeIs('services.offer') ? 'active' : '' }}">
                                                    <div class="d-flex">
                                                        <div class="lead text-muted pt-1">
                                                            <i class="ci-server"></i>
                                                        </div>
                                                        <div class="ms-2">
                                                            <span class="d-block text-heading">
                                                                Oferta especializada
                                                            </span>
                                                            <small class="d-block text-muted">Programas y
                                                                Herramientas</small>
                                                        </div>
                                                    </div>
                                                </a>
                                            </li>
                                        </ul>
                                    </li>
                                    @guest
                                        <li class="nav-item dropdown">
                                            <a class="nav-link dropdown-toggle"
                                                href="{{ route('login') }}">Acceder</a>
                                        </li>
                                    @endguest
                                </ul>
                            </div>
                        </div>
                    </div>
                </div>
            @endif
        </header>

        <main class="">
            @isset($without_location)
                @include('partials.customer-without-location')
            @endisset
            @yield('content')
        </main>

        <footer class="footer bg-blue-gray pt-5">
            <div class="container">
                <div class="row pb-2 justify-content-center">
                    <div class="col-md-2 col-sm-6">
                        <div class="widget widget-links widget-light">
                            <a class="d-none d-sm-block me-3 flex-shrink-0" href="/">
                                <img src="{{ asset('images/logo-secundario.webp') }}" width="160"
                                    alt="Solar Center">
                            </a>
                            <a class="d-sm-none me-2" href="/">
                                <img src="{{ asset('images/logo-secundario.webp') }}" width="74"
                                    alt="Solar Center">
                            </a>
                        </div>
                        <div class="my-1">
                            <a href="https://www.instagram.com/solarcentermx/" target="_blank"
                                rel="noopener noreferrer"><i class="bi bi-instagram social-icon"></i></a>
                            <a href="https://www.facebook.com/SolarCenterMX" target="_blank"
                                rel="noopener noreferrer"><i class="bi bi-facebook social-icon"></i></a>
                        </div>
                    </div>
                    <div class="col-md-2 col-sm-6">
                        <div class="widget widget-links widget-light pb-2 mb-4">
                            <h3 class="widget-title text-light">Atención a Clientes</h3>
                            <ul class="widget-list">
                                <li class="widget-list-item"><a class="widget-list-link"
                                        href="{{ route('faqs.howToBuy') }}">¿Cómo comprar?</a></li>
                                <li class="widget-list-item"><a class="widget-list-link"
                                        href="{{ route('faqs.questions') }}">Preguntas Frecuentes</a></li>
                                <li class="widget-list-item"><a class="widget-list-link"
                                        href="{{ asset('catalogo/solar-center-24.pdf') }}" download>Descargar el
                                        Catálogo</a></li>
                                <li class="widget-list-item"><a class="widget-list-link"
                                        href="{{ route('about-us.contact') }}">Contacto</a></li>
                            </ul>
                        </div>
                    </div>
                    <div class="col-md-2 col-sm-6">
                        <div class="widget widget-links widget-light pb-2 mb-4">
                            <h3 class="widget-title text-light">Cuenta e Información de Envíos</h3>
                            <ul class="widget-list">
                                <li class="widget-list-item">
                                    <a class="widget-list-link" href="#">Tu cuenta</a>
                                </li>
                                <li class="widget-list-item">
                                    <a class="widget-list-link" href="#">Tárifas de envío y Políticas</a>
                                </li>
                                <li class="widget-list-item">
                                    <a class="widget-list-link" href="#">Reembolsos y reemplazos</a>
                                </li>
                                <li class="widget-list-item">
                                    <a class="widget-list-link" href="#">Seguimiento de orden</a>
                                </li>
                                <li class="widget-list-item">
                                    <a class="widget-list-link" href="#">Información de envío</a>
                                </li>
                            </ul>
                        </div>
                    </div>
                    <div class="col-md-2 col-sm-6">
                        <div class="widget widget-links widget-light pb-2 mb-4">
                            <h3 class="widget-title text-light">Sobre Nosotros</h3>
                            <ul class="widget-list">
                                <li class="widget-list-item">
                                    <a class="widget-list-link" href="#">Sobre Solar Center</a>
                                </li>
                                <li class="widget-list-item">
                                    <a class="widget-list-link" href="#">Nuestro equipo</a>
                                </li>
                                <li class="widget-list-item">
                                    <a class="widget-list-link" href="#">Bolsa de Trabajo</a>
                                </li>
                            </ul>
                        </div>
                    </div>
                    <div class="col-md-2 col-sm-6">
                        <div class="widget widget-links widget-light pb-2 mb-4">
                            <h3 class="widget-title text-light">Informacion</h3>
                            <ul class="widget-list">
                                <li class="widget-list-item"><a class="widget-list-link"
                                        href="{{ route('information.generalPolicies') }}">Políticas
                                        generales</a></li>
                                <li class="widget-list-item"><a class="widget-list-link"
                                        href="{{ route('information.warrantyPolicies') }}">Política de
                                        garantía</a></li>
                                <li class="widget-list-item"><a class="widget-list-link"
                                        href="{{ route('information.noticePrivacy') }}">Aviso de
                                        privacidad</a></li>
                        </div>
                    </div>
                </div>
            </div>
            <div class="pt-5 bg-darker">
                <div class="container">
                    <div class="pb-4 fs-xs text-light opacity-50 text-center text-md-start">
                        © Todos los derechos reservados.
                    </div>
                </div>
            </div>
        </footer>
            <div id="sideDiv" class="hidden">
                <object
                style="
                    margin-top: 0;
                    margin-left: 0px;
                    margin-right: 0px;
                    position:fixed;
                    right:20px;
                    bottom:80px;
                    border:0;
                    width: 500px;
                    height: 600px;
                    z-index: 1000;"
                    id="chatObject"
                    type="text/html"
                    data="https://cwkolob215.nuxiba.com/chatjs/?domain=solarcenter.com"
                >
                </object>
            </div>
            {{-- <div>
                <button id="show-chat" type="button" class="btn btn-primary" style="width: 200px; position: fixed; right: 10px; bottom: 10px">
                    Hablar con un asesor
                </button>
            </div> --}}
        @yield('loader')
    </div>
    <script>
        document.getElementById("show-chat").addEventListener("click", function () {
            const sideDiv = document.getElementById("sideDiv");

            if (sideDiv.classList.contains("hidden")) {
                sideDiv.classList.remove("hidden");
                sideDiv.classList.add("visible-right");
            } else if (sideDiv.classList.contains("visible-right")) {
                sideDiv.classList.remove("visible-right");
                sideDiv.classList.add("hidden");
            }
        });
    </script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/tiny-slider/2.9.2/min/tiny-slider.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/simplebar@latest/dist/simplebar.min.js"></script>
    @yield('scripts')
</body>

</html>
