@extends('layouts.app')

@section('styles')
<style>
.d-none {
    display: none;
}

.image-upload > input {
    display: none;
}

.image-upload img {
    cursor: pointer;
}

</style>
@endsection

@section('content')
<div class="container">
    <div class="row justify-content-center">
        <div class="col-md-12">
            <div class="card border border-0 shadow-sm">
                <div class="card-header bg-white border-0">
                    <!-- Contenedor Flex -->
                    <div class="d-flex flex-column flex-md-row justify-content-between align-items-center">
                        <!-- Texto a la izquierda -->
                        <h4 class="fw-bold mt-2">Listado de Banners</h4>
                        <!-- Botones a la derecha -->
                        <div>
                            <a href="{{route('admin.banner-group.create')}}" class="btn btn-outline-accent me-2">Crear</a>
                        </div>
                    </div>
                </div>
                <div class="card-body bg-white">
                    <div class="table-responsive">
                        <table class="table table-hover">
                            <thead class="table-light">
                                <tr class="text-center">
                                    <th scope="col">Imagen</th>
                                    <th scope="col">Texto</th>
                                    <th scope="col">URL del producto</th>
                                    <th scope="col">Acciones</th>
                                </tr>
                            </thead>
                            <tbody>
                                @foreach ($banners as $banner)
                                    <tr class="text-center" data-id="{{$banner->id}}">
                                        <td>
                                            <div class="image-upload">
                                                <label for="file-input-{{$banner->id}}">
                                                    <img
                                                        src="{{ Storage::url($banner->image) }}"
                                                        alt="Imagen Destacada"
                                                        width="100"
                                                        id="image-{{$banner->id}}"
                                                        >
                                                </label>
                                                <input type="file" id="file-input-{{$banner->id}}" class="form-control mt-2 d-none" data-field="image" onchange="previewImage(event, {{$banner->id}})">
                                            </div>
                                            <small class="text-muted fs-xs">123 x 150 px</small>
                                        </td>
                                        <td>
                                            <textarea type="text" class="form-control ckeditor" rows="3" data-field="banner_text">{!! $banner->banner_text !!}</textarea>
                                        </td>
                                        <td>
                                            <input type="text" class="form-control" value="{{$banner->product_url}}" data-field="product_url">
                                        </td>
                                        <td>
                                            <div class="d-flex align-items-center justify-content-center">
                                                <button type="button" class="btn btn-success me-2" onclick="saveRow(this)">
                                                    <i class="bi bi-floppy"></i>
                                                </button>
                                                <form action="{{ route('admin.banner-group.destroy', $banner) }}" method="POST" class="inline ml-2">
                                                    @csrf
                                                    @method('DELETE')
                                                    <button type="button" onclick="confirmDelete(this)" class="btn btn-danger">
                                                        <i class="bi bi-trash"></i>
                                                    </button>
                                                </form>
                                            </div>
                                        </td>
                                    </tr>
                                @endforeach
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection

@section('scripts')
@if (session('message'))
<script>
    Swal.fire({
        position: "center",
        icon: "{{ session('icon') }}",
        title: "{{ session('message') }}",
        showConfirmButton: false,
        timer: 4000,
    });
</script>
@endif
<script src="https://cdn.ckeditor.com/ckeditor5/41.0.0/classic/ckeditor.js"></script>
<script>
    document.addEventListener("DOMContentLoaded", function() {
        document.querySelectorAll('.ckeditor').forEach((textarea) => {
            ClassicEditor
                .create(textarea)
                .then(editor => {
                    textarea.ckeditorInstance = editor;
                })
                .catch(error => {
                    console.error('Error during initialization of the editor', error);
                });
        });
    });

    function previewImage(event, id) {
        var reader = new FileReader();
        reader.onload = function() {
            var output = document.getElementById('image-' + id);
            output.src = reader.result;
        };
        reader.readAsDataURL(event.target.files[0]);
    }

    function saveRow(button) {
        let row = button.closest('tr');
        let sliderId = row.getAttribute('data-id');
        let formData = new FormData();

        // Actualizar manualmente el contenido de CKEditor en cada textarea
        row.querySelectorAll('.ckeditor').forEach(editorElement => {
            let editorInstance = editorElement.ckeditorInstance;
            if (editorInstance) {
                editorInstance.updateSourceElement();
            }
        });

        // Recorrer y agregar los inputs
        row.querySelectorAll('input[data-field]').forEach(input => {
            if (input.type === 'file' && input.files[0]) {
                formData.append(input.getAttribute('data-field'), input.files[0]);
            } else {
                formData.append(input.getAttribute('data-field'), input.value);
            }
        });

        // Recorrer y agregar los textareas
        row.querySelectorAll('textarea[data-field]').forEach(textarea => {
            formData.append(textarea.getAttribute('data-field'), textarea.value);
        });

        fetch(`/admin/banner-group/${sliderId}`, {
            method: 'POST',
            headers: {
                'X-CSRF-TOKEN': '{{ csrf_token() }}',
                'X-HTTP-Method-Override': 'PUT'
            },
            body: formData
        })
        .then(response => {
            if (!response.ok) {
                throw new Error('Error en la respuesta del servidor');
            }
            return response.json();
        })
        .then(data => {
            if (data.success) {
                Swal.fire({
                    icon: 'success',
                    title: 'Actualizado',
                    text: 'Registro actualizado con éxito',
                    timer: 1500,
                    showConfirmButton: false
                });
            } else {
                Swal.fire({
                    icon: 'error',
                    title: 'Error',
                    text: 'Error al actualizar el campo'
                });
            }
        })
        .catch(error => {
            console.error('Error:', error);
            Swal.fire({
                icon: 'error',
                title: 'Error',
                text: 'Error al actualizar el campo'
            });
        });
    }

    function confirmDelete(button) {
        Swal.fire({
            title: '¿Estás seguro?',
            text: "Esta acción no se puede deshacer.",
            icon: 'warning',
            showCancelButton: true,
            confirmButtonColor: '#3085d6',
            cancelButtonColor: '#d33',
            confirmButtonText: 'Sí, eliminar',
            cancelButtonText: 'Cancelar'
        }).then((result) => {
            if (result.isConfirmed) {
                button.closest('form').submit();
            }
        });
    }
</script>
@endsection
