@extends('layouts.app')

@section('styles')
<style>
.d-none {
    display: none;
}

.image-upload > input {
    display: none;
}

.image-upload img {
    cursor: pointer;
}

</style>
@endsection

@section('content')
<div class="container">
    <div class="row justify-content-center">
        <div class="col-md-12">
            <div class="card border border-0 shadow-sm">
                <div class="card-header bg-white border-0">
                    <!-- Contenedor Flex -->
                    <div class="d-flex flex-column flex-md-row justify-content-between align-items-center">
                        <!-- Texto a la izquierda -->
                        <h4 class="fw-bold mt-2">Listado de Sliders</h4>
                        <!-- Botones a la derecha -->
                        <div>
                            <a href="{{route('admin.hero-slider.create')}}" class="btn btn-outline-accent me-2">Crear</a>
                        </div>
                    </div>
                </div>
                <div class="card-body bg-white">
                    <div class="table-responsive">
                        <table class="table table-hover">
                            <thead class="table-light">
                                <tr class="text-center">
                                    <th scope="col">Imagen</th>
                                    <th scope="col">Texto 1</th>
                                    <th scope="col">Texto 2</th>
                                    <th scope="col">Texto 3</th>
                                    <th scope="col">Texto Botón</th>
                                    <th scope="col">URL Botón</th>
                                    <th scope="col">Acciones</th>
                                </tr>
                            </thead>
                            <tbody>
                                @foreach ($sliders as $slider)
                                    <tr class="text-center" data-id="{{$slider->id}}">
                                        <td>
                                            <div class="image-upload">
                                                <label for="file-input-{{$slider->id}}">
                                                    <img src="{{ Storage::url($slider->image) }}" alt="Imagen Destacada" width="100" id="image-{{$slider->id}}">
                                                </label>
                                                <input type="file" id="file-input-{{$slider->id}}" class="form-control mt-2 d-none" data-field="image" onchange="previewImage(event, {{$slider->id}})">
                                            </div>
                                            <small class="text-muted fs-xs">420 x 430 px</small>
                                        </td>
                                        <td>
                                            <input type="text" class="form-control" value="{{$slider->text_small}}" data-field="text_small">
                                        </td>
                                        <td>
                                            <input type="text" class="form-control" value="{{$slider->text_medium}}" data-field="text_medium">
                                        </td>
                                        <td>
                                            <input type="text" class="form-control" value="{{$slider->text_large}}" data-field="text_large">
                                        </td>
                                        <td>
                                            <input type="text" class="form-control" value="{{$slider->button_text}}" data-field="button_text">
                                        </td>
                                        <td>
                                            <input type="text" class="form-control" value="{{$slider->button_url}}" data-field="button_url">
                                        </td>
                                        <td>
                                            <div class="d-flex align-items-center justify-content-center">
                                                <button type="button" class="btn btn-success me-2" onclick="saveRow(this)">
                                                    <i class="bi bi-floppy"></i>
                                                </button>
                                                <form action="{{ route('admin.hero-slider.destroy', $slider) }}" method="POST" class="inline ml-2">
                                                    @csrf
                                                    @method('DELETE')
                                                    <button type="button" onclick="confirmDelete(this)" class="btn btn-danger">
                                                        <i class="bi bi-trash"></i>
                                                    </button>
                                                </form>
                                            </div>
                                        </td>
                                    </tr>
                                @endforeach
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection

@section('scripts')
@if (session('message'))
<script>
    Swal.fire({
        position: "center",
        icon: "{{ session('icon') }}",
        title: "{{ session('message') }}",
        showConfirmButton: false,
        timer: 2000,
    });
</script>
@endif

<script>
    function previewImage(event, id) {
        var reader = new FileReader();
        reader.onload = function() {
            var output = document.getElementById('image-' + id);
            output.src = reader.result;
        };
        reader.readAsDataURL(event.target.files[0]);
    }

    function saveRow(button) {
        let row = button.closest('tr');
        let sliderId = row.getAttribute('data-id');
        let formData = new FormData();

        row.querySelectorAll('input[data-field]').forEach(input => {
            if (input.type === 'file' && input.files[0]) {
                formData.append(input.getAttribute('data-field'), input.files[0]);
            } else {
                formData.append(input.getAttribute('data-field'), input.value);
            }
        });

        fetch(`/admin/hero-slider/${sliderId}`, {
            method: 'POST',  // Cambiamos de POST a PUT
            headers: {
                'X-CSRF-TOKEN': '{{ csrf_token() }}',
                'X-HTTP-Method-Override': 'PUT' // Añadimos esto para engañar al navegador
            },
            body: formData
        })
        .then(response => {
            if (!response.ok) {
                throw new Error('Error en la respuesta del servidor');
            }
            return response.json();
        })
        .then(data => {
            if (data.success) {
                Swal.fire({
                    icon: 'success',
                    title: 'Actualizado',
                    text: 'Registro actualizado con éxito',
                    timer: 1500,
                    showConfirmButton: false
                });
            } else {
                Swal.fire({
                    icon: 'error',
                    title: 'Error',
                    text: 'Error al actualizar el campo'
                });
            }
        })
        .catch(error => {
            console.error('Error:', error);
            Swal.fire({
                icon: 'error',
                title: 'Error',
                text: 'Error al actualizar el campo'
            });
        });
    }

    function confirmDelete(button) {
        Swal.fire({
            title: '¿Estás seguro?',
            text: "Esta acción no se puede deshacer.",
            icon: 'warning',
            showCancelButton: true,
            confirmButtonColor: '#3085d6',
            cancelButtonColor: '#d33',
            confirmButtonText: 'Sí, eliminar',
            cancelButtonText: 'Cancelar'
        }).then((result) => {
            if (result.isConfirmed) {
                button.closest('form').submit();
            }
        });
    }
</script>
@endsection
