@extends('layouts.app')

@section('styles')
<style>
    table.dataTable thead th:nth-child(1) .dt-column-order {
    display: none;
}
</style>
@endsection

@section('content')
<div class="container">
    <div class="row justify-content-center">
        <div class="col-md-10">
            <div class="card border border-0 shadow-sm">
                <div class="card-header bg-white border-0 pb-0">
                    <!-- Contenedor Flex -->
                    <div class="d-flex flex-column flex-md-row justify-content-between align-items-center">
                        <!-- Texto a la izquierda -->
                        <h4 class="fw-bold mt-2">Listado de productos</h4>
                        <!-- Botones a la derecha -->
                        {{-- <div>
                            <a href="{{route('admin.products.create')}}" class="btn btn-outline-accent me-2">Crear</a>
                            <a href="{{route('admin.products.create')}}" class="btn btn-outline-accent">Importar</a>
                        </div> --}}
                    </div>
                </div>
                <div class="card-body bg-white pt-0">
                    <table class="table table-striped" id="products">
                        <thead class="table-light">
                            <tr class="text-center">
                                <th scope="col">Imagen</th>
                                <th scope="col">Nombre</th>
                                <th scope="col">Marca</th>
                                <th scope="col">Categoría</th>
                                <th scope="col">Acciones</th>
                            </tr>
                        </thead>
                        <tbody>
                            @foreach ($products as $product)
                            <tr class="text-center">
                                <td>
                                    <img src="{{ Storage::url($product->featured) }}" alt="Imagen Destacada" width="100">
                                </td>
                                <td scope="row">
                                    {{$product->name}}
                                </td>
                                <td>{{$product->brand}}</th>
                                <td>
                                    {{$product->category? $product->category->name: ''}}
                                </td>
                                <td>
                                    <div class="d-flex align-items-center justify-content-center">
                                        <a href="{{ route('admin.products.edit', $product) }}" class="btn btn-warning me-2">
                                            <i class="bi bi-pencil"></i>
                                        </a>
                                        <form
                                            action="{{ route('admin.products.destroy', $product) }}"
                                            method="POST"
                                            class="inline ml-2"
                                        >
                                            @csrf
                                            @method('DELETE')
                                            <button type="button" onclick="confirmDelete(this)" class="btn btn-danger">
                                                <i class="bi bi-trash"></i>
                                            </button>
                                        </form>
                                    </div>
                                </td>
                                </tr>
                            @endforeach
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection

@section('scripts')
<script src="https://code.jquery.com/jquery-3.7.1.min.js"></script>
<script src="https://cdn.datatables.net/2.0.8/js/dataTables.min.js"></script>

<script>
    let table = new DataTable('#products', {
        lengthChange: false,
        columnDefs: [
            { orderable: false, targets: 0 }  // Deshabilita la ordenación para la primera columna (índice 0)
        ],
        language: {
            decimal: "",
            emptyTable: "No hay datos disponibles en la tabla",
            info: "Mostrando _START_ a _END_ de _TOTAL_ entradas",
            infoEmpty: "Mostrando 0 a 0 de 0 entradas",
            infoFiltered: "(filtrado de _MAX_ entradas totales)",
            infoPostFix: "",
            thousands: ",",
            // lengthMenu: "Mostrar _MENU_ entradas",
            loadingRecords: "Cargando...",
            processing: "Procesando...",
            search: "Buscar:",
            zeroRecords: "No se encontraron registros coincidentes",
            // paginate: {
            //     first: "Primero",
            //     last: "Último",
            //     next: "Siguiente",
            //     previous: "Anterior"
            // },
            aria: {
                sortAscending: ": activar para ordenar la columna de manera ascendente",
                sortDescending: ": activar para ordenar la columna de manera descendente"
            }
        }
    });
</script>

<script>
function confirmDelete(button) {
    Swal.fire({
        title: '¿Estás seguro?',
        text: "Esta acción no se puede deshacer.",
        icon: 'warning',
        showCancelButton: true,
        confirmButtonColor: '#3085d6',
        cancelButtonColor: '#d33',
        confirmButtonText: 'Sí, eliminar',
        cancelButtonText: 'Cancelar'
    }).then((result) => {
        if (result.isConfirmed) {
            // Si el usuario confirma, envía el formulario
            button.closest('form').submit();
        }
    });
}
</script>
@endsection
