<?php

use Illuminate\Support\Facades\Route;
use App\Http\Controllers\HomeController;
use App\Http\Controllers\CartController;
use App\Http\Controllers\CheckoutController;
use App\Http\Controllers\Customer\Order\CancellationRequest;
use App\Http\Controllers\CustomerRegistrationController;
use App\Http\Controllers\CustomerAccountController;
use App\Http\Controllers\CustomerSupport\Address\Update;
use App\Http\Controllers\CustomerSupport\CancelShipController;
use App\Http\Controllers\ForgotPasswordController;
use App\Http\Controllers\CustomerSupport\CustomerController;
use App\Http\Controllers\CustomerSupport\OrderController;
use App\Http\Controllers\CustomerSupport\ShipController as CustomerSupportShipController;
use App\Http\Controllers\CustomerSupport\ShipmentLabel;
use App\Http\Controllers\CustomerSupport\ShippingController as CustomerSupportShippingController;
use App\Http\Controllers\CustomerSupport\UpdateShipController;
use App\Http\Controllers\Marketing\ProductController;
use App\Http\Controllers\Marketing\HeroSliderController;
use App\Http\Controllers\Marketing\BannerGroupController;
use App\Http\Controllers\ShippingController;
use App\Http\Controllers\StockAssistanceRequestController;
use App\Http\Middleware\Customer\HasLocation;

Route::get('/', [HomeController::class, 'index'])
    ->middleware(HasLocation::class)
    ->name('index');

Route::get('/nosotros', [HomeController::class, 'aboutUs'])->name('about-us.index');
Route::get('/sucursales', [HomeController::class, 'branches'])->name('about-us.branches');
Route::get('/contacto', [HomeController::class, 'contact'])->name('about-us.contact');
Route::post('/contacto', [HomeController::class, 'sendContact'])->name('about-us.send-contact');
Route::get('/servicios', [HomeController::class, 'services'])->name('services.index');
Route::get('/oferta-especializada', [HomeController::class, 'offer'])->name('services.offer');
Route::get('/como-comprar', [HomeController::class, 'howToBuy'])->name('faqs.howToBuy');
Route::get('/preguntas-frecuentes', [HomeController::class, 'questions'])->name('faqs.questions');
Route::get('/politicas-generales', [HomeController::class, 'generalPolicies'])->name('information.generalPolicies');
Route::get('/politicas-garantia', [HomeController::class, 'warrantyPolicies'])->name('information.warrantyPolicies');
Route::get('/aviso-privacidad', [HomeController::class, 'noticePrivacy'])->name('information.noticePrivacy');
Route::get('/integradores', [HomeController::class, 'integrators'])->name('integrators.index');
Route::post('/integradores', [HomeController::class, 'sendIntegratorContact'])->name('integrators.send-contact');

Route::get('/buscar-productos', [HomeController::class, 'searchProducts'])->name('search-products');
Route::get('/producto/{product}', [HomeController::class, 'productByFilter'])
    ->middleware(HasLocation::class)
    ->name('products-by-filter');

Route::get('/productos', [HomeController::class, 'productFilter'])
    ->middleware(HasLocation::class)
    ->name('product-filter');

Route::middleware(['auth'])->group(function () {
    // Delete this routes when deploy is fucking ready!
    // Route::get('/symlink', function () {
    //     Artisan::call('storage:link');
    //     return 'Migrate fresh successfully!';
    // });

    Route::get('/migrate-fresh', function () {
        try {
            Artisan::call('migrate:fresh');

            Artisan::call('db:seed');

            return 'Migrate fresh successfully!';
        } catch (\Exception $e) {
            return 'Error clearing cache: ' . $e->getMessage();
        }
    });

    Route::get('/clear-cache', function () {
        try {
            Artisan::call('route:cache');
            Artisan::call('view:cache');
            Artisan::call('config:cache');

            Artisan::call('route:clear');
            Artisan::call('view:clear');
            Artisan::call('config:clear');

            Artisan::call('cache:clear');
            Artisan::call('optimize:clear');
            return 'Cache cleared successfully!';
        } catch (\Exception $e) {
            return 'Error clearing cache: ' . $e->getMessage();
        }
    });

    // Route::get('/productos/{category}', [HomeController::class, 'productsByCategory'])->name('products-by-category');


    Route::get('carrito', [CartController::class, 'cartList'])
        ->middleware(\App\Http\Middleware\Customer\CartEmpty::class)
        ->name('cart.list');
    Route::post('carrito', [CartController::class, 'addToCart'])
        ->name('cart.store');
    Route::post('carrito/actualizar', [CartController::class, 'updateCart'])
        ->name('cart.update');
    Route::post('carrito/eliminar', [CartController::class, 'removeCart'])
        ->name('cart.remove');
    Route::post('carrito/limpiar', [CartController::class, 'clearAllCart'])
        ->name('cart.clear');
    Route::get('carrito/producto/{product}/stock', [CartController::class, 'getProductStock'])
        ->name('cart.product.stock');
    // Carga una vista con los detalles del carrito de compras
    Route::get('checkout/detalle', [CheckoutController::class, 'index'])
        ->middleware(\App\Http\Middleware\Customer\CartEmpty::class)
        ->name('checkout.index');
    // Carga la vista donde el usuario podrá cotizar su envío
    Route::get('checkout/cotizar-envio', [CheckoutController::class, 'getQuoteShipping'])
        ->middleware(\App\Http\Middleware\Customer\CartEmpty::class)
        ->name('checkout.get-quote-shipping');
    // Ejecuta la función para cotizar envíos en el backend por medio de la API de paquetería
    Route::post('shipping/quoter', [ShippingController::class, 'quoter'])
        ->name('shipping.quoter');
    // Recibe los datos de la cotización mediante un método POST y redirige
    Route::post('checkout/procesar-pago', [CheckoutController::class, 'processPayment'])
        ->name('checkout.process-payment');
    // Carga una vista con dos botones "Realicé mi pago" o "Pagar después"
    Route::get('checkout/pago', [CheckoutController::class, 'checkout'])
        ->name('checkout.payment');
    // Guarda la orden en la base de datos
    Route::post('checkout/guardar', [CheckoutController::class, 'store'])
        ->name('checkout.store');
    // Muestra la vista de compra completada con éxito
    Route::get('checkout/completo', [CheckoutController::class, 'complete'])
        ->name('checkout.complete');
    //TODO: revisar si el nombre de estas rutas coinciden con lo que realmente están haciendo.
    // Route::get('checkout-payment', [CheckoutController::class, 'payment'])->name('checkout.payment');
    Route::post('checkout/{order}/update', [CheckoutController::class, 'update'])
        ->name('checkout.update');

    Route::get('cuenta/perfil', [CustomerAccountController::class, 'profile'])
        ->name('account.profile');
    Route::put('cuenta/perfil/{customer}/update', [CustomerAccountController::class, 'profileUpdate'])
        ->name('account.profile-update');
    Route::post('cuenta/perfil/location/update', [CustomerAccountController::class, 'locationUpdate'])
        ->name('account.location-update');

    Route::get('cuenta/ordenes', [CustomerAccountController::class, 'orders'])
        ->name('account.orders');
    Route::post('cuenta/ordenes/solicitud_cancelacion/{id}', [CancellationRequest::class, 'handle'])
        ->name('account.orders.cancellation.request');

    Route::get('cuenta/contacto', [CustomerAccountController::class, 'contact'])
        ->name('account.contact');
    Route::post('cuenta/contacto', [CustomerAccountController::class, 'sendCustomerContact'])
        ->name('account.send-contact');


    Route::post('/customer-requests', [StockAssistanceRequestController::class, 'store']);

});


Route::get('/pre-registro', [CustomerRegistrationController::class, 'index'])->name('customer-registration.index');
Route::post('/pre-registro', [CustomerRegistrationController::class, 'store'])->name('customer-registration.store');
Route::get('/pre-registro/exitoso', function() {
    return view('auth.pre-register');
})->name('customer-registration.success');

Route::prefix('admin')->name('admin.')->middleware(['auth', 'verified'])->group(function () {

    Route::middleware(['role:administration|operator'])->group(function () {
        // Rutas específicas para admin
    });

    Route::middleware(['role:customer_support|operator'])->group(function () {

        Route::resource('customers', CustomerController::class)->except(['create', 'store']);

        Route::resource('orders', OrderController::class)->except(['create', 'store']);
        Route::get('orders/edit/{id}', [OrderController::class, 'edit'])->name('orders.edit');
        Route::post('orders/{order}/update-status', [OrderController::class, 'updateStatus'])->name('orders.update.status');
        Route::post('orders/{order}/invoice', [OrderController::class, 'updateInvoice'])->name('orders.update.invoice');
        Route::post('orders/ship/{shipment_id}', [CustomerSupportShipController::class, 'handle'])->name('orders.ship');
        Route::post('orders/cancel_ship/{shipment_id}',[CancelShipController::class, 'handle'] )->name('orders.ship.cancel');
        Route::get('orders/quote/{shipment_id}', [CustomerSupportShippingController::class, 'handle'])->name('orders.quote');
        Route::post('orders/update_and_ship/{shipment_id}', [UpdateShipController::class, 'handle'])->name('orders.update.ship');
        Route::get('orders/shipment/label/{shipment_id}', [ShipmentLabel::class, 'handle'])->name('orders.shipment.label');
        Route::post('orders/cancelar/{id}', [OrderController::class, 'cancel'])->name('orders.cancel');
        Route::prefix('customers/address')->group(function(){

            Route::get('edit/{id}', [Update::class, 'view'])
                ->name('customer.address.update.view');
            Route::post('edit', [Update::class, 'handler'])
                ->name('customer.address.update');

        });
    });

    Route::middleware(['role:marketing|operator'])->group(function () {
        Route::resource('products', ProductController::class)->except(['show']);
        Route::resource('hero-slider', HeroSliderController::class)->except(['show']);
        Route::resource('banner-group', BannerGroupController::class)->except(['show']);
    });

});


Auth::routes();

Route::get('/home', [App\Http\Controllers\HomeController::class, 'index'])->name('home');

// Custom Forgot & Reset Password
Route::get('forget-password', [ForgotPasswordController::class, 'showForgetPasswordForm'])->name('forget.password.get');
Route::post('forget-password', [ForgotPasswordController::class, 'submitForgetPasswordForm'])->name('forget.password.post');
Route::get('reset-password/{token}', [ForgotPasswordController::class, 'showResetPasswordForm'])->name('reset.password.get');
Route::post('reset-password', [ForgotPasswordController::class, 'submitResetPasswordForm'])->name('reset.password.post');


Route::get('testing-chat', function() {
    return view('testing-chat');
});
